#
# spec file for package fwupd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch %{ix86} x86_64 %{arm} aarch64 riscv64
%bcond_without efi_fw_update
%else
%bcond_with efi_fw_update
%endif

%ifarch %{ix86} x86_64
%bcond_without msr_support
%bcond_without dell_support
%else
%bcond_with msr_support
%bcond_with dell_support
%endif

%if 0%{?suse_version} > 1500
%bcond_without fish_support
%else
%bcond_with fish_support
%endif

%define shlib_sover  3
%define docs 0

Name:           fwupd
Version:        2.0.6
Release:        2.1
Summary:        Device firmware updater daemon
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Management
URL:            https://fwupd.org/
Source:         %{name}-%{version}.tar.xz

# PATCH-FIX-UPSTREAM
Patch0:         https://patch-diff.githubusercontent.com/raw/fwupd/fwupd/pull/8583.patch
# PATCH-FIx-UPSTREAM
Patch1:         https://patch-diff.githubusercontent.com/raw/fwupd/fwupd/pull/8588.patch
# PATCH-FIX-OPENSUSE fwupd-bsc1130056-shim-path.patch bsc#1130056
Patch99:        fwupd-bsc1130056-change-shim-path.patch

BuildRequires:  dejavu-fonts
BuildRequires:  fdupes
%if %{with fish_support}
BuildRequires:  fish
%endif
BuildRequires:  gcab
# for certtool
BuildRequires:  gnutls
BuildRequires:  gobject-introspection
BuildRequires:  gobject-introspection-devel
BuildRequires:  gpgme-devel
BuildRequires:  help2man
BuildRequires:  intltool
BuildRequires:  libelf-devel
BuildRequires:  meson >= 0.62.0
BuildRequires:  pkgconfig
BuildRequires:  procps
BuildRequires:  python3-Pillow
BuildRequires:  python3-cairo
BuildRequires:  python3-dbusmock
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-setuptools
BuildRequires:  python3-xml
BuildRequires:  vala
BuildRequires:  xz-devel
BuildRequires:  pkgconfig(appstream-glib) >= 0.5.10
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(colorhug) >= 1.2.12
%ifnarch s390x ppc64le
BuildRequires:  pkgconfig(flashrom)
%endif
%if 0%{?docs}
BuildRequires:  pandoc
%endif
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.45.8
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.48.8
BuildRequires:  pkgconfig(glib-2.0) >= 2.45.8
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 232
BuildRequires:  pkgconfig(gusb) >= 0.2.9
BuildRequires:  pkgconfig(jcat) >= 0.1.3
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.1.1
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libcbor)
BuildRequires:  pkgconfig(libcurl) >= 7.62.0
BuildRequires:  pkgconfig(libdrm_amdgpu)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libgcab-1.0) >= 1.0
BuildRequires:  pkgconfig(libprotobuf-c)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(mbim-glib)
BuildRequires:  pkgconfig(mm-glib)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(qmi-glib)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(tss2-esys) >= 2.0
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(umockdev-1.0)
BuildRequires:  pkgconfig(xmlb) >= 0.3.19
%if %{with efi_fw_update}
BuildRequires:  pkgconfig(efiboot)
BuildRequires:  pkgconfig(efivar) >= 33
%endif
%ifarch %{ix86} x86_64
BuildRequires:  pkgconfig(libsmbios_c) >= 2.3.0
%endif
Obsoletes:      dbxtool <= 8
Provides:       dbxtool
%if %{with efi_fw_update}
Obsoletes:      fwupdate <= 12
%ifarch x86_64 aarch64
Requires:       shim >= 11
Requires:       udisks2
%endif
%endif
%if %{with efi_fw_update}
Requires:       fwupd-efi
%endif

%description
fwupd is a daemon to allows session software to update device firmware on
the local machine.

You can either use a GUI software manager like GNOME Software to view and apply
updates, the command line tool or the system D-Bus interface directly.

%package -n libfwupd%{shlib_sover}
Summary:        Allow session software to update device firmware
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libfwupd%{shlib_sover}
fwupd is a daemon to allows session software to update device firmware on
the local machine.

%package -n typelib-1_0-Fwupd-2_0
Summary:        GObject-introspection bindings for libfwupd
Group:          System/Libraries

%description -n typelib-1_0-Fwupd-2_0
fwupd is a daemon to allows session software to update device firmware on
the local machine.

%package -n dfu-tool
Summary:        Generic tool Device Firmware Upgrade (DFU) tool
Group:          Development/Tools/Other

%description -n dfu-tool
A generic tool to upload firmware to USB Devices based on Device Firmware Upgrade (DFU).

%package devel
Summary:        Allow session software to update device firmware
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
Requires:       libfwupd%{shlib_sover} = %{version}
Requires:       typelib-1_0-Fwupd-2_0 = %{version}

%description devel
fwupd is a daemon to allows session software to update device firmware on
the local machine.

%package doc
Summary:        Developer documentation for %{name}
BuildArch:      noarch

%description doc
Developer documentation for %{name}.

%package bash-completion
Summary:        Bash completion for fwupd
Group:          System/Management
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
This package contain the bash completion command for the device firmware updater daemon.

%if %{with fish_support}
%package fish-completion
Summary:        Fish completion for fwupd
Group:          System/Management
Requires:       %{name}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
This package contain the fish completion command for the device firmware updater daemon.
%endif

%lang_package

%prep
%autosetup -p1

for file in $(grep -l %{_bindir}/env . -r); do
  sed -i "s|%{_bindir}/env python3|%{_bindir}/python3|" $file
done

%build
# for F_OFD_SETLK detection
export CFLAGS="%{optflags} -D_GNU_SOURCE"
# Dell support requires direct SMBIOS access,
# Synaptics requires Dell support, i.e. x86 only
%meson \
  -Dlaunchd=disabled \
  -Dplugin_amdgpu=enabled \
  -Dpassim=disabled \
%if %{with efi_fw_update}
  -Dplugin_uefi_capsule=enabled \
  -Dplugin_uefi_pk=enabled \
  -Defi_binary=false \
%else
  -Dplugin_uefi_capsule=disabled \
  -Dplugin_uefi_pk=disabled \
%endif
%if %{with msr_support}
  -Dplugin_msr=enabled \
%else
  -Dplugin_msr=disabled \
%endif
%if %{with dell_support}
  -Dplugin_synaptics_mst=enabled \
%else
  -Dplugin_synaptics_mst=disabled \
%endif
%ifnarch %{ix86} x86_64
  -Dplugin_synaptics_rmi=disabled \
%endif
  -Dplugin_nvme=enabled \
  -Dplugin_redfish=enabled \
  -Ddocs=enabled \
  -Dsupported_build=enabled \
  -Dtests=false \
  -Dvalgrind=disabled \
  -Dvendor_ids_dir=/usr/share/hwdata \
%ifarch s390x ppc64le
  -Dplugin_flashrom=disabled \
%endif
%if 0%{?docs}
  -Dman=true \
%else
  -Dman=false \
%endif
  %{nil}
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}/doc

# Do not ship default polkit .rules - openSUSE overrides them anyway - boo#1125428
rm %{buildroot}%{_datadir}/polkit-1/rules.d/org.freedesktop.fwupd.rules

# do not package tests
rm -fr %{buildroot}%{_datadir}/installed-tests

%if %{without fish_support}
rm -fr %{buildroot}%{_datadir}/fish
%endif

%if %{suse_version} >= 1600
%python3_fix_shebang_path %{buildroot}%{_datadir}/%{name}/*
%endif

%check
%meson_test

%ldconfig_scriptlets -n libfwupd%{shlib_sover}

%preun
%service_del_preun %{name}.service fwupd-refresh.service

%pre
%service_add_pre %{name}.service fwupd-refresh.service

%post
%udev_rules_update
%service_add_post %{name}.service fwupd-refresh.service

%postun
%service_del_postun %{name}.service fwupd-refresh.service

%files
%license COPYING
%doc README.md
%{_unitdir}/fwupd.service
%{_unitdir}/fwupd-refresh.service
%{_unitdir}/fwupd-refresh.timer
%{_libexecdir}/fwupd
%{_bindir}/fwupdmgr
%{_bindir}/fwupdtool
%{_bindir}/dbxtool
%{_datadir}/dbus-1/system.d/org.freedesktop.fwupd.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.fwupd.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.fwupd.service
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/metainfo
%dir %{_datadir}/%{name}/quirks.d
%dir %{_datadir}/%{name}/remotes.d
%dir %{_datadir}/%{name}/remotes.d/vendor
%dir %{_datadir}/%{name}/remotes.d/vendor/firmware
%{_datadir}/%{name}/add_capsule_header.py
%{_datadir}/%{name}/firmware_packager.py
%{_datadir}/%{name}/install_dell_bios_exe.py
%{_datadir}/%{name}/simple_client.py
%if %{with efi_fw_update}
%{_datadir}/%{name}/uefi-capsule-ux.tar.xz
%endif
%{_datadir}/%{name}/metainfo/org.freedesktop.fwupd.remotes.lvfs-testing.metainfo.xml
%{_datadir}/%{name}/metainfo/org.freedesktop.fwupd.remotes.lvfs.metainfo.xml
%{_datadir}/%{name}/remotes.d/vendor/firmware/README.md
%if 0%{?docs}
%{_mandir}/man1/fwupdagent.1%{?ext_man}
%{_mandir}/man1/fwupdmgr.1%{?ext_man}
%{_mandir}/man1/fwupdtool.1%{?ext_man}
%if %{with efi_fw_update}
%{_mandir}/man1/dbxtool.1%{?ext_man}
%{_mandir}/man1/fwupdate.1%{?ext_man}
%endif
%endif
%{_datadir}/polkit-1/actions/org.freedesktop.fwupd.policy
%if %{with msr_support}
%dir %{_modulesloaddir}
%{_modulesloaddir}/fwupd-msr.conf
%endif
%config %{_sysconfdir}/%{name}/
%dir %{_sysconfdir}/pki
%dir %{_sysconfdir}/pki/fwupd
%dir %{_sysconfdir}/pki/fwupd-metadata
%{_sysconfdir}/pki/fwupd-metadata/GPG-KEY-Linux-Vendor-Firmware-Service
%{_sysconfdir}/pki/fwupd-metadata/GPG-KEY-Linux-Foundation-Metadata
%{_sysconfdir}/pki/fwupd-metadata/LVFS-CA.pem
%{_sysconfdir}/pki/fwupd/GPG-KEY-Linux-Vendor-Firmware-Service
%{_sysconfdir}/pki/fwupd/GPG-KEY-Linux-Foundation-Firmware
%{_sysconfdir}/pki/fwupd/LVFS-CA.pem
%if %{with efi_fw_update}
%dir %{_sysconfdir}/grub.d
%{_sysconfdir}/grub.d/35_fwupd
%endif
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.freedesktop.fwupd.metainfo.xml
%{_datadir}/icons/hicolor/*
%{_prefix}/lib/systemd/system-shutdown/fwupd.shutdown
%dir %{_libdir}/fwupd-*
%ifnarch s390x ppc64le
%{_libdir}/fwupd-*/libfu_plugin_flashrom.so
%endif
%{_libdir}/fwupd-*/libfu_plugin_modem_manager.so
%{_libdir}/fwupd-*/libfwupdengine.so
%{_libdir}/fwupd-*/libfwupdplugin.so
%{_libdir}/fwupd-*/libfwupdutil.so
%{_datadir}/%{name}/quirks.d/builtin.quirk.gz
%_sysusersdir/fwupd.conf

%files -n libfwupd%{shlib_sover}
%{_libdir}/libfwupd.so.*

%files -n typelib-1_0-Fwupd-2_0
%{_libdir}/girepository-1.0/Fwupd-2.0.typelib

%files devel
%{_datadir}/gir-1.0/Fwupd-2.0.gir
%{_datadir}/vala/vapi/fwupd.deps
%{_datadir}/vala/vapi/fwupd.vapi
%{_includedir}/fwupd-3/
%{_libdir}/pkgconfig/fwupd.pc
%{_libdir}/libfwupd.so

%files doc
%doc %{_datadir}/doc/fwupd/
%doc %{_datadir}/doc/libfwupd/
%doc %{_datadir}/doc/libfwupdplugin/

%files bash-completion
%{_datadir}/bash-completion/completions/fwupdmgr
%{_datadir}/bash-completion/completions/fwupdtool

%if %{with fish_support}
%files fish-completion
%{_datadir}/fish/vendor_completions.d/fwupdmgr.fish
%endif

%files lang -f %{name}.lang

%changelog
* Mon Mar 17 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Add 8588.patch: Fix compile when using Pango >= 1.56.2.
* Tue Mar 11 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Add explicit pkgconfig(pango) BuildRequires: used to be pulled in
  by python-gobject, but that's no longer the case with 3.52.
- Add 8583.patch: Fix build againts pygobject 3.52.
* Fri Feb 14 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.0.6:
  + This release adds the following features:
  - Add 'fwupdtool efiboot-hive' to allow setting the nmbl cmdline
  - Allow setting the inhibit reason from fwupdmgr
  - Allow USB-provided hidraw devices to use DS-20 descriptors
  + This release fixes the following bugs:
  - Correctly deploy the dbx on MSI hardware
  - Correctly extract the milestone from Lenovo version numbers
  - Do not add invalid CoSWID entities to fix a fuzzing hang
  - Fix Logitech HID++ child device detection
  - Get the correct internal network VID and PID from Redfish
  - Include the payload length in the Wacom scaler update start command
  - Only use emulated devices when using device-emulate
  - Reload the thunderbolt retimer version after the payload is deployed
  - Speed up startup by ~1%% by limiting the precision of percentage updates
  - Support new version formats for future Huddly devices
  - Updating the Logitech Rallybar in a more reliable way
  + This release adds support for the following hardware:
  - HPE Gen10/Gen10+ devices using Redfish
* Mon Feb  3 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.0.5:
  + This release adds the following features:
  - Allow emulating devices reading EFI keys
  - Allow skipping device tests by CPU architecture
  + This release fixes the following bugs:
  - Cleanup Dell kestrel devices when disconnected
  - Correctly build binary EFI_SIGNATURE_LIST objects
  - Do not allow dbx updates when no ESP was found
  - Ignore BootXXXX entries that do not exist when checking the dbx
  - Ignore EFI binaries that are zero-sized, or not well formed
  - Inhibit dbx updates if snapd is not available when using Ubuntu-style FDE
  - Only match the device checksum if the protocol matches
  - Raise authentication requirements for emulation-load
  - Request to upload failed reports for install/downgrade too
  - Use the kernel architecture when building the dbx instance ID
  - Write sbatlevel to PE/COFF files correctly
  + This release adds support for the following hardware:
  - More ELAN Fingerprint readers
  - Star Labs StarLite Magnetic Keyboard
* Mon Jan 20 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.0.4+4:
  + dell-kestrel: cleanup the devices when disconnected
  + Raise authentication requirements for emulation-load
  + uefi-dbx: Only list the version in the quirk file key
- Update to version 2.0.4:
  + This release adds the following features:
  - Record the entire USB descriptor in the emulation data
  - Return defined return code when network metadata refresh
    fails
  + This release fixes the following bugs:
  - Add a new private flag of 'delayed-removal' to remove a
    footgun
  - Added a more specific instance ID for qc-s5gen2 USB devices
  - Add fadvise64 to the systemd syscall allowlist
  - Add the Unifying bootloader VID/PID as a full instance ID
  - Allow disabling zero-length packet for modem-manager devices
  - Allow recovering Logitech Bolt receiver in bootloader mode
  - Correctly parse CSV streams without trailing NULs
  - Detect if network is reachable before downloading metadata
  - Disabling reading the OptionROM device after dumping
  - Do not claim kernel interface to avoid Parade downstream port
    resets
  - Do not save BootOrder when measuring system integrity
  - Enumerate child nordic-hid devices correctly
  - Fix a possible critical warning for Mediatek scaler devices
  - Fix Firehose padding for some modem-manager devices
  - Fix UEFI capsule updates when using 4096 byte NVME blocksize
  - Get the Dell dock update package version correctly
  - Never read more of the composite stream from a partial stream
  - Notify snapd about DBX updates
  - Probe sd_mod before starting
  - Properly handle FU_DEVICE_PRIVATE_FLAG_NO_GENERIC_GUIDS
  - Remove the test for CSME 18 manufacturing lock
  - Restore the Logitech compatibility UFY instance IDs
  - Show the correct version when installing a same-device
    composite update
  - Show updates with problems when using 'fwupdmgr get-releases'
  - Split up the AMD GPU VBIOS P/N for the version
  - Use attr USB4_TYPE rather than guessing from
    thunderbolt_domain
  - Use the ISO date as a dbx version number for the Microsoft
    KEK
  - Use the KEK to set the dbx vendor ID
* Thu Jan  9 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.0.3:
  + This release adds the following features:
  - Add a power quirk for Framework systems
  - Speed up writing firmware to the new Dell dock
  + This release fixes the following bugs:
  - Deinitialize DRM after getting GPU marketing name to fix Xorg
    startup
  - Do not show 'Device has been removed' as a dock device error
  - Fix a warning about legion-hid2 progress going backwards
  - Fix some small memory leaks in realtek-mst and dell-kestrel
  - Only mark supported Logitech devices as updatable
  - Parse FDTs with missing END tokens to work on more
    ChromeBooks
  - Reduce the device emulation RSS requirement by ~40%%
  - Skip checking BootXXXX entries when the partition does not
    exist
  + This release adds support for the following hardware:
  - Primax Ryder Mouse
- Changes from version 2.0.2:
  + Add fwupdtool 'get-version-formats' and 'vercmp' commands
  + Add support for checking AMD HW configuration MSR
  + Add support for enumerate-only device emulation to increase
    test coverage
  + Add support for passing a JSON file for emulation instead of
    ZIP
  + Remove support for now-obsolete CSR DFU and Nitrokey devices
- Changes from version 2.0.1:
  + Add API so that gnome-firmware can record devices for emulation
  + Save the emulation-tag devices to the database rather than the
    config file
- Changes from version 2.0.0:
  + Drop legacy signing formats for verification of metadata and
    firmware
  + Reduce the runtime memory usage and CPU startup cost
    significantly
  + Remove all the long-deprecated legacy CLI tools
  + Remove libgusb and GUdev from plugins and use libusb and sysfs
    instead
  + Stream firmware binaries over a file descriptor rather than
    into memory
- Drop harden_fwupd-offline-update.service.patch: offline service
  no longer exists.
- Drop harden_fwupd-refresh.service.patch: merged upstream.
- Drop fwupd-jscSLE-11766-close-efidir-leap-gap.patch: fwupd now
  falls back to ID_LIKE.
- Bump shlib_sover to 3, following upstream.
- Add python3-dbusmock BuildRequires: new dependency.
* Thu Jan  9 2025 Gary Ching-Pang Lin <glin@suse.com>
- Update fwupd-bsc1130056-change-shim-path.patch to correct the
  path for shim.efi
* Mon Dec 23 2024 Callum Farmer <gmbr3@opensuse.org>
- Correct efi_fw_update arch list:
  * Remove ppc64le and s390x - these aren't supported
  * Add armv6hl/armv7hl and riscv64 - support recently added
* Sat Dec 21 2024 tobi.goergens@gmail.com
- Update to version 1.9.27:
  + This release fixes the following bugs:
  - Add a power quirk for Framework systems
  - Allow cros-ec repair the device after flush failure
  - Check the VLI USB3 firmware size before erasing
  - Disallow DBX updates on the Samsung Galaxy Book2 360
  - Do not show 'Device has been removed' as a dock error
  - Do not use a CMSE11 function when using CSME18
  - Fix an unlikely memory leak when using ModemManger Sahara devices
  - Fix a tiny memory leak in algoltek-usb when checking status
  - Mark UEFI dbx updates as affecting full disk encryption
  - Parse FDTs with missing END tokens
  - Rename the dell-k2 plugin to dell-kestrel and rework the update flow
  + This release adds support for the following hardware:
  - Google GID8 Headset
  - Parade PS188
  - Primax Ryder Mouse
- Update to version 1.9.26:
  + This release fixes the following bugs:
  - Add HSI tests for Arrow and Meteor Lake CSME
  - Allow UEFI capsule config values to be set with fwupdmgr modify-config
  - Check for the logitech-bulkcontroller response packet length correctly
  - Fix using ID_LIKE for fallback when ESP isn't mounted
  - Fix various Coverity-reported overflowed constants
  - Only compare the first 10 characters of the AMD GPU part number
  + This release adds support for the following hardware:
  - Jabra PanaCast
  - Some Lenovo Legion HID devices
* Tue Oct 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks (PED-266).
* Mon Oct 14 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Enable plugin_amdgpu: the plugin built succesfully
* Wed Sep 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.25:
  + This release fixes the following bugs:
  - Fix checking new Synaptics MST firmware size
  - Make another ModemManager instance ID visible for firmware
    matching
  - Never set a zero-length device name when matching the vendor
    name
  - Recalculate the device supported flag when reparenting
    devices
  - Reduce idle power consumption of paired logitech-hidpp
    devices
  - Retry the open action to fix BC901 NVMe reload
  + This release adds support for the following hardware:
  - Algoltek devices supporting sector erase
  - Dell K2 dock
  - Intel USB4 hub 5787
  - More MediaTek scaler devices
  - Nordic HID devices supporting DFUv1
* Thu Aug 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.24:
  + This release fixes the following bugs:
  - Add support for capsule on disk for Dell systems
  - Do not re-use the connection cache to fix Redfish BMC restart
  - Exclude known recovery partitions when choosing an ESP volume
  - Fix the VLI usb3 private flag registration
  + This release adds support for the following hardware:
  - More Mediatek scaler devices
  - Parade USB hubs
* Tue Aug  6 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.23:
  + Fix a regression in 1.9.22 that caused some devices not to
    probe correctly.
  + Try harder to get a valid response when flashing usi-dock
    devices.
* Mon Jul 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.22:
  + This release fixes the following bugs:
  - Add a PCB tag in the usi-dock GUID to distinguish different
    revisions.
  - Add explicit hidraw permission to fwupd.service to fix
    several devices.
  - Always load the flashrom plugin when using coreboot.
  - Be explicit with the rts54hub detach retry delay to fix the
    Acer D501.
  - Be more careful when setting thelio-io version strings.
  - Fix a critical warning if a device returns unexpected data
    from DFU upload.
  - Fix a critical warning if the DMI manufacturer is an empty
    string.
  - Fix several reported integer overflows from Coverity.
  - Fix the Blackbird and Talos II baseboard details.
  - Fix transient version number issue after flashing wacom-usb
    devices.
  - Increase the cros_ec acquiesce delay to manage additional
    reboots.
  - Only accept valid ASCII cabinet filenames.
  - Only require udevdir when gudev support is enabled.
  - Only show one PixArt receiver device per physical device.
  - Set the rts54hub version in more cases.
  - Speed up the daemon self tests by ~60%%.
  - Use the bootloader build-timestamp as the fallback HWID BIOS
    version.
  + This release adds support for the following hardware:
  - Framework SD
  - Raspberry Pi 5 (unofficial)
* Fri Jun 14 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Fri Jun 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.21:
  + This release adds the following features:
  - Add a fwupd.conf option to ignore CHID requirements for
    development.
  + This release fixes the following bugs:
  - Allow loading Wacom device flags from metadata.
  - Check for needs-shutdown like we do needs-reboot.
  - Fix updating the Aerox 3 Wireless Mouse.
  + This release adds support for the following hardware:
  - Synaptics Carrera devices.
  - Wacom Movink devices.
* Tue May 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.20:
  + This release adds the following features:
  - Add some API to allow uploading reports for use in
    gnome-firmware
  - Allow the user to upload the entire devicelist to the LVFS
  + This release fixes the following bugs:
  - Correctly detect Synaptics Cayenne and Spyder firmware
  - Do not offer the UEFI DBX update on Lenovo ideacentre
    300-20ISH
  - Explicitly enable shadow stack support in fwupd.service
  - Fix a potential buffer overread when reading the algoltek-usb
    version number
  - Fix the CET HSI test by rewriting it in assembly
  - Fix using --verbose in fwupdmgr
  - Ignore --p2p when downloading the metadata signature
  + This release adds support for the following hardware:
  - FPC FF2 fingerprint devices
* Tue May  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.19:
  + This release adds the following features:
  - Drop heap as part of a housekeeping action.
  - Retry downloads to workaround flaky network connections.
  + This release fixes the following bugs:
  - Assume new ME versions are called CSME.
  - Fix a buffer-overread when parsing invalid CoSWID entity
    data.
  - Fix a logic thinko when parsing GUID strings.
  - Fix downloading files on Windows with libcurl >= 7.77.0.
  - Revert back to a simpler syscall blocklist-based filter.
  + This release adds support for the following hardware:.
  - Acer U32 dock.
  - Luxshare 7-in-1 dock.
  - Pixart models 2404, 4206, 2440, 2418, 2752, 2840 and 2818.
* Mon Apr 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.18:
  + Fix a small memory leak in fwupdmgr.
  + Use simple allow-listing for the syscall filter.
- Changes from version 1.9.17:
  + This release fixes the following bugs:
  - Capture device status changes when in bootloader mode.
  - Change the systemd SystemCallFilter to an allowlist.
  - Detect when a CCGX dock forbids downgrade.
  - Do not add an overly-generic instance ID to CrosEC devices.
  - Do not read OptionROM verification data on Apple hardware.
  - Emit a signal when a user-request is no longer valid.
  - Fix a potential crash when parsing invalid CBOR data.
  - Properly show SPDX project licenses with AND as a delimiter.
  - Verify that syscalls are being filtered correctly at startup.
  + This release adds support for the following hardware:
  - Asus DC201.
  - Realtek Gen1 RTS541x.
* Mon Apr  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.16:
  + This release adds the following features:
  - Prefer zstd over xz for metadata.
  - Relicense a few remaining plugin files to LGPL-2.1+.
  + This release fixes the following bugs:
  - Correctly record UEFI success if adding ESRT nodes.
  - Defer the DP Aux MST scanning on hotplug to workaround a
    kernel bug.
  - Do not do the post-update version check if the device
    needs-reboot.
  - Fix a fastboot warning when loading device.
  - Fix a possible warning in fwupdmgr when excluding releases.
  - Fix a qsi-dock warning when writing chunks.
  - Ignore attribute-changed to work around a regression in
    macOS.
  - Ignore ZFS zvols when finding the default ESP.
  - Mark Pluton TPMs as part of the main CPU.
  - Put the fwupd-efi verbose debugging in the journal.
  - Recognize zfsbootmenu in ESP detection heuristic.
  + This release adds support for the following hardware:
  - Acer T34 and U33 docks.
  - Qualcomm Series 5 Gen 1 and Gen 2 and Series 3 Gen 1 and
    Gen 2 devices.
  - Several Puya SPI chips.
  - VIA VL822 C0.
* Fri Apr  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- dbxtool is built unconditionally on all architectures: move it
  out of the condition in the files section and also
  unconditionally provide/obsolete the old version.
* Tue Mar 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.15:
  + This release adds the following features:
  - Allow loading in parameters for the test device from
    fwupd.conf.
  - Ensure LVFS remotes are changed from .gz to .xz.
  - Store the install duration in the history database.
  + This release fixes the following bugs:
  - Drop OverrideESPMountPoint references in uefi-capsule.
  - Fix a potential double-free when writing AVer firmware.
  - Only request the BOS descriptor when bcdUSB > 0x0200.
  - Use the root device order when sorting device children.
* Tue Feb 27 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.9.14:
  * Correctly detect ARM32 and RISC-V UEFI binaries.
  * Correctly migrate the database schema from very old fwupd versions.
  * Fix DS-20 descriptors by opening the GUsbDevice earlier.
  * Fix updating the fingerprint reader on the Framework 13 and 16 laptop.
  * Fix warning when probing devices using the metadata allowlist.
  * Only recover the version format for specific devices.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.13:
  + This release adds the following features:
  - Add a timer inhibit if the daemon took a long time to
    startup.
  - Add a concept of 'Test Mode' rather than enabling specific
    plugins.
  - Do not idle-quit the daemon if there is a connected D-Bus
    client.
  + This release fixes the following bugs:
  - Allow plugins to opt-out of the child-device first depsolve.
  - Allow setting multiple flags in LVFS::DeviceFlags.
  - Do not migrate config comments for removed keys.
  - Do not request the Advantech BMC to reboot.
  - Do not warn the user about ESP when using MBR.
  - Fix a critical warning when adding a PixArt wireless device.
  - Fix migration of legacy config files.
  - Only save config values to the mutable config file.
  - Parse DS-20 descriptors earlier in device setup.
  - Store the version format in the history database to fix
    offline reports.
  - Use the correct GUID for matching realtek-mst and
    parade-lspcon.
  + This release adds support for the following hardware:
  - GoodWay Acer Dock.
* Wed Jan 24 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.12:
  + This release adds the following features:
  - Add remote modification support to fwupdtool
  - Add support for more modify-config options
  - Generate HTML pages for all man pages
  + This release fixes the following bugs:
  - Assume the legacy LVFS::UpdateRequestId tag is non-generic
  - Avoid crashing the daemon if not using udisks
  - Correctly mark the CPU as supported
  - Correctly match invalid EFI partitions
  - Do not change the device status until the action has
    completed
  - Do not require systemd for fwupdtool modify-config
  - Enable access to the home interface for snap
  - Fix an assertion when enabling lvfs-testing for the first
    time
  - Fix a possible crash in fwupdtool build-cabinet
  - Handle systems with more than one ccp device
  - Only check AMD CPUs for SHSTK, not IBT
  - Only write the mutable fwupd.conf with the current values
  - Re-evaluate supported every time pci-psp attributes are
    refreshed
  - Show "CET OS support" on AMD systems too
  + This release adds support for the following hardware:
  - AVer CAM340plus
  - AVer VB342 Pro
  - More Algoltek devices
* Sat Jan 13 2024 Dennis Tseng <dennis.tseng@suse.com>
- Fix build failure on s390x and ppc64le
  + This release modifies spec file
  - add s390x and ppc64le into default 'with efi_fw_update'
    so that old dbxtool version can be obsoleted.
* Thu Jan  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.11:
  + This release adds the following features:
  - Allow exporting 'offline' reports for manual upload
  + This release fixes the following bugs:
  - Add some recovery partition names to ignore for ESP selection
  - Check for CET and SMAP on non-Intel x86 processors too
  - Correctly mark the CPU as supported in the HSI tests
  - Do not fail on probing downstream Synaptics MST ports
  - Do not offer to change BIOS settings that are already set
  - Do not prefer msftdata when choosing the default ESP
  - Do not show spurious device request flags
  - Fix a missing build dependency to fwupdplugin-self-test
  - Fix a segfault when using zlib-ng instead of zlib
  - Fix updating Jabra 410, 510, 710 and 810 devices
  - Match more community-supported branches
  - Remove the Intel SPIBAR proxy support as the mtd module works
  - Show a better error when the ESP is missing
  - Show an error if the post-update version does not match exactly
  - Speed up Synaptics MST device enumeration
  + This release adds support for the following hardware:
  - Algoltek USB devices
  - Luxshare Quad USB4 Dock
* Wed Dec 20 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_modulesloaddir}: used to be present via udev-mini -> kmod
  - > suse-module-tools dependency before.
* Mon Dec  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.9.10:
  + This release adds the following features:
  - Add support for not_hardware requirements
  - Add support for loongarch64
  - Add support for per-release priority attributes
  - Make USB claim retry count configurable across devices
  + This release fixes the following bugs:
  - Compare the HID report value when checking for duplicates
  - Consider the component priority when installing composite updates
  - Deploy the CCGX firmware correctly the first time
  - Do not export the 'main-system-firmware' and 'cpu' GUIDs
  - Enforce fwupd version requirements client side
  - Fix Genesys 'failed to get static tool info from device' error
  - Fix potential 'dereference before null check' in ccmx-dmc
  - Fix the 'already registered private FuMmDevice flag with value' warning
  - Fix the 'assertion backend_id != NULL failed' runtime warning
  - Fix Wacom USB device emulation by recording the composite phases
  - Generate generic request message text where possible
  - Hide HTTP passwords in fwupd debugging logs
  - Let the client know what interaction is expected
  - Make all critical warnings into backtraces for non-release builds
  - Never obsolete the wrong HSI attribute
  - Never show a HSI index that is impossible
  - Only apply fastboot plugin to modem devices supporting fastboot
  - Only send interactive requests when the sender is alive
  - Remove the now-obsolete Synaptics MST cascade device scanning
  - Replace the Redfish KCS user if required
  - Restrict mediatek-scaler devices on specific hardware only
  - Skip any recovery partitions when detecting ESP
* Tue Nov 21 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.9 (boo#1217295):
  + This release adds the following features:
  - Add a new generic request for the device power cable.
  + This release adds support for the following hardware:
  - Lenovo X1 Yoga Gen7 530E.
  - Advantech BMC devices.
* Thu Nov 16 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Re-add fwupd-bsc1130056-change-shim-path.patch: patch was dropped
  in error (boo#1217138).
* Wed Nov 15 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.8:
  + This release adds the following features:
  - Add a DP AUX device subclass and port the Synaptics MST
    plugin to it
  - Add a feature flag for non-generic requests where
    translations are required
  - Hide generic VID/PIDs to avoid accidental firmware matches
  - Optionally set the modem carrier configuration as the branch
    name
  - Rename 'fwupdmgr sync-bkc' to 'fwupdmgr sync' and also
    consider the branch
  - Require additional requirements for devices using non-OEM USB
    VIDs
  - Set the waiting-for-user status when sending a request
  - Support uSWID SBoM data with LZMA compressed payloads
  + This release adds support for the following hardware:
  - Kinetic SST/MST DisplayPort converters
  - Wacom Cintiq Pros (DTH172, DTH227)
* Thu Nov  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Do not pass -Dsystemd_unit_user=root to meson: use fwupd's
  defautl fwupd_refresh user (boo#1216973).
* Thu Nov  2 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Disable passim support for now. For openSUSE users this is likely
  less intereting that it would be for enterprise customers.
* Wed Nov  1 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to versrion 1.9.7:
  + This release adds the following features:
  - Add support for child device requirements in metadata.
  - Allow to have more than one host BKC.
  - Delete BootNext as a post-reboot action to work around broken
    firmware.
  - Parse cabinet archives internally without libgcab.
  - Use close-ended mode for eMMC FFU to speed up firmware
    updates.
  + This release adds support for the following hardware:
  - Logitech Rally System devices.
  - More PixartRF HPAC devices.
  - More Synaptics Prometheus fingerprint readers.
  - Some Western Digital eMMC devices.
  - VIA VL830 and VL832.
* Fri Oct 20 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.9.6:
  + This release adds the following features:
  - Add a launchd agent for macOS.
  - Add a new security attribute for BIOS capsule updates to be
    enabled.
  - Add functionality to fix specific host security attributes.
  - Add global information from the context into the report data.
  - Add support for coSWID payload sections.
  - Add support for parsing the EDID.
  - Allow adding only-quirk instance IDs from quirk files.
  - Install a sysusers.d systemd file when using
  - Dsystemd_unit_user.
  + For The changes of 1.9.0…1.9.5, please consult
    https://github.com/fwupd/fwupd/releases
- Add pkgconfig(passim) BuildRequires: new dependency.
- Pass -Dplugin_amdgpu=disabled to meson: not buildable just yet.
- Pass -Dlaunchd=disabled to meson: launched is MacOS only.
- Drop -Dplugin_dell=enabled meson parameter: no longer supported.
- Drop fwupd-bsc1130056-change-shim-path.patch: no longer
  applicable.
* Fri Sep 15 2023 Callum Farmer <gmbr3@opensuse.org>
- Remove protobuf-c BR: SLE now matches TW package layout
- Remove gnu-efi BR: efi binary is in fwupd-efi
* Sat Jul 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.17:
  + Correctly obtain the Thunderbolt is_native controller
    attribute.
  + Fix a Wacom emulation failure on s390x.
  + Only allow --force on security attributes for unsupported
    builds.
  + Reduce the amount of RSS by ~12%% at startup.
* Wed Jul  5 2023 Andreas Schwab <schwab@suse.de>
- Enable efi_fw_update on riscv64
- fwupdagent and dfu-tool are only built %%{with efi_fw_update}
* Tue Jun 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.16:
  + Auto-detect the OEM BCM57xx PCI cards with double the available
    EEPROM
  + Beep the console when waiting for user input
  + Do not assume a file descriptor of zero is invalid
  + Fix high memory usage when writing a carefully crafted EFI
    filesystem
  + Ignore refresh on a non-download remote to fix old versions of
    KDE
  + Limit the maximum number of file objects in the EFI filesystem
  + Only add the supported DFU attributes as private flags
  + Show devices with problems in fwupdmgr get-upgrades
  + Update official Intel GPU product names
- Changes from version 1.8.15:
  + Add the latest dbx fixups for BlackLotus
  + Allow fwupd-refresh.timer trigger once per hour
  + Fix a crash when converting HFSTS1 values
  + Fix the version detection for SteelSeries Bluetooth mode
  + Invalidate the XMLb cache when installing new fwupd versions
  + Trigger the passive flow for usb4 from dell-dock
  + New hardware support: More Logitech Unifying receivers, Nordic
    MCUboot and nRF52 Desktop Keyboard
- Changes from version 1.8.14:
  + Fix possible crash when getting UEFI report metadata
  + Fix 'fwupdmgr install FILE GUID'
- Changes from version 1.8.13:
  + New features:
  - Add pcap converter which allows emulating devices from a
    Wireshark dump
  - Add the ability to dump TPM firmware for future use
  - Optionally retain firmware in a backup remote
  - Record the ESP type in the firmware report sent to the LVFS
  + Bugs fixed:
  - Accept application/octet-stream for archives when the mime
    database is missing
  - Add the latest dbx version version fixups as Microsoft
    removed another entry
  - Assume DFU appIDLE if GetStatus is not implemented
  - Do not require signatures for local or directory remotes
  - Do not use pandoc to build the man pages
  - Enhance Qubes functionality to use JCat
  - Fix a CCGX 'usbfs: process did not claim interface 1 before
    use' warning
  - Fix a compile warning when using a new libqmi version
  - Fix a critical warning when parsing an empty kernel cmdline
  - Fix a synaptics-cape regression where the firmware pauses for
    INTR
  - Fix the defines for HFSTS6 enforcement policy
  - Fix the i2c name properly for ElanTP hardware
  - Fix the name of the MTD Intel SPI controller
  - Set the release remote when installing archives
  - Use the powerd power type information to better set AC levels
  + New hardware:
  - Framework Audio Card
  - Lenovo ThinkPad TBT3-TR Gen 2
  - Wacom Intuos BT S Gen 3
- Update options passed to meson following upstream changes.
* Fri Mar 10 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Introduce docs flag, set to 0: do not build documentation using
  pandoc: ghc is not part of the rings and we don't want this
  there.
* Thu Mar  2 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.8.12:
  + Allow setting the package user agent before the client has
    connected.
  + Fix a small memory leak when refreshing metadata.
- Changes from version 1.8.11:
  + Add support for replaying USB devices so they can be emulated
    in CI.
  + Allow desktop software to inhibit the system to prevent
    updates.
  + Allow using requirements with depth=0 and no parent.
  + Auto-set the CCGX remove-delay now we parse DMC subcomponents.
  + Detect and warn users with the broken NVMe firmware 3B2QGXA7.
  + Print errors as JSON objects when using fwupdmgr --json.
- Changes from version 1.8.10:
  + Add a PE/COFF firmware parser to allow reading coSWID SBoM
    data.
  + Allow dumping CFI SPI chips using devices like CH341a.
  + Refactor the HWIDs functionality to include FDT data.
- Rebase fwupd-bsc1130056-change-shim-path.patch.
- Drop uefi-capsule-Do-not-call-grub2-probe-without-argumen.patch:
  fixed upstream.
- Add -Dcompat_cli=true meson parameter: keep compat binaries for
  the time being.
- Add xz-devel BuildRequires: needed to link liblzma.
* Wed Jan 18 2023 Michal Suchanek <msuchanek@suse.com>
- Fix error generating grub.cfg when an update is available.
  + uefi-capsule-Do-not-call-grub2-probe-without-argumen.patch
* Wed Jan  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.9:
  + This release adds the following features:
  - Add an interactive request for re-inserting the USB cable
  - Add SHA384 support for TPM hashes
  - Add X-FingerprintReader, X-GraphicsTablet, X-Dock and X-UsbDock categories
  - Allow specifying OR parent requirements in metadata
  + This release fixes the following bugs:
  - Add the fwupd version to the HSI result if the chassis is invalid
  - Allow getting the ESP when there is a block device with no filesystem
  - Allow reinstalling on devices with only-version-upgrade set
  - Do not require the TPM event log to have all reconstructions
  - Fix a tiny memory leak when parsing signed reports
  - Ignore failure to mount the ESP if unsupported
  - Never allow using SHA-1 for checksum validation
  - Return a more useful error if USB recovery failed
  - Skip the fwupdx64.efi BootXXXX entry when measuring system integrity
  - Speed up daemon startup using prepared XPath queries
  - Suggest to turn on ThunderboltAccess for Lenovo systems
  - Use better defaults if the config file is missing
  + This release adds support for the following hardware:
  - More Solidigm NVMe devices
  - More Synaptics Cape devices
  - More Synaptics Prometheus devices
  - Most Texas Instruments USB-4 docks
  - Scaler support for Wacom USB devices
  - Several new Wistron USB-C docks
* Mon Dec 26 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.8:
  + This release adds the following features:
  - Add BIOS rollback protection support for Dell and Lenovo
    systems
  - Generate OVAL rules for openSCAP evaluation
  - Show the signed reports from QA teams in client tools
  + This release fixes the following bugs:
  - Add a X-Gpu category for new hardware support
  - Add more ChromeOS metadata to the report attributes
  - Ensure the device name is set for Intel USB4 devices
  - Fix a critical DFU CSR warning when deploying firmware
  - Fix a Synaptics RMI issue when updating non-secure devices
  - Match more device properties when using GetDetails
  - Move AMD platform rollback protection to level 4
  - Use the correct AppStream ID for the Key Manifest failure
  - Wait for the Intel GPU to come back after updating
  + This release adds support for the following hardware:
  - Logitech Whiteboard cameras
  - More Goodix MoC devices
  - Several QSI Docks
* Thu Nov 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.7:
  + This release adds the following features:
  - Add a new HSI check for the leaked Lenovo 'Key Manifest'
    hashes
  - Measure system integrity when installing UEFI updates
  - Record more host DMI data when submitting a report for dbx
    failures
  - Use xz-compressed metadata to reduce bandwidth used by ~25%%
  + This release fixes the following bugs:
  - Add documentation for three existing HSI attributes
  - Add re-insert requirement for Analogix devices
  - Allow parsing metadata more than 1MB in size
  - Do not follow symlinks when searching for ESP devices
  - Ensure the config file permission is correct for built-in
    plugins
  - Fix a compile failure when compiling without efiboot
  - Fix a regression when using fwuptool install-blob with FMAP
    firmware
  - Only count the Microsoft hashes when getting the dbx version
  - Only use the IFD when the system is Intel-based
  - Support loading CoSWID when only one role has been set
  + This release adds support for the following hardware:
  - Anker Thunderbolt 4 Mini Hub
  - ELAN haptic hardware
  - Fingerprint lenfy devices
  - Goodix GF3258WNC
  - Intel discrete GPUs (experimental)
  - More Star Labs laptops
  - QSI Godzilla Creek Reference Hub
- Stop passing conditional plugin_amt=disabled, no longer needed,
  nor recognized.
* Thu Nov  3 2022 Tseng <dennis.tseng@suse.com>
- For pushing fwupd-1.8.6 to 15-SP5 (fwupd-1.7.3), sync change log:
  (jsc#PED-1232)
  - fwupd-bsc1193921-nvme-ignore-non-PCI-NVMe-devices.patch
    be merged to fwupd-1.7.3
* Fri Oct 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.6:
  + This release adds the following features:
  - Reduce the installed package size by more than 30%%
  - Translate more interactive messages
  + This release fixes the following bugs:
  - Allow disabling a DFU device when required
  - Fix a regression when getting the i2c bus number
  - Fix a small memory leak when reloading the parade-lspcon
    device
  - Fix installing the dbx update when using fwupdtool
  - Improve writing CoSWID and uSWID metadata
  - Only include the last 5 releases in the installed metainfo
    file
  - Only request the BOS descriptor for newer libgusb versions
  - Prevent high memory usage when loading corrupt SREC files
  - Try harder when trying to find the default ESP volume
  - Use a higher compression preset for the UEFI splash images
  + This release adds support for the following hardware:
  - Focaltech touchpads
  - FPC fingerprint readers
  - Supermicro machines using Redfish
- Drop plugin_sover define, and sub-packages libfwupdplugin7 and
  typelib-1_0-FwupdPlugin-1_0 following upstream changes.
* Fri Sep 30 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.8.5:
  + This release adds the following features:
  - Add a new android-boot plugin to update specific block
    devices
  - Add new plugin to display SMU firmware version on AMD APU/CPU
  - Add support for platform capability descriptors so devices
    can set quirks
  - Move the generic Intel Goshen Ridge code out to a new plugin
  + This release fixes the following bugs:
  - Allow specifying the ESP when applying the dbx update
  - Always check the BDP partitions when getting all the possible
    ESPs
  - Correctly update Wacom AES devices
  - Disable changing sleep mode on Ryzen 6000 systems
  - Do not show the 'may not be usable while updating' message
    for DBX updates
  - Expose Pine64 PinePhone Pro MTD as Tow-Boot
  - Fix a critical warning when issuing Secure Boot modem AT
    commands
  - Fix a fuzzing crash when parsing malicious FDT data
  - Fix aligning up addresses greater than 4GB
  - Fix a possible crash when dumping VBE firmware
  - Fix a possible critical warning when parsing cabinet archives
  - Fix a regression when parsing pixart-rf firmware
  - Fix a small memory leak when parsing UF2 files
  - Fix checking for invalid depth requirements
  - Fix parsing the coSWID firmware ID when encoded as a UUID
  - Fix parsing uSWID uncompressed metadata
  - Fix uploading to DFU-CSR devices
  - Limit the archive size to 25%% of the RAM, or 4G
  - Load coSWID metadata from a uSWID MTD block device
  - Never save the Redfish auto-generated password to a
    user-readable file
  - Only create users using IPMI when we know it's going to work
  - Write all the CCGX metadata block as intended
  + This release adds support for the following hardware:
  - Corsair SABRE RGB PRO Gaming mouse
  - More Sonix CAM devices
  - More Intel Goshen Ridge USB-4 docks
- Changes from version 1.8.4:
  + This release adds the following features:
  - Add a translated title and long description for HSI security
    attributes
  - Add support for loading a machine-default BIOS settings
    policy
  - Add support for reading and writing BIOS settings
  - Allow loading BIOS settings for host emulation
  - Prompt users to fix some BIOS configuration issues
  + This release fixes the following bugs:
  - Actually show provided AppStream security issues
  - Add Quectel secure boot status AT commands
  - Correctly detect CET IBT
  - Do not assert when running with no plugins
  - Do not require UEFI capsule updates for checking TPM PCR0
  - Do not show HSI events where we changed the spec result value
  - Fix applying the latest DBX update
  - Include vfat in the list of possible BDP partition types
  - Install all devices with the same composite id in fwupdtool
  - Only fail the kernel HSI test for specific taint reasons
  - Only show changed events in fwupdmgr security
  - Update vulnerable CMSE versions from CSMEVDT data
  + This release adds support for the following hardware:
  - Elan non-HID touchpads
  - Google Prism
  - LabTop Mk III
  - ThinkPad Thunderbolt 4 Dock
  - ThinkPad Universal Smart Dock
- Changes from version 1.8.3:
  + This release adds the following features:
  - Add resolution flags to each security attribute failures for
    the user
  - Allow loading in emulated host profiles for debugging
  - Check if Intel TME has been disabled by the firmware or
    platform
  - Wait for the system to acquiesce after doing each update
  + This release fixes the following bugs:
  - Do not use CoD even when advertized on non-aarch64 platforms
  - Fix a crash when updating the Logitech Bolt radio device
  - Fix a critical warning when parsing an invalid PHAT record
  - Fix a critical warning when parsing invalid FDT firmware
  - Fix fwupdmgr security when plugins are added to the blocklist
  - Fix parsing SMBIOS data to correct the device hardware IDs
  - Fix uploading signed reports by sending the correct checksum
  - Use the correct protocol attribute name when exporting to
    JSON
  + This release adds support for the following hardware:
  - Additional Startech devices
  - Additional Elan fingerprint readers
- Changes from version 1.8.2:
  + This release adds the following features:
  - Add startup profiling which allowed us to speed up daemon
    startup considerably
  - Add support for OptionROM, CPD and FPT firmware formats for
    future hardware
  - Add the HostVendor to the D-Bus interface
  - Break some internal ABI and add a conversion helper for
    out-of-tree plugins
  - Optionally build the quirk files into the daemon binary to
    reduce installed size
  + This release fixes the following bugs:
  - Allow front-end clients to read the percentage property
  - Allow more quirk entries to add multiple items
  - Allow to force install Genesys firmware even if the
    public-key does not match
  - Allow UFS disks to define the signed status in metadata
  - Autoconnect the Redfish network device when rebooting the BMC
  - Copy the instance ID strings when incorporating devices
  - Do not generate a capsule header for the FMP GUID
  - Ensure more firmware formats can round-trip to and from XML
  - Fix a regression for devices using the Atmel FLIP Bootloader
  - Fix running fwupdtool security with a user-specified plugin
    allowlist
  - Handle ENOTTY with the correct error code for ioctl calls
  - Increase the self tests coverage substantially
  - Modernize the AMT plugin and split out common MEI
    functionality
  - Only move the logitech-bulkcontroller progressbar forwards
    when writing
  - Set the device ID on the FwupdRequest to allow better UX
  - Show the get-details output when the device requirements fail
  - Simply quirk matching for i2c devices to speed up daemon
    startup
  - Support SHA256 fastboot hashes if specified
  - Use force-detach to bypass the DFU streaming check for camera
    devices
  - Use the SCSI target to correctly set the physical ID
  - Wait for the System76 launch device to re-enumerate if
    already unlocked
  + This release adds support for the following hardware:
  - Corsair HARPOON RGB Wireless mouse
  - U-Boot devices writing simple FIT images
  - Genesys M27fd AIM101
  - More PixArt wireless devices
  - More Steelseries HID, Sonic and Fizz devices
  - System76 launch_2
- Changes from version 1.8.1:
  + This release adds the following features:
  - Add archive writing support for devices with composite
    firmware
  - Add a way to read device composite firmware in fwupdtool
  - Allow clients to opt-in to showing updates with user-solvable
    problems
  - Allow the device to pause polling when writing firmware
  - Export the system and device battery levels on the D-Bus
    interface
  - Log errors and warnings to the win32 eventlog when required
  - Add X-UsbReceiver as an update category with icon
    usb-receiver
  + This release fixes the following bugs:
  - Accurately return the last-set status to client tools
  - Allow dumping flashrom firmware using fwupdtool
  - Allow specifying a non-file D-Bus transport
  - Allow to request post actions from fwupdtool
  - Always be arch-explicit when installing OS deps
  - Be more resilient when restarting the Redfish BMC
  - Do not mark all Redfish updates as UPDATABLE
  - Do not use 'dongle' to describe USB receiver hardware
  - Download in-process when using fwupdtool
  - Fix a critical warning on failed modem update
  - Fix regression when probing PS175 devices
  - Hardcode the Redfish filedata name to firmware.bin
  - Set the Bluetooth version if REV has been set
  - Switch the Windows installer from NSIS to MSI
  - Use StartServiceCtrlDispatcherA for the daemon on Windows
  - Use the native certificate store on Windows
  + This release adds support for the following hardware:
  - Corsair KATAR PRO XT, SABRE PRO and KATAR PRO Wireless
  - HP Thunderbolt Dock G4
  - Lenovo ThinkPad Universal USB-C Dock
  - More PixArt wireless devices
  - More SunplusIT USB cameras
  - Some UFS devices
  - Steelseries Aerox 3 Wireless and Rival 3 Wireless
- Changes from version 1.8.0:
  + This release adds the following features:
  - Add a new attribute for CPUs supported by HSI
  - Add coSWID and uSWID parsers to libfwupdplugin for initial
    SBoM support
  - Add new HSI attributes for the AMD PSP and various other
    system protections
  - Add the runtime fwupd-efi version as a firmware requirement
  - Allow 'fwupdmgr install' to install a specified firmware
    version
  - Allow overriding the detected machine type for debugging and
    development
  - Restart the BMC after installing BCM updates
  - Show the device serial number and instance IDs by default
  - Support dumping the MTD image to a firmware blob
  - Take a device inhibit when updating a device
  - Use the CFI manufacturer ID to set the vendor
  - Use the correct icon automatically for more hardware
  + This release fixes the following bugs:
  - Add signed-payload metadata for more devices
  - Allow Capsule-on-Disk to work in more cases
  - Allow quirking the detected flashrom flash size
  - Check for os-release on FWUPD_SYSCONFDIR
  - Check the alignment when parsing raw firmware
  - Check the update protocol exists when checking requirements
  - Convert the build system to use meson tristate features
  - Correctly probe USB-2 hubs with more than 7 ports
  - Do not add the Windows compatibility ID to capsule devices
  - Do not allow the DBX update for specific motherboards
  - Do not expect KernelCmdline on Windows
  - Do not export USB4 host controllers as updatable if they
    don't have unique GUIDs
  - Do not fallback to audio-card and use a more suitable icon
    for USB hubs
  - Do not hardcode the libexecdir to /usr/libexec
  - Do not leak child processes when canceling
  - Do not show unconnected or unreachable devices in the client
    tools
  - Do not throw away the TPM eventlog when uploading to the LVFS
  - Do not use /var/run for the socket
  - Export the version_lowest_raw value correctly
  - Fix build for MacOS and add to the CI matrix
  - Fix eventlog replay for Intel TXT machines
  - Fix several small memory leaks
  - Fix writing large mtd images than 10kb
  - Ignore MTD devices that report EPERM on open
  - Mark the ME region device locked if it is read only
  - Never send the DeviceChanged signal with old data
  - Only show the CLI time remaining for predictable status
    phases
  - Respect the NO_COLOR env variable
  - Return the correct error when there is no GPIO device to open
  - Support the new UPower PENDING device states
  + This release adds support for the following hardware:
  - CH341A SPI programmer
  - Corsair Sabre RGB PRO and Slipstream USB receiver
  - Genesys GL3521 and GL3590 hubs
  - Google Servo Dock
  - Logitech M550, M650 and K650
  - More ELAN fingerprint readers
  - More integrated Wacom panels
  - More NovaCustom machines
  - More StaLabs StarLite machines
  - More Tuxedo laptops
  - Quectel EM05
  - FlatFrog devices
  - System76 launch_lite_1
- Rebase patches with quilt.
- Use ldconfig_scriptlets macro for post(un) handling.
- Add shlib_sover define and set it to 2, ease future updates.
- Add plugin_sover define and set it to 7, ease future updates, and
  rename libfwupdplugin5 to libfwupdplugin7 following upstream
  changes.
- Drop gtk-doc and pkgconfig(gtk-doc) BuildRequires: No longer
  needed nor used. Following this, stop passing docs=gtkdoc to
  meson, no longer recognized.
- Add pkgconfig(gi-docgen), pkgconfig(libcbor), pkgconfig(mm-glib),
  pkgconfig(mbim-glib), pkgconfig(qmi-glib) and
  pkgconfig(umockdev-1.0) BuildRequires, and conditional
  pkgconfig(flashrom) BuildRequires: New dependencies.
- Update options passed to meson following upstream changes.
- Replace false for plugin_nvme and plugin_redfish with enabled,
  build nvme and redfish plugins.
- Split out developer/api docs in new doc sub-package, add fdupes
  BuildRequires and macros, remove duplicates.
* Thu Sep 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.7.10 (CVE-2022-3287, boo#1203852):
  + Always check the BDP partitions when getting all the possible
    ESPs
  + Correctly detect CET IBT
  + Do not show HSI events where we changed the spec result value
  + Fix aligning up addresses greater than 4GB
  + Fix applying the latest DBX update on machines with
    20200729.x64 installed
  + Fix checking for invalid depth requirements
  + Fix getting the new version number of the USI docking hardware
  + Fix HSI prefix for invalid chassis
  + Never save the Redfish auto-generated password to a
    user-readable file (CVE-2022-3287, boo#1203852).
  + Only create users using IPMI when we've tested the hardware
  + Only fail the kernel tainted HSI test for specific taint
    reasons
  + Only show changed events in the fwupdmgr security output
  + Recognize CSME version 16 and update vulnerable versions from
    CSMEVDT data
  + Write all the CCGX metadata block as intended
* Mon Aug  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.7.9 (boo#1201311):
  + Do not generate a capsule header for the FMP GUID.
  + Do not use CoD even when advertized on non-aarch64 platforms.
  + Fix a critical warning when parsing an invalid PHAT record.
  + Fix a regression for devices using the Atmel FLIP Bootloader.
  + Fix parsing SMBIOS data.
  + Set the device ID on the FwupdRequest.
  + Use the correct protocol member when converting to JSON.
  + Wait for the system76-launch device to re-enumerate if unlocked
    and reset.
- Changes from version 1.7.8:
  + Add the bootloader VID/PID used for the first batch of ColorHug
    devices.
  + Also check for os-release in SYSCONFDIR.
  + Export the version lowest raw value correctly.
  + Fix a Wacom timeout when parsing very corrupt firmware.
  + Fix Genesys device enumeration failure by not claiming the
    interface.
  + Hardcode the Redfish filedata name to firmware.bin.
  + Install D-Bus introspection data even if introspection is
    disabled.
  + Only set the flashrom BIOS size if not already quirked.
  + Read the SynapticsMST firmware size in a more safe way.
  + Restart the BMC after installing BCM updates.
* Sun Apr 17 2022 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.7.7:
  * This release adds the following features:
    + Add CCGX trigger code to support future hardware
    + Add signed and unsigned payload metadata to more devices
    + Allow overriding the detected machine type
    + Allow quirking the flashrom flash size
    + Do not allow the DBX update for broken firmware versions
  * This release fixes the following bugs:
    + Do not add the backup BMC device as it shares the same GUIDs
    + Do not hardcode the libexecdir to /usr/libexec
    + Do not leak child processes when canceling
    + Do not throw away the TPM eventlog when uploading reports to
    the LVFS
    + Don't export USB4 host controllers if they do not have unique
    GUIDs
    + Fix build for MacOS
    + Fix the TPM eventlog replay for Intel TXT machines
    + Fix writing large MTD images
    + Never send the DeviceChanged signal with invalid data
    + Return the correct error when there is no GPIO device to open
    + Show the update message and update image in front end tools
    + Support the new PENDING upower device states
  * This release adds support for the following hardware:
    + Logitech M550, M650 and K650
    + More Elan fingerprint readers
    + More Star Labs StarLite laptops
    + More Wacom panels found on Lenovo laptops
- Split bash and fish completions to separate subpackages
- Remove un-needed BRP_PESIGN_FILES
- Set GNU_SOURCE so meson detects F_OFD_SETLK in fnctl.h support
* Fri Feb 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.7.6:
  * This release adds the following features:
    + Add a flag for UEFI devices that never want a capsule header
    auto-added
    + Add a flag to indicate the device has a signed or unsigned
    payload
    + Add a plugin to set a GPIO pin for the duration of an update
    + Add a simple plugin to enumerate (but not update) SCSI
    hardware
    + Add two more instance IDs to the MTD devices
    + Add X-BaseboardManagementController as an update category
    + Allow assigning issues to devices for known high priority
    problems
    + Parse the MTD firmware version using the defined GType
  * This release fixes the following bugs:
    + Check the IFD sections have non-zero data length to fix a
    critical warning
    + Modify the AT retry behavior to fix getting the firmware
    branch
    + Do not run fwupd-refresh automatically in containers
    + Do not show a warning if the TPM eventlog does not exist
    + Do not show TSS2 warning messages by default
    + Fix a critical warning when loading an empty TPM eventlog
    item
    + Fix a logic error when adding the community warning in
    fwupdmgr
    + Fix loading flashrom devices in coreboot mode
    + Fix the error handling when updating USB4 retimers
    + Show the user when devices are not updatable due to inhibits
    + Skip probing the Dell DA300 device to avoid a warning
    + Try harder to convert to a version into a correct semver
    + Use multiple checksums when there are no provided artifacts
  * This release adds support for the following hardware:
    + HP M2xfd monitors
    + Star Lite Mk III
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.7.5:
  * This release adds the following features:
    + Add a flag to indicate the firmware is not provided by the
    vendor
    + Add support for showing dependency versions in JSON format
    + Allow fwupd to operate in socket mode without a D-Bus daemon
    + Allow marking a device as End-of-Life by the OEM vendor
    + Allow specifying the machine Best Known Configuration locally
    + Fall back to the ARM Device Tree 'compatible' data when
    required
  * This release fixes the following bugs:
    + Be more robust by retrying IPMI transactions on servers
    + Change the expired Redfish password when required
    + Fix a ModemManager segfault on startup for some MBIM-QDU
    devices
    + Fix a possible dell-dock segfault at startup
    + Fix compiling with new versions of efivar
    + Fix the Nordic bootloader type detection
    + Fix USB4 retimer enumeration
    + Get the SMBIOS table and host machine ID when running on
    Windows
    + Show results when calling get-details if failing requirements
    + Uninhibit the modem using ModemManager after upgrade
  * This release adds support for the following hardware:
  + Future Analogix devices
  + NovaCustom NV4x
- Changes from version 1.7.4 (bsc#1193921):
  * This release adds the following features:
    + Add firmware branch support for ModemManager devices
    + Allow firmware engineers to patch files at known offsets
    + Show why more devices are not marked as updatable
  * This release fixes the following bugs:
    + Allow fwupdtool to be run as the non-root user in more cases
    + Assign the Logitech bulkcontroller update interface correctly
    + Do not allow UEFI updates when the laptop lid is closed
    + Do not autoload ipmi-si to avoid warning on non-server
    hardware
    + Do not show a critical warning for a weird TPM event log
    + Fix waiting for USB devices when using Windows
    + Ignore non-PCI NVMe devices
  * This release adds support for the following hardware:
    + HP USB-C G2 Dock
    + Many UF2 devices, experimentally
    + More PixArt devices
    + Nordic HID devices using MCUBoot
    + Quectel EG25-G LTE Modem
    + ThinkPad Thunderbolt 4 Dock
* Tue Dec 21 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.7.3:
  * This release adds the following features:
    + Add a sync-bkc subcommand to ensure a known set of firmware
    versions
    + Add FuArchiveFirmware for plugins that use archives as
    firmware files
    + Add quirkable page and sector size properties to FuCfiDevice
    + Make Upower and powerd support optional
  * This release fixes the following bugs:
    + Add some sanity checks to the elanfp firmware parser
    + Add the CFI JEDEC instance ID if using the vendor-extended
    version
    + Check the value range when parsing the quirk keys
    + Do not wait for a USB runtime if will-disappear is set
    + Enable the MOTD integration when using pam_motd
    + Fix DFU regression when merging the FuProgress work
    + Fix running the tests when fwupd is not installed
    + Fix the GLib error message when inotify max_user_instances is
    too low
    + Fix VLI VL820Q7 detection to fix flashing of the Lenovo TBT3
    dock
    + Ignore a USB error for STM32 attach when the device goes away
    + Make the HSI tests optional for embedded targets
    + Make the plugin startup order deterministic
    + Set Thunderbolt ports offline on host controller
    + Use endian-safe version functions when enumerating Logitech
    hardware
    + Use lowercase flag names in intel-spi to prevent a runtime
    warning
    + Wait for the System76 Launch device to come back from DFU
    mode
  * This release adds support for the following hardware:
    + Most Nordic Semiconductor nRF Secure devices
- Fix build when not on TW: add BR protobuf-c
* Fri Dec 10 2021 Hans-Peter Jansen <hpj@urpla.net>
- Fix build issue in spec
  (references to libfwupdplugin2 -> libfwupdplugin5)
* Fri Nov 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.7.2:
  * This release adds the following features:
    + Add a new HSI check that PCR registers 0-7 are not empty
    + Add several compile flags to reduce the install size by over
    300Kb
    + Allow overriding HwId data from the daemon.conf config file
    + Allow overriding the firmware GType from a quirk file
    + Export the component release ID over DBus
    + Remove support for the SoloKey and ChaosKey devices
    + Show a daemon warning if quirk flags are malformed
    + Speed up the daemon startup by ~40%% by doing less at startup
  * This release fixes the following bugs:
    + Be case insensitive when fixing the device model
    + Fix a critial warning in ccgx found by the fuzzer
    + Fix a DFU crash if the attach failed due to a hardware fault
    + Fix a Redfish crash when specifying a URL without a port
    + Fix CLI downloads when using fwupdmgr --ipfs
    + Fix critical warning when /etc/machine-id does not exist
    + Inhibit thunderbolt devices to correctly use UPDATABLE_HIDDEN
    + Set SSL_VERIFYHOST=0 when using Redfish to fix OpenBMC auth
    + Skip UEFI devices that fail coldplug
  * This release adds support for the following hardware: All
    exported MTD block devices
- Changes from version 1.7.1:
  * This release adds the following features:
    + Allow specifying 'fwupdmgr device-test foo --json' for
    unattended testing
    + Allow using a filename when using set-approved-firmware
    + Inhibit ModemManager device in mbim-qdu
    + Share the Common Flash Memory Interface quirks between
    plugins
    + Show changes in HSI attributes when using 'fwupdmgr security'
    + Show the user a warning if updating may affect
    full-disk-encryption
    + Show translated firmware release notes when provided
    + Support loading remotes from /var/lib/fwupd/remotes.d
  * This release fixes the following bugs:
    + Fix a CCGX regression when loading firmware
    + Fix a potential crash when dumping Parade devices
    + Fix build error when sys/io.h is not available
    + Fix building the Synaptics RMI self tests on s390x
    + Fix the CSME CVE detection for new generations
    + Handle EPERM when running the self tests on systems with IPMI
    + Mark as SUPPORTED even if on battery power
    + Only save the HSI attributes to the database if different
    + Raise the client timeout value from 25 seconds to fix Redfish
    startup
    + Redirect the old HSI links to the correct place
    + Relax the ITE SuperIO signature checks for new hardware
    support
    + Set device time and timezone for logitech bulkcontroller
    devices
    + Set the verfmt of the returned device when the daemon device
    is unset
  * This release adds support for the following hardware:
    + Dell Atomic Dock
    + HP Thunderbolt Dock G4
    + More PixArt devices
    + Steelseries Stratus
    + Wacom 3rd-gen Intuos BT
- Changes from version 1.7.0:
  * This release adds the following features:
    + Add FuCfuPayload and FuCfuOffer for future usage
    + Add support for an 'unreachable' device flag
    + Add support for Logitech devices supporting the Unified
    Battery feature
    + Allow adding GUIDs to each HSI security attribute
    + Allow installing the LVFS remote, but with it disabled by
    default
    + Convert security attributes to JSON and write then to the
    database
    + Convert the device test script to a fwupdmgr subcommand
    + Create Redfish user accounts automatically using IPMI
    + Use an interactive request to restart some Logitech DFU
    devices
  * This release fixes the following bugs:
    + Abort on invalid SREC files early to avoid a fuzzing timeout
    + Allow using interrupt transfers for HID devices
    + Allow waiting for multiple devices to replug
    + Fix a critical warning on a Unifying flash failure
    + Fix a regression in flashing the Dell dock
    + Fix Thunderbolt host controller probing
    + Forcefully set checksums found in cabinet files to lowercase
    + Force UX-capsule over full size BGRT
    + Make the SuperIO ports and timeouts specific to the DMI model
    + Only probe SynapticsMST devices that have opted-in
    + Remove support for --ignore-power as it did not work for UEFI
    firmware
    + Reset the CMOS as required when changing system firmware
    branch
    + Restart the daemon if any of the the plugin config files are
    modified
    + Show HSiLevel=0 attributes in JSON security output
    + Update the child composite ID if the parent changes
    + Use a per-device global percentage completion
    + Write the BMP image upside down to avoid using a negative
    bitmap height
  * This release adds support for the following hardware:
    + A huge number of Synaptics CAPE devices
    + Elan fingerprint readers
    + Logitech Bolt peripherals, receivers and radio hardware
    + Logitech devices supporting the bulk controller protocol
    + More supported PixArt devices
    + More supported StarBook coreboot devices
    + Union Point SPI hardware
- Add pkgconfig(libprotobuf-c) and pkgconfig(protobuf)
  BuildRequires: New dependencies.
- Refresh patches with quilt.
- Drop sub-package fwupdtpmevlog, no longer built.
- Update URL in _service, new home.
* Fri Nov 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.4:
  * Allow overriding the quirks directory at runtime
  * Fix a regression in flashing the Dell dock
  * Fix probing the Dell TPM
  * Show HSiLevel=0 attributes in JSON security output
  * Abort on invalid SREC files early to avoid a fuzzing timeout
  * This release adds support for the following hardware:
    + AVer ATLAS CAM/CAM520 Pro2
    + Cayenne/Spyder Synaptics MST
    + VL819 USB devices
- Changes from version 1.6.3:
  * This release adds the following features: Fall back to the
    parent if the child does not have a battery level set
  * This release fixes the following bugs:
    + Disable the uefi_capsule plugin if Redfish coldplug succeeded
    + Fix an elantp crash when starting the daemon
    + Fix compiling with old versions of libxmlb
    + Fix detection of 8Bitdo wireless usb adapter
    + Fix the 8bitdo N30 Pro 2 install duration
    + Fix the modem-manager report that failed to get device after
    update
    + Fix writing large redfish firmware files
  * This release adds support for the following hardware:
    + Poly Studio P21
    + Realtek RTD2141B
- Switch service to obs_scm, and recompress to buildtime.
- Drop automatic changesgenerate, upstream have perfectly fine and
  human understandable release notes at
  https://github.com/fwupd/fwupd/releases that should be copied
  into .changes.
* Wed Nov 17 2021 jlee@suse.com
- Add requires to udisks2 for dbxtool update. (bnc#1192344)
* Fri Nov  5 2021 Dominique Leuenberger <dimstar@opensuse.org>
- If the machine we install onto has shim installed, it is likely
  an EFI based system. Require fwupd-efi in this case
  (boo#1192206).
* Fri Nov  5 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Require libfwupdplugin2 by the -devel package: the -devel package
  installs the .so symlink, thus we must guarantee the target
  library to be present.
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_fwupd-offline-update.service.patch
  * harden_fwupd-refresh.service.patch
* Thu Oct  7 2021 Joey Lee <jlee@suse.com>
- Update to version 1.6.2
  - The fwupd efi program be separated to fwupd-efi package.
  - Removed pesign-obs-integration, moved needssslcertforbuild
    , SBAT and EFI signing stuff to fwupd-efi.
  - Moved libfwupdplugin1 to libfwupdplugin2
- Change log from upstream:
  https://github.com/fwupd/fwupd/blob/main/data/org.freedesktop.fwupd.metainfo.xml
  - This release adds the following features:
  * Add a plugin to check Lenovo firmware settings
  * Add initial support for the powerd daemon
  * Add support for CapsuleOnDisk
  * Add support for installing UEFI updates from GRUB
  * Add support for soft-requirements that can be ignored with --force
  * Allow devices to only accept version upgrades
  * Allow discovery of Redfish BMCs specified by VID-PID or MAC
  * Allow the daemon to request interactive action from the end user
  * Automatically connect the BMC network interface at startup
  * Show the build timestamp if set on the device
  * Show the user how to switch out of Wacom tablet Android-mode
  - This release fixes the following bugs:
  * Add the alternate vendor name into the 8BitDo allowlist
  * Allow multiple devices to set WAIT_FOR_REPLUG
  * Allow the client to watch for more property changes
  * Always ensure the SuperIO version string is NUL terminated
  * Automatically clear the update error as required
  * Disable all UX capsules for Lenovo hardware
  * Do not assume the metainfo file is NUL-terminated
  * Do not save invalid files on LVFS server error
  * Fix a VLI regression in enumerating the PD device
  * Fix a VLI regression when installing VL820Q7 firmware
  * Fix enumeration of the Synaptics Prometheus config child
  * Fix parsing Redfish USB/PCI network VID/PIDs
  * Fix the fwupdmgr progressbar spinner to actually work
  * Fix version number for legacy Wacom Bluetooth modules
  * Ignore virtual M.2 ATA devices
  * Preserve NEEDS_REBOOT on successful update
  * Prevent a corrupt PHAT table from allocating lots of memory
  * Read the Redfish SMBIOS table when required
  * Remove the vendor string from the device name where required
  * Save the update state to the database correctly all of the time
  * Switch from sysctl to ioctl for ESRT on FreeBSD
  * Try reading from /sys/class/dmi if SMBIOS direct access fails
  * Watch for children added or removed after setup has been completed
  * Work around a XCC-ism on Lenovo hardware
  - This release adds support for the following hardware:
  * ModemManager devices supporting Firehose or MBIM QDU
  * More models of RTS54HUB
  * More Poly DFU devices
  * Parade LSPCON
  * PixArt receiver and wireless hardware
  * Realtek MST with RTD2142
  * SuperIO IT5570
  * USB4 Dell dock
* Thu Apr  1 2021 Gary Ching-Pang Lin <glin@suse.com>
- Remove valgrind from BuildRequires since it's not a hard
  requirement anymore. (bsc#1184248)
* Tue Mar 30 2021 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 1.5.8:
  New features:
  * Add a new internal flag to opt-in to GUID matching
  * Add D501 Baklava device support
  * Add fu_device_set_battery_level()
  * Add missing uint64 read and write helpers
  * Add Qubes wrapper source and create packages
  * Allow enabling plugins only matching a specific HwId
  * Prompt for unlock keypress if reset command is blocked
  * Remove obsolete dell-dock non-passive update flow support
  * Remove the Hughski public key
  * Show a warning when parsing invalid quirk files
  * Support for GATT characteristic signals/notifications
  * Support more than one protocol for a given device
  Fixes:
  * Align the CCGX DMC firmware to 64 byte chunks
  * Be more strict for custom quirk keys
  * Check pixart firmware compatibility with hardware before
    flashing
  * Correct a thunderbolt assertion if kernel failed FW read
  * Correctly erase STM32 devices when transfer size is less
    than sector size
  * Detect SREC overflow to avoid adding ~4GB of 0xFF padding
  * Do not show a critical error when flashing footer-less
    binary files
  * Don't allow device updates while needing activation
  * Fix a regression in the elantp defined IAP start address
  * Fix a regression where activate stopped working
  * Fix firmware update of pointing device on Lenovo ThinkPad
    Nano
  * Fix the HSI plugin 'Disabled' state
  * Fix the quirk key name for the Lenovo HDMI with power
  * Fix writing to the GD32VF103 bootloader
  * Only call elantp->detach() when writing a firmware blob
  * Updated StarLabs GUIDs
  * Wait a few ms for the Logitech hardware to settle after
    detach
- Remove GPG-KEY-Hughski-Limited from the filelist
- Drop upstreamed patch
  + fwupd-bsc1182057-fix-sbat-section-copy.patch
* Fri Mar 12 2021 Gary Ching-Pang Lin <glin@suse.com>
- Add fwupd-bsc1182057-fix-sbat-section-copy.patch to set the
  proper section flags for .sbat section so that objcopy can
  copy it into fwupd*.efi (bsc#1182057)
* Wed Feb 24 2021 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 1.5.7:
  New features:
  * Add initial support for Bluez bluetooth devices
  * Add more supported pixart devices
  * Add support for the RTD21xx HDMI converter
  Fixes
  * Convert MBR types to GPT GUIDs to help find the ESP
  * Do not allow updating a synaptics-mst device with no customer ID
  * Drop unused heap pages after startup has completed
  * Ensure SBAT metadata is added correctly
  * Move the plugin build logic to the plugins themselves
  * Only allow verify-update for plugins that support CAN_VERIFY
- Specify SBAT metadata for openSUSE/SLE (bsc#1182057)
- Adjust the meson options
  + plugin_uefi => plugin_uefi_capsule and plugin_uefi_pk
  + plugin_synaptics => plugin_synaptics_mst and plugin_synaptics_rmi
  + Disable Intel AMT plugin in non-x86 systems
* Thu Feb 18 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.6:
  New features:
  * Add SBAT metadata to the fwupd EFI binary
  * Add support for GD32VF103 as found in the Longan Nano
  * Add support for RMI PS2 devices
  * Add support for the System76 Keyboard
  * Allow downloading firmware from IPFS
  * Install the UX data into a single .tar.xz file
  * Add a plugin to update PixArt RF devices
  * Add new hardware to use the elantp and rts54hid plugins
  * Allow specifying more than one VendorID for a device
  * Detect the AMD TSME encryption state for HSI-4
  * Detect the AMI PK test key is not installed for HSI-1
  * Add Maple Ridge Thunderbolt firmware parsing support
  * Add --no-remote-check to ignore checking for download remotes
  * Allow creating FMAP and Synaptics firmware using builder.xml
  Fixes:
  * Add support for the Starlabs LabTop L4
  * Allow using an external ESP again
  * Ask the user to reboot when required if downgrading
  * Be more paranoid when parsing ASCII buffers and devices
  * Check if the fwupd BootXXXX entry exists on failure
  * Clear the pending flag if restarting the system
  * Do not allow flashing using flashrom if BLE is enabled
  * Do not allow Lenovo hardware to install multiple capsules
  * Do not parse the OptionROM image
  * Do not show Unknown [***] for every client connection
  * Fix dnload wBlockNum wraparound for ST devices
  * Fix OOM when using large ArchiveSizeMax values
  * Fix several crashes spotted by AddressSanitizer
  * Fix several places where the Goodix MOC plugin could crash
  * Include the PCR0 to the report metadata
  * Report the lockdown status from UEFI and SuperIO plugins
  * Show a console warning if the system clock is not set
  * Fix flashing a fingerprint reader that is in use
  * Fix several critical warnings when parsing invalid firmware
  * Fix updating DFU devices that use DNLOAD_BUSY
  * Ignore the legacy UEFI OVMF dummy GUID
  * Make libfwupd more thread safe to fix a crash in gnome-software
  * Never show unprintable chars from invalid firmware in the logs
  * Allow using fwupdtool as non-root for firmware commands
  * Do not trust the Block.HintSystem boolean for ESP filtering
  * Fix a memory leak when parsing Synaptics firmware
  * Fix a possible crash when reading the Goodix MOC USB request
  * Fix crashes when parsing invalid FMAP, DMC, Solokey and Synaptics images
- Deprecate fwupd-bsc1179790-disable-hintsystem.patch
* Mon Dec 14 2020 Gary Ching-Pang Lin <glin@suse.com>
- Add fwupd-bsc1179790-disable-hintsystem.patch to remove
  Block.HintSystem from ESP filtering (bsc#1179790)
* Wed Dec  9 2020 glin@suse.com
- Update to version 1.5.3:
  + Lower the CURL version required to fix build in RHEL
  + Do not use meson ternary operations to avoid bumping the
    required meson version
  + Added Lite Mk III
  + Allow setting the GMainContext when used for sync methods
  + Fall back to the misc device for serio devices
  + Actually implement rescan in FuUdevDevice
  + bcm57xx: Refactor CRC code to remove extra byteswap
  + bcm57xx: Fix CRC check
  + synaptics-rmi: Don't crash if calling ->to_string() before
  - >setup()
  + Fix a possible critical warning due to missing retval
  + Add the serio->firmare_id for UDev devices
  + Export the driver name from FuUdevDevice
  + Allow the client to send PKCS7 and GPG signatures
  + Force the remote kind to JCat server-side
  + Only parse the signature if the remote is JCat
  + fu-main: Fix sender_features insert with wrong size
  + make platform integrity plugin optional and disabled by default
  + Add quirk for Western Digital
  + Mark more user-visible strings as translatable
  + modem-manager: validate firmware update method combinations
  + modem-manager: remove unused byte counts in QMI/PDC update logic
  + modem-manager: make sure the correct interface number is used
    for QMI
  + modem-manager: udev monitoring only if device switches layout
  + modem-manager: plug udev client leak
  + Restrict loading component types of firmware
- Enable supported_build to clarify that this package is supported
  (bsc#1179790)
- Drop fwupd-platform-integrity.conf since upstream disables the
  platform integrity module by default now due to incompleteness.
- Address fwupd-refresh.service in %%preun, %%pre, %%post, and %%postun
  and provide a rc link for it
- Version "Obsoletes: dbxtool" and "Obsoletes: fwupdate"
* Fri Dec  4 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 1.5.2:
  + ata: Add OUI quirk for Toshiba
  + libfwupd: Restore recognizing gpg and pkcs7 types still
  + Register the SoupSession gtype when required
  + Switch from libsoup to libcurl
  + Fix sync method when called from threads without a context
  + Move ABI check to Github actions
  + Enable github workflows
  + libfwupd: Add fwupd_client_download_file()
  + libfwupd: Add fwupd_client_get_user_agent()
  + Only download the remote metadata as required
  + Add breaks for fwupdate 12-7 (Closes: #960688)
  + Install modules-load configs in the correct directory
  + vli: Do not be clever replugging the MSP430 device
  + vli: Make some trivial debugging more specific to help debug
    an issue
  + make gcab optional
  + Fall back to FAT32 internal partitions for detecting ESP
  + Add a flag to indicate if packages are supported
  + uefi: a new option for uefi configuration to use UEFI removable
    path
  + Add a section to man page on scripting
  + synaptics-mst: Improve reliability by waiting 2 seconds after
    writing data
  + hailuck: Add an plugin for the Pinebook Pro laptop
  + Allow setting global flags for FuHidDevice
  + Set the SMBIOS chassis type to portable if a DT battery exists
  + colorhug: Don't set the version format to triplet at startup
  + Allow components to set the icon from the metadata
  + colorhug: Fix detection of version on older firmware versions
  + bcm57xx: Fix reading vendor/device ids from firmware.
  + Remove HSI update and attestation suffixes
  + trivial: make dbxtool executable to fix snap build
  + Ignore an invalid vendor-id when adding releases for display
  + Notify the service manager when idle-quitting
- Refresh fwupd-bsc1130056-change-shim-path.patch
- Changes in BuildRequires:
  + Replace pkgconfig(libsoup-2.4) with pkgconfig(libcurl)
  + Replace pkgconfig(systemd) with pkgconfig(libsystemd)
- fwupd-msr.conf and fwupd-platform-integrity.conf are moved to
  %%{_modulesloaddir}.
* Mon Nov 16 2020 Gary Ching-Pang Lin <glin@suse.com>
- Obsoletes and Provides dbxtool since fwupd 1.5.0+ now embeds
  dbxtool in the dbxtool plugin
* Tue Nov  3 2020 Gary Ching-Pang Lin <glin@suse.com>
- Amend the spec file (jsc#SLE-16818)
  + Only enable fish support for Tumbleweed
  + Only enable the MSR plugin for x86
  + Only install dbxtool in the architectures with UEFI support
* Mon Nov  2 2020 dimstar@opensuse.org
- Update to version 1.5.1:
  + Use UDisks to find out if swap devices are encrypted.
  + Show a link to discover more information about a specific
    plugin failure.
  + updated fish completions to 1.5.0.
  + Remove the duplicate parent-child data in FwupdDevice and
    FuDevice.
  + Show a less scary fwupdate output for devices without info.
  + thunderbolt: recognize authorized value of '2' as well.
  + bcm57xx: Make hotplug more reliable.
  + Use a different Device ID for the OptionROM devices.
  + contrib/ci: switch TPM simulator from ibmswtpm to swtpm.
  + Delete unused EFI variables when deploying firmware.
  + Fix probe warning for the Logitech Unifying device.
  + Include the amount of NVRAM size in use in the LVFS failure
    report.
  + Add external interface messages.
* Mon Oct 26 2020 dimstar@opensuse.org
- Update to version 1.5.0:
  + Add a compatible re-implementation of the rhboot dbxtool.
  + Add async versions of the library for GUI tools.
  + Add commands for interacting with the ESP to fwupdtool.
  + Add firmware-extract subcommand to fwupdtool.
  + Add FwupdPlugin so we can convey enumerated system errors to
    the end user.
  + Add plugin for Goodix fingerprint sensors.
  + Add plugin that can update the BCM5719 network adapter.
  + Add plugin to update Elan Touchpads using HID.
  + Add support for a delayed activation flow for Thunderbolt.
  + Add support for ChromeOS Quiche and Gingerbread.
  + Add support for Hyper hardware.
  + Add support for the Host Security ID.
  + Add support for ThunderBolt retimers.
  + Add switch-branch command to fwupdtool and fwupdmgr.
  + Allow blocking specific firmware releases by checksum.
  + Allow contructing a firmware with multiple images.
  + Allow firmware to require specific features from front-end
    clients.
  + Allow updating the dbx using the LVFS, validating it is safe to
    apply.
  + Include the HSI results and attributes in the uploaded report.
  + Support loading DMI data from DT systems.
  + Support LVFS::UpdateImage for GUI clients.
* Wed Sep  2 2020 QK ZHU <qkzhu@suse.com>
- Add fwupd-jscSLE-11766-close-efidir-leap-gap.patch: Set SLE and
  openSUSE esp os dir at runtime (jsc#SLE-11766)
- Drop _multibuild and build option -Defi_os_dir="%%{efidir}": with
  the above patch fwupd can detect esp os dir dynamically
- Update the efidir related %%post and %%postun scripts in spec file
* Thu Jul 30 2020 dimstar@opensuse.org
- Update to version 1.4.5:
  * Add XB_QUERY_FLAG_FORCE_NODE_CACHE
  * Add support for a delayed activation flow for Thunderbolt
  * Allow firmware to require specific features from front-end clients
  * Allow multi-byte FuUdevDevice preads and writes
  * Be more defensive when remotes are missing required keys
  * Disable the SQLite lookaside cache
  * ccgx: Add more hybrid dock support
  * ccgx: Modify readme to remove customer info
  * ccgx: add new protocol for dmc dock
  * ccgx: remove verify flag in plugin
  * modem-manager: read the vendor ID directly from sysfs attribute Fixes: #2209
  * thelio-io: Add the DFU instance ID as a counterpart only
  * thunderbolt: Add a new subclassed thunderbolt firmware update type
  * thunderbolt: Allow quirks to skip the authentication step
  * thunderbolt: drop support for force power
  * tpm-eventlog: fix PCR0 calculation
  * uefi: check for free space after cleaning up ESP
  * vli: Add dual-image feature for VL103 backup firmware
  * vli: Add the project ID shared SPI PD controllers
  * vli: Allow chained usb hub devices where the parent needs GPIOB reset
  * vli: Do not modify the class vfuncs depending on device type
  * vli: Do not use GUID matching for the MSP device
  * vli: Rename FuVliUsbhubI2cDevice to FuVliUsbhubMsp430Device
  * vli: Set FuQuirks on the shared SPI object
  * vli: Set the i2c instance IDs in probe()
  * vli: Use the GPIOB reset for the MiniDock VL103
  * vli: Wait for the root device to be replugged when updating the MSP430
* Thu Jul 30 2020 dimstar@opensuse.org
- Update to version 1.4.4:
  * Release fwupd 1.4.4
  * Fix regression when checking for downgraded metadata
* Thu Jul 30 2020 dimstar@opensuse.org
- Update to version 1.4.3:
  * Release fwupd 1.4.3
  * ata: A OUI quirk for Kingston
  * ccgx: Fix a potential division by zero
  * Check the device requirements when returning from GetDetails
  * fu-engine: Allow --plugin-whitelist to use dashes instead of
    underscores
  * Always enforce the metadata signature has a valid timestamp
  * ccgx: modify install duration for dmc device
  * ccgx: Add support for HP DMC dock devices
  * dell-dock: prevent updates to occur via synaptics-mst plugin
  * dell-dock: Capture the dock SKU in metadata
  * synaptics-prometheus: Force the minor version from 0x02 to 0x01
    to make sure the devices can be updated back to 0x01.
  * Generate a body for github releases (Fixes: #2034)
* Fri Jul 24 2020 Yifan Jiang <yfjiang@suse.com>
- Build the package separately for openSUSE and SLE using
  _multibuild (jsc#SLE-11744).
* Wed Jun  3 2020 dimstar@opensuse.org
- Update to version 1.4.2:
  * vli: Add no-guid-matching for all VLI devices
  * vli: Remove a copy-and-paste mistake
  * Add two OUI quirks
  * ata: Add WD OUI quirk 000cca
  * synaptics-rmi: Essentially blacklist Dell K12A
  * dfu: Avoid communicating when bitManifestationTolerant is off
  * ata: Add OUI quirk for Western Digital
  * dfu: Support MATEKF722SE quirk
  * Fix various build issues with -Wdiscarded-qualifiers
  * thunderbolt/dell-dock: Delay activation for Thunderbolt updates
  * Switch the default of EnumerateAllDevices to false
  * Add OUI quirk for SanDisk
  * vli: Add two standard USB instance IDs for shared-PD devices
  * vli: Use GPIOB to reset the VL817 found in two Lenovo products
  * tpm-eventlog: Correct the display of final calculated PCRs
  * wacom-raw: fixup switching to bootloader mode
* Wed Jun  3 2020 dimstar@opensuse.org
- Update to version 1.4.1:
  * thunderbolt: Don't show safe mode errors for USB4 host controllers
  * ep963x: Various changes to make the plugin actually work on real hardware
  * Make tss2-esys conditional
  * ep963x: Remove some dead code spotted by Coverity
  * ccgx: Only update the FW2 partition of the ThinkPad USB-C Dock Gen2
  * ccgx: Expand the FWImageType for future hardware
  * Allow specifying the device on the command line by GUID
  * Fix the DeviceID set by GetDetails
  * wacom-usb: Fix a theoretical buffer over-read to make GCC happy
  * vli: Only show the i2c devices on the USB3 hub
  * Allow devices to be updatable, but only when upgrading a proxy device
  * Reset the progressbar time estimate if the percentage is invalid
  * ccgx: Always report 100%% when finished writing
  * Add a device quirk that forces an explicit device-id match
  * ccgx: Set the device name and summary from quirk files
  * vli: Only do the APP5 FW bug fix on affected hardware
  * vli: Show all the buffer when debugging with FWUPD_VLI_USBHUB_VERBOSE
  * fu-engine: Refresh device name and format before setting supported flag
  * Allow a device to set the logical or physical ID during ->setup()
  * ccgx: Split out a trivial helper to set the instance IDs
  * ccgx: Set the device name to be more useful
  * ccgx: Set the logical ID as the FwMode
  * ccgx: Split out a trivial function to set the version
  * ccgx: Do not reboot the device write after installing
  * ccgx: Do no show the flash parameters when unknown
  * Allow devices to match the proxy device by GUID
  * Do not skip attach() if the device is marked _WILL_DISAPPEAR
  * dell-dock: Port to using fu_device_get_proxy()
  * Allow adding a device 'proxy' device that can do actions on it
  * vli: Do not show the USB 2 recovery devices for USB 3 hubs
  * vli: Add metadata to identify which is the same physical device
  * uefi: correctly format firmware version of Dynabook (né Toshiba) X30, X40 and probably others
  * synaptics-cxaudio: Use the ->attach() device vfunc
  * synaptics-cxaudio: Wait for the device to reboot after writing firmware
  * logitech_hidpp: decrease verbosity of messages that hid++ ID is missing
  * Prefer to update the child first if the order is unspecified
  * Do not modify the device priority for child devices
* Wed Apr 22 2020 Gary Ching-Pang Lin <glin@suse.com>
- Exclude fwupdate from the architectures without UEFI support.
* Wed Apr 15 2020 glin@suse.com
- Update to version 1.4.0:
  * Release fwupd 1.4.0
  * Allow removing device flags from quirk files
  * Use black to format python source in a consistent manner
  * Define SOURCE_VERSION when building a package
  * Only set the parent when adopting children
  * Do not conditionalize attach() and detach() on IS_BOOTLOADER
  * Do not crash the daemon if a plugin does something dumb
  * wacom-usb: Add more sanity checks in case the daemon goes crazy
  * wacom-usb: Use a per-device cleanup function
  * Add some more device regression tests
  * wacom-usb: Add a lot of missing metadata about the devices
  * wacom-usb: Hide a lot of debugging behind FWUPD_WACOM_VERBOSE
  * Only auto-add counterpart GUIDs when required
  * ccgx: remove update message
  * ccgx: add parent guid for hybrid dock
  * ccgx: Use a smaller timeout for i2c read and write operations
  * ccgx: Retry the register read and write with a i2c reset
  * ccgx: Fix buffer overflow when reading out i2c status
  * ccgx: Retry the HID disconnect up to 5 times
  * ccgx: Show a better error message on failure
  * ccgx: Allow forcing firmware of the wrong app_type with fwupdtool
  * Modularize the hardware tests
  * Ignore indirect devices that replug during the composite firmware update
  * Export the device state as part of the D-Bus interface
  * Fix devices that use CounterpartGuid when more than one device is installed
  * Use the GUID as a fallback rather than the connection ID
  * ccgx: Fix critical warning on i2c write failure
  * logitech-hidpp: Do not add peripheral devices for receiver in BL mode
  * Install the installed-tests only if tests are enabled
  * Load the signature to get the aliased CDN-safe version of the metadata
  * vli: Only reboot the USB hub once
  * synaptics-cxaudio: Only use the PATCH2 address when the patch level is 2
  * add STM32F745 stm dfuse quirk
  * dfu: Add a way to set the timeout from a quirk
  * Export the release urgency
  * Export the release creation time
  * Check the firmware requirements before adding SUPPORTED
  * data/motd/fwupd-refresh: Only order after network.target
  * ccgx: Do not add the HID device that will disconnect
  * ccgx: Use Silicon ID and Application type to set flash parameters
  * Add a new daemon configuration option to control EnumerateAllDevices
  * logitech_hidpp: set the bootloader protocol
  * Install meson from pip for LGTM
  * bash: add completion for fwupdtool reinstall
  * fu-tool: add reinstall command
  * fu-engine: export fu_engine_get_releases_for_device in header
  * vli: Wait for the VL103 to timeout to fix detach
  * ccgx: Show the UpdateMessage in the correct device mode
  * ccgx: Add extra instance IDs to match specific firmware
  * Use a static version number
  * thunderbolt: Rather than hardcoding to PCI slot numbers, use domain in GUID
  * Revert "thunderbolt: Create a unique GUID including Thunderbolt controller path"
  * dell-dock: Port to fu_device_retry()
  * nitrokey: Convert to use FuHidDevice
  * nitrokey: Port to fu_device_retry()
  * vli: Port to fu_device_retry()
  * Add fu_device_retry() helper functionality
  * ccgx: Implement writing firmware to flash
  * ccgx: Add i2c status check when reading or writing registers
  * ccgx: Add 5ms delay between read registers to avoid an i2c error
  * libfwupdplugin: Use fu_device_locker_close()
  * synaptics-mst: Use fu_device_locker_close()
  * Add fu_device_locker_close()
  * ccgx: Do not store the silicon ID in the image address
  * ccgx: Add device quirks for the Lenovo Hybrid Dock
  * ccgx: Switch HID mode to HPI mode at startup
  * ccgx: Clear the event queue when in startup
  * ccgx: Wait for hardware to settle when coming out of reset
  * ccgx: Do not mark the device as updatable when in boot mode
  * ccgx: Verify the firmware app type when preparing firmware
  * ccgx: Set the update message when running in backup firmware
  * ccgx: Read the FwAppType from the hardware
  * ccgx: Set the HPI version number for the current firmware
  * ccgx: Get the silicon ID to map the flash parameters
  * ccgx: Read the HPI device mode at startup
  * ccgx: Set up the HPI I²C config at startup
  * ccgx: Create devices when in HID and I2C modes
  * Add a new ChromeOS CI target to build without GPG and PKCS7
  * Use Jcat files in firmware archives and for metadata
  - Removed fu-keyring-gpg which caused CVE-2020-10759 (boo#1172643)
  * csr: Allow truncated HID reads
  * vli: Only consider the high nibble when building the sub-version
  * csr: Parse the firmware as a DFU file
  * Add support for EP963x hardware
  * Add FuHidDevice abstraction
  * vli: Correctly attach VL103 after a firmware update
  * ccgx: Parse the metadata block in the firmware image
  * ccgx: Add a firmare parser for cyacd files
  * logitech: Correctly set the protocol
  * Add the optional device-id to the update --help output
  * Fix a difficult-to-trigger daemon hang when replugging devices
  * vli: Remove a dock device from the whitelist that is never going to be updated
  * vli: Add some trivial debugging to help track down a bug
  * vli: Never add USB hub devices that are not upgradable
  * uefi: Don't use shim for non-secure boot configurations
  * Start fwupd-activate.service after snapd.service
  * dfu: Actually reload the DFU device after upgrade has completed
  * dfu: Add one more m-stack device requiring a quirk
  * Apply version format to releases and devices at same time
  * Ensure that the DeviceID is set for child devices
  * Fix a daemon crash when removing children
  * Allow waiting for the parent device when replugging
  * Add fu_device_get_root() shared API
  * vli: Fix an error when detaching MSP430
  * vli: Fix a critical warning when getting the USB speed
  * vli: Fix the error enum values for the MSP430
  * Do not add blank lines when tokenizing Intel hex files
  * vli: Fix the version calculation for MSP430
  * vli: Ignore one more error when attaching
  * vli: Always expect the VL103 header at 0x1003 or 0x4000
  * vli: Do not fall back to the recovery write for usbhubs
  * vli: Only show the 2nd header if the device ID is valid
  * vli: Fix VL103 reboot from ROM mode to FW mode
  * vli: Add some better comments for writing GPIOs
  * Add a helper script to add a DFU header
  * Add 'firmware-convert' subcommand to fwupdtool
  * fu-engine: Make two passes of requirements checking
  * fu-engine: Copy the VersionFormat from the CAB if specified in `get-details`
  * Add a new plugin for CPU microcode
  * Don't build/install fwupdagent man page if agent build is not requested
  * Introduce a new VersionFormat for `hex`
  * Drop UEFI quirks we now inherit from metadata
  * ci: build Debian using libflashrom
  * When TPM PCR0 measurements fail, query if secure boot is available and enabled
  * fix fwupd.shutdown.in according to the movement of fwupdtool to bindir
  * ata: Add OUI quirk for Western Digital and Intel
  * improved fish shell completion
  * vli: Set the MSP430 version format to pair
  * Always return AppStream markup for remote agreements
  * ata: Add trivial OUI quirk for Micron
  * added completion script for fish shell
  * Do not fail loading in /etc/machine-id is not available
  * Use xb_builder_source_add_simple_adapter
  * Create FuCabinet and untangle a lot of legacy code
  * nvme: Do not try to handle integer version numbers
  * Allow server metadata to set the version format on some devices
  * fu-tool: Correctly append the release to devices in `get-details`
  * For the `get-details` command make sure to always show devices
  * fu-engine: Copy the version and format from donor device in get-details
  * fu-engine: Use unknown for version format by default on get-details
  * Inihbit all power management actions using logind when updating
  * Decouple the version format from the version itself
  * Add raw versions for bootloader and lowest
  * Allow server metadata to set the device name on some devices
  * Remove support for GCab less than v1.0
  * fu-device-list: Check protocol before de-duping devices
  * Do not allow devices that have no vendor ID to be UPDATABLE
  * ata: Include a vendor ID for ATA hardware
  * ata: Switch off the verbose logging by default
  * Always check for PLAIN when doing vercmp() operations
  * Discard the reason upgrades aren't available (Fixes: #1678)
  * Improve the description of `fwupdtpmevlog` for man page
  * Move `fwupdtpmevlog` into `bindir`
  * uefi: Move `fwupdate` into `bindir`
  * Move `fwupdtool` and `fwupdagent` into `bindir`
  * Use the system provided flashrom on Fedora
  * Add a plugin vfunc to run after subclassed FuDevice creation
  * ci: use standalone script to generate build dependencies
  * Move the daemons from /usr/lib/fwupd to /usr/libexec/fwupd
  * Use the recently released flashrom v1.2
  * Generate an additional UEFI quirk file using the stable LVFS metadata
  * uefi: Apply capsule update even with single valid capsule
  * Fix a critical warning when installing some firmware
  * ebitdo: Fix the endpoint address logged in the error message
  * uefi: Find the correct lds and crt name when specifying -Defi_ldsdir
  * upower: Move battery threshold declaration into a configuration file
  * upower: Decrease minimum battery requirement to 10%%
- Refresh fwupd-bsc1130056-change-shim-path.patch
- Add new dependency: jcat
* Wed Mar 11 2020 hpj@urpla.net
- Update to version 1.3.9:
  * Release fwupd 1.3.9
  * Always check for PLAIN when doing vercmp() operations
  * improved fish shell completion
  * vli: Set the MSP430 version format to pair
  * added completion script for fish shell
  * Always return AppStream markup for remote agreements
  * Do not fail loading in /etc/machine-id is not available
  * fu-engine: Fixup broken-ness from 0c0fada18fc9cb2a0efec351db67f0867bf045cd
  * Use xb_builder_source_add_simple_adapter
  * fu-tool: Correctly append the release to devices in `get-details`
  * For the `get-details` command make sure to always show devices
  * fu-engine: Copy the version and format from donor device in get-details
  * fu-engine: Use unknown for version format by default on get-details
  * Inihbit all power management actions using logind when updating
  * fu-device-list: Check protocol before de-duping devices
  * ata: Switch off the verbose logging by default
  * Discard the reason upgrades aren't available (Fixes: #1678)
  * Improve the description of `fwupdtpmevlog` for man page
  * Move `fwupdtpmevlog` into `bindir`
  * uefi: Move `fwupdate` into `bindir`
  * Move `fwupdtool` and `fwupdagent` into `bindir`
  * ci: use standalone script to generate build dependencies
  * Move the daemons from /usr/lib/fwupd to /usr/libexec/fwupd
  * Use the recently released flashrom v1.2
  * uefi: Apply capsule update even with single valid capsule
  * Fix a critical warning when installing some firmware
  * ebitdo: Fix the endpoint address logged in the error message
  * fu-util: fix a logic error in report uploading introduced in e076d48afb74d1447936d353f12781755f13b047
  * uefi: Find the correct lds and crt name when specifying -Defi_ldsdir
  * upower: Move battery threshold declaration into a configuration file
  * upower: Decrease minimum battery requirement to 10%%
- Update to version 1.3.8:
  * Release fwupd 1.3.8
  * Do not use fu_common_vercmp() when the device verfmt is PLAIN
  * altos: Output raw buffer data when using FWUPD_ALTOS_VERBOSE
  * altos: Prefix an error to provide more context
  * altos: Add a trivial _to_string() implementation
  * synaptics-cxaudio: Make the verfmt match that of the existing Windows tools
  * synaptics-mst: Allow MST to fall back if no PCI device is marked as parent
  * Allow specifying a list of subsystems when setting a physical ID
  * synaptics-mst: Fix trivial thinko caused by the wrong dock connected
  * vli: Invert the logic to reboot the parent FuCliUsbhubDevice, not the child
  * vli: Switch around the hub tier values
  * uefi: Fix a build regression with Fedora 30
  * logitech_hidpp: Ignore detach failures (Fixes: #1183)
  * logitech_hidpp: When detaching to bootloader use non-blocking IO and wait for timeout
  * vli: Show erase progress when doing a v2 recovery
  * uefi: Do not remove the 'Linux Firmware Updater' boot entry before update
  * uefi: Do not rewrite BootOrder in the EFI helper
  * vli: Add support for the PS186 device
  * Set up more parent devices for various Lenovo USB hubs
  * cxaudio: Set the update protocol to prevent a daemon warning
  * vli: Add support for Lenovo Modularized dock
  * Add an extra instance ID to disambiguate USB hubs
  * vli: Remove the unused tierX custom flags for each device
  * Revert "Correctly delete UEFI variables"
  * uefi: make debugging output more readable
  * vli: Fix a potential buffer-overflow when parsing firmware
  * tpm: Optimize the string parsing and fix the boolean logic
  * synaptics-rmi: Add a missing error enum value
  * synaptics-rmi: Correctly identify a checksum failure
  * synaptics-rmi: Fix Coverity issue that is impossible to hit in reality
  * solokeys: Parse old versions of the bootloader string
  * Add a plugin to update PD controllers by Fresco Logic
  * vli: Set the device progress correctly when erasing a PD device
  * vli: Use the correct command to get the device firmware version
  * vli: Correctly reset all VL100 devices
  * vli: Set all standalone PD devices to not do SPI auto-detection
  * vli: Mark standalone PD devices as updatable
  * vli: Set the protocol for FuVliUsbhubPdDevice types
  * Support the new gnuefi file locations
  * Cleanup ancient fwupdate-* EFI variables too (Fixes: #1739)
  * Detect kernel lockdown status
  * vli: Add the DEV instance ID to all devices
  * tpm-eventlog: Replay the TPM event log to get the PCRx values
  * tpm-eventlog: Store the eventlog hashes in binary form
- Update to version 1.3.7:
  * Release fwupd 1.3.7
  * Correctly delete UEFI variables
  * ci: allow working with podman w/o aliases
  * ci: fedora: force correct rpm package version
  * src: fu-engine: check version was updated by checking version
  * Correctly import PKCS-7 remote metadata
  * Add 'refresh' to fwupdtool
  * Add 'get-remotes' to fwupdtool
  * Generate a win32 setup binary
  * Fix display of UTF-8 characters on Windows
  * Move MOTD population into the daemon
  * fu-util: Discourage metadata refreshes more than once per day
  * Disable the battery percentage checks if UPower is unavailable
  * Allow getting the list of updates in JSON format from fwupdagent
  * Revert "trivial: Attempt to fix Debian CI"
  * fu-remote-list: emit a changed signal when modifying a remote
  * synaptics-mst: Skip self tests for systems with amdgpu
  * Allow applying all releases to get to a target version
  * Split up fu_engine_install() into two halves
  * logitech_hidpp: use the correct timeout for IO channel writes
  * Allow quirking devices that always require a version check
  * Shut down automatically when there is system memory pressure
  * Show the device parent if there is an interesting child
  * Allow the client to get the list of FwupdDevice children
  * Set the FwupdDevice parents in fwupdtool
  * Don't always get the vendor ID for udev devices using the parent
  * Add a runtime warning when adding a device without an vendor-id or protocol set
  * vli: Set more of the firmware max sizes automatically
  * vli: Add a SpiAutoDetect quirk for some of the PD devices
  * vli: Use a different protocol ID for i2c devices
  * vli: Add support for standalone Single PD devices
  * vli: Move generic SPI functionality into the FuVliDevice base class
  * vli: Remove the PD emulation code
  * vli: Use a more standard GUID for the child i²c and shared SPI devices
  * vli: Allow setting the device kind from a quirk
  * vli: Make more function names match the docs
  * vli: Move the SPI command quirking from FuVliUsbhubDevice down to FuVliDevice
  * vli: Rename FuVliUsbhubPdFirmware to FuVliPdFirmware
  * vli: Allow the device to specify the PD firmware header offset
  * vli: Add a FuVliDevice as a subclass to FuVliUsbhubDevice
  * vli: Define the device GType in the quirk file
  * vli: Move the CRC calculations out of usbhub scope
  * vli: Have one 'DeviceKind' for all objects
  * vli: Rename the `vli_usbhub` plugin to `vli`
  * Capitalize GNOME
- package has grown a few new binaries: fwupdagent, fwupdate, fwupdtool
  and a tpm event debugging tool, that is packaged separately:
  fwupdtpmevlog
* Thu Jan 23 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Drop docbook-utils-minimal build dependency, manpages are generated
  with gtk-doc.
* Thu Jan  2 2020 bjorn.lie@gmail.com
- Update to version 1.3.6:
  * plugins/coreboot: Add missing fu_hash dependency
  * trivial: synaptics-cxaudio: Add Google type C <-> 3.5mm adapter
  * fu-engine: don't expose bootloader version errors to users
  * trivial: dell-dock: drop unused quirk keyx
  * trivial: rename synapticsmst to synaptics-mst
  * trivial: actually set vendor ID for synaptics
  * fu-remote-list: Drop fallback path behavior
  * libfwupdplugin: Make sure systemd created environment variables exist
  * trivial: fu-remotes-list: drop usage of `FU_SELF_TEST_REMOTES_DIR`
  * trivial: synaptics-rmi: hardcode Vendor string
  * trivial: Set vendor ID for Dell WD19 to USB:0x413C (Fixes: #1653)
  * trivial: Document the use of vendor-id in each plugin
  * superio: Use the baseboard vendor as the vendor ID
  * uefi: Use the BIOS vendor as the vendor ID
  * coreboot: Use the BIOS vendor as the vendor ID
  * flashrom: Use the BIOS vendor as the vendor ID
  * dell: Hardcode a plausible vendor ID
  * emmc: Set the correct vendor ID prefix
  * fu-util-common: correct the default prompt for reboot/shutdown (Fixes: #1617)
  * Split out the remote loading from FuConfig
  * vli-usbhub: Fix the quirk for the legacy VIA 813 chip
  * Clarify error messages when no upgrades available
  * trivial: Don't handle a vendor-id requirement error that cannot happen
  * Only check the vendor ID if the device has one set
  * fu-install-task: Enforce that device protocol matches metadata
  * Add a new plugin that can parse the TPM event log
  * Allow other plugins to contribute report metadata
  * trivial: dell: hardcode the physical device ID for tpm to match the tpm plugin
  * Add a new plugin that exposes the system TPM device firmware version
  * Add fu_udev_device_set_flags()
  * trivial: Render large values of VersionRaw in a more portable way
  * trivial: wacom-raw: mark all Moffett SKUs as self recovery
  * Throw exit status 0 (instead of 2) if there is no firmware to be updated
  * Add a `dell-bios` version format
  * Add support for multiple LVFS::VersionFormat tags
  * Do not do semver conversion in fu_common_vercmp()
  * trivial: Deprecate fu_common_version_parse()
  * trivial: Support 'plain' in fu_common_version_from_uintXX()
  * Add the sysfs 'description' as the one-line device summary
  * trivial: Also print the parent keys when using FU_UDEV_DEVICE_DEBUG
  * trivial: Add fu_common_version_from_uint64()
  * trivial: Convert the VersionRaw value to a uint64_t for future use
  * Allow building on Windows with MinGW
  * synaptics-prometheus: Allow incremental version major and minor number
  * Replace 'scheduing' with 'scheduling'
  * Export the raw device version to the client --verbose output
  * trivial: Only dlopen the test plugin once
  * Export the device protocol to the client --verbose output
  * trivial: installed-tests: try to display journal for failed tests
  * trivial: ci: debian: enable verbose daemon logging for failure analysis
  * trivial: installed-tests: explicitly choose webcam device ID
  * trivial: debian: remove obj-* built files to fix back to back builds
  * trivial: ci: don't let bad symlinks cause debian build failures
  * trivial: debian: correct a dependency for libfwupdplugin-dev
- Changes from version 1.3.5:
  * plugins: Fix potential use of NULL pointer in fu_dell_dock_mst_write_register
  * Fix shifting integer by more than 31 in fu_util_filter_device
  * synaptics-prometheus: Reload the device version after IOTA update
  * synaptics-prometheus: Reload the device version after update
  * trivial: wacom: remove coretronic config from Moffett scope
  * trivial: Fix a NULL/FALSE confusion
  * trivial: Add a BR for Fedora
  * trivial: Fix coreboot commit to fix CI
  * trivial: libfwupdplugin: clarify name of self test
  * plugins/coreboot: Improve version detection
  * plugins/coreboot: Get rid of FU_HWIDS_KEY_BIOS_VENDOR in coldplug
  * trivial: Move progressbar out of libfwupdplugin
  * trivial: Unexport fu_test_get_filename()
  * trivial: Unexport fu_test_compare_lines()
  * trivial: Unexport fu_test_loop_run_with_timeout()
  * trivial: Do not include non-introspectable functions in the GIR
  * trivial: Fix up a few introspection problems in FwupdPlugin
  * trivial: Include the Fwupd GIR in the FwupdPLugin GIR
  * trivial: Never add duplicate symbols to the map file
  * trivial: Properly namespace the defines in the exported header
  * Install development files for libfwupdplugin
  * Convert libfwupdprivate to a shared library libfwupdplugin
  * trivial: Allow building GCab from a subpackage
  * trivial: Fix under-include to define O_RDONLY
  * trivial: Allow compiling without <glib-unix.h>
  * trivial: Do not use FuProgressbar in dfu-tool
  * synaptics-prometheus: Manually set the bootloader mode when attaching
  * trivial: Split out a new helper funtion
  * trivial: Add some optional debugging when hotplugging devices
  * trivial: Include the correct header for S_IRWXU
  * Always use the more portable 3-arg form for open()
  * trivial: Untangle FuHistory from FuPlugin
  * trivial: Allow compiling without <fnmatch.h>
  * Revert "synaptics-rmi: Use the build ID as the version number to match the vendor tool"
  * Add missing documentation from the plugin interface
  * trivial: fu-udev-device: remove a prototype that was missed in b3d4d2ff
  * trivial: add missing gtk-doc fields for many files in src/
  * trivial: fix compile failure without gudev
  * synaptics-prometheus: Mirror the _IS_BOOTLOADER from device to config
  * Allow setting the device flags using GObject properties
  * vli_usbhub: Set the composite parent at construction time
  * synaptics-prometheus: Set the composite parent at construction time
  * Allow plugins to set the parent during construction
  * vli-usbhub: Whitelist the PD and I²C devices
  * Set the protocol per-device not per-plugin
  * synaptics-rmi: Use the build ID as the version number to match the vendor tool
  * Create a REV_00 instance ID as this may be what the vendor needs to target
  * fu-util-common: Invert default behavior for reboot and shutdown prompts
  * trivial: fu-plugin-vfuncs: Add GTK documentation for all vfuncs
  * Make gudev a compile-time option
  * trivial: Set the offline trigger using an environment variable
  * trivial: ci: pull lintian from unstable for now.
  * trivial: stop including fu-hash.h as part of fu-plugin-vfuncs.h
  * Fix shebangs on scripts
  * trivial: Use prefixes for DATADIR in config.h for portability
  * Allow compiling GUsb as a subproject
  * trivial: fu-udev-device: add a to_string func for debugging
  * trivial: Don't assume that plugins end in .so
  * trivial: optionrom: remove unneeded includes
  * trivial: debian: ci: ignore library-not-linked-against-libc for more
  * trivial: remove version-format.md
  * trivial: Allow compiling without pwrite()
  * trivial: Allow compiling without <errno.h>
  * trivial: Allow compiling without realpath()
  * trivial: Allow compiling without HAVE_LC_MESSAGES
  * trivial: Allow compiling without getuid()
  * trivial: Allow compiling without <sys/ioctl.h>
  * trivial: Allow compiling without <poll.h>
  * trivial: Allow compiling without <sys/utsname.h>
  * Ensure the _get_type() gets the same ABI version as the constructor
  * Use the correct unlocker when using GRWLock
  * trivial: plugins: only build coreboot when option set
  * fwupdtool: don't show a warning when calling `get-plugins`
- Changes from version 1.3.4:
  * trivial: Don't force specific linker flash when cross building
  * dell: Use the more portable g_usleep()
  * trivial: Fix unused header includes
  * vli-usbhub: Make erasing less verbose and writing more obvious
  * vli-usbhub: Correctly print the 24-bit USB3 offset
  * vli-usbhub: Print the PD firmware offset and size for debugging
  * vli-usbhub: Open the parent device before attempting to read or write from the child
  * vli-usbhub: Set the install duration for the PD device
  * trivial: Fix a failed error prefix string
  * trivial: wacom-raw: Remove embedded from device name
  * wacom-raw: Correct HWID support
  * uefi: Just use a uint16_t for BootNext processing
  * uefi: Use a simpler entries set algorithm
  * vli-usbhub: Add support for writing using I2C passthru
  * vli-usbhub: Support updating PD devices that share the hub flash
  * vli-usbhub: Support the PD file format
  * trivial: uefi: correct a NULL pointer dereference
  * uefi: fall back to `ID_LIKE` when the path for `ID` doesn't exist (Fixes:# 1566)
  * uefi: Make generate_binary.sh more robust
  * Tokenize the Intel Hex file before parsing
  * trivial: Detect the USB version automatically
  * trivial: fu-util/fu-tool: explicitly block unsupported flags
  * Add support for matching <firmware> requirements on device parents
  * Skip cleanup after device is done updating if `will-disappear` is set (Fixes: #1529)
  * efi: use a wildcard section copy for final EFI generation
  * modem-manager: explicitly use plain version format
  * modem-manager: add quirks for the Foxconn T77W968 modules
  * Allows confined snaps to activate fwupd via D-Bus
  * trivial: thunderbolt: clarify error message
  * Add a new property `Interactive` to the daemon
  * trivial: contrib/get-version.py: require git less hard
  * superio: Never read from port offset zero
  * superio: Fix regression when coldplugging superio devices
  * trivial: Fix Fedora CI build
  * trivial: Fix the autobuilt spec file with the new tarball version
  * Dynamically determine release version
  * trivial: synapticmst: allow missing `/proc/modules`
  * synapticsmst: filter invalid chip IDs
  * trivial: Provide some defines for common image names
  * Allow aborting early when using fu_archive_iterate()
  * Add fu_firmware_image_set_version() for future use
  * modem-manager: increase re-enumeration delay to 20000ms
  * modem-manager: add counterpart GUID for the DW5821e/eSIM
  * Add versions formats for the Microsoft Surface devices
  * usb: make loading vendor/product/serial strings non-fatal
  * trivial: Fix the protocol ID for VLI usbhub devices
  * trivial: wacom-raw: add more device IDs for Dell devices
  * trivial: contrib: don't require TSS for debian archs without EFI
  * fu-udev-device: Adjust bounds checking to be safer
  * fu-udev-device: Don't assume all devices have `device_file`
  * synaptics-rmi: correct an error cleaning up on probe
  * trivial: fu-udev-device: add some safety checks for fd
  * udev-device: fix offset of vendor id of hidraw devices
  * flashrom: switch to upstream source
  * trivial: fu-plugin: only show an error once  "failed to open plugin" was being prefixed twice
  * trivial: debian: only use mingw-w64-tools in archs with UEFI plugin
  * fastboot: Fix a regression when updating modem firmware
  * trivial: conflict with old unifying plugin
  * Rename unifying plugin to logitech-hidpp (Fixes: #1329)
  * Add a new contrib script for installing a Dell BIOS from an EXE file
  * trivial: add-capsule-header: rename to make it easier to import
  * trivial: simple_client: make it easier to reuse code
  * trivial: firmware-packager: make it easier to reuse code
  * trivial: add-capsule-header: make it actually work
  * trivial: fix some gtkdoc sections
  * Bump the required gudev version
  * trivial: Fix a compile error with older versions of gudev
  * trivial: wacom: add vid/pid for panels in Moffett
  * trivial: post release version bump
- Changes from version 1.3.3
  * unifying: notify users to replug when using dfu control (Fixes: #1383)
  * trivial: 8bitdo: set a transient failure while waiting for user action
  * libfwupd: Add a new error type for user action needed
  * trivial: 8bitdo: show the same message for SN30pro and SN30pro+
  * trivial: Fix up some typos from codespell
  * trivial: Ensure config.h is included in all source files
  * trivial: Fix up some NULL/FALSE confusion
  * trivial: Add all the _LAST enums that shouldn't be checked for ABI
  * trivial: Fix a typo that means that UEFI results were never cleared
  * Always report the update-error correctly for multiple updates
  * trivial: Fix fwupdmgr get-history if the firmware was not installed from the LVFS
  * trivial: Do not emit a warning if a child has no version number
  * Move the file descriptor lifecycle into FuUdevDevice
  * trivial: Fix some GtkDoc annotations
  * ebitdo: Modernize the plugin to use FuFirmware
  * nitrokey: Use fu_common_dump_raw() when debugging
  * thunderbolt: Create a unique GUID including Thunderbolt controller path
  * Use device safety flags to show prompts before installing updates
  * trivial: Use the new possible_plugin support for USB devices too
  * jabra: Move the Jabra-specific detach out into its own plugin
  * Ensure the device is open when doing the subclassed prepare() and cleanup()
  * vli-usbhub: Add support for updating V2 devices
  * Allow verifying the device image itself from fwupdtool
  * Use XMLb to query quirks
  * trivial: ci: disable pulling libxmlb from unstable
  * synaptics-prometheus: Don't add a config-subdevice in bootloader mode
  * dfu: Use the VID/PID to identify devices without download capability in runtime
  * trivial: debian: remove some unneeded lintian
  * trivial: debian: bump compat version
  * ebitdo: Add SN30Pro+ to recognized quirk list (Fixes: #1503)
  * dfu: Add several quirks for Realtek camera hardware
  * dfu: Always mark devices as UPDATABLE
  * uefi: use `genpeimg` to mark ASLR and DP/NX on EFI binary
  * trivial: solokey: correct a typo
  * trivial: fu-util: fix typo
  * uefi: rework ESP path detection and lifecycle
  * trivial: uefi: show more metadata in to_string method
  * trivial: fu-device: add new method to remove metadata
  * Add a plugin to update VIA USB hub hardware
  * trivial: Add fu_common_read_uint8_safe()
  * trivial: Fix two typos in fu_common_read_uint16_safe()
  * solokey: Allow parsing firmware with fwupdtool
  * Allow fwupdtool to dump details of common firmware formats
  * trivial: Do not do system coldplug when using FU_ENGINE_LOAD_FLAG_NO_ENUMERATE
  * trivial: fu-self-test: set polling self tests to slow
  * trivial: fu-tool: Allow `detach`/`attach` to prompt for device
  * Strip trailing whitespace from USB descriptors
  * trivial: Add fu_common_read_uint16_safe()
  * trivial: Add version to the FuFirmware->to_string() output
  * Add fu_firmware_set_version()
  * Add a systemd preset file for `fwupd-refresh.service`
  * trivial: dell: work around a memory leak caught by address sanitizer
  * ebitdo: if the device has the will disappear flag, don't wait for ack (Fixes: #994)
  * Add a new plugin for working with eMMC devices (Fixes: #1455)
  * fu-engine: Check multiple plugins if quirks match
  * trivial: don't try to enable LVFS from systemd
  * trivial: coreboot: fix a clang compiler error
  * fu-util: Add user friendly strings for all device flags
  * Add new device flags indicating update resilience
  * plugins: Add coreboot plugin
  * fu-plugin: Add fu_plugin_get_hwid_replace_value
  * trivial: Increase verbosity when actually updating devices
  * trivial: Allow plugins to use WAIT_FOR_REPLUG in prepare and cleanup
  * Add FuDevice->prepare() and FuDevice->cleanup() vfuncs for future use
  * dfu: Implement FuDevice->to_string()
  * trivial: colorhug: fix a crash that occurs when flashing sometimes
  * trivial: fu-util: break out of automatic reports if one is not automatic
  * thunderbolt: some more clarifications when using ICL
  * trivial: fwupd-refresh: activate motd if using systemd v243 or later
  * trivial: fwupd-refresh: allow exit code 2 for success
  * trivial: synaptics-cxaudio: Add Google Pixel buds
  * trivial: arch: ci: Wait some time for tpm_server to start up
  * Allow a custom FuFirmwareImage->write() in superclassed objects
  * dfu: Remove two completely unused helpers
  * dfu: Make DfuFirmware derive from FuFirmware
  * dfu: Make DfuImage derive from FuFirmwareImage
  * dfu: Remove private headers that do not need to exist
  * Fix device flag filtering
  * trivial: fu-engine: Don't compare device and content checksums
  * fu-engine: Read all releases and convert versions when comparing
  * Add new flags `can-verify` and `can-verify-image`
  * trivial: make verify and verify-update safer
  * trivial: test: add checksums for "stock" 1.2.2
  * trivial: fu-udev-device: use parent udev device to indicate `internal`
  * trivial: fix TPM2 simulator tests for arch
  * trivial: uefi: don't add PCRs with all 0's
  * trivial: Fix a recent regression causing a double-free
  * synaptics-cxaudio: Support the ThinkPad USB-C Dock Gen2
  * trivial: fu-util: add some extra checks around automatic reports
  * trivial: fu-tool: typo
  * fu-systemd: Use correct method for stopping units.
  * trivial: fu-udev-device: Use ID_PCI_CLASS_FROM_DATABASE if name not set
  * trivial: fu-plugin: quiet down debug output for optionrom plugin
  * 8bitdo: use will-disappear flag for sf30/sn30 controllers (Fixes: #783)
  * trivial: ebitdo: don't dump out firmware header unless plugin verbose
  * trivial: ebitdo: don't use local errors when writing firmware
  * Add a new device flag for indicating device won't come back
  * wacom-emr: Fix a regression for EMR devices
  * Add a generic DFU firmware object for plugins to use
  * dfu: Use FwupdInstallFlags rather than a DFU-specific version
  * dfu: Remove functionality for modifying DfuSe files
  * dfu: Remove functionality you can do now with fwupdtool
  * dfu: Remove the merge command as it's unused and broken
  * trivial: Add fu_firmware_parse_file() helper for future use
  * trivial: Remove the fuzzing details for DfuPatch
  * trivial: Add klass->to_string for superclassed FuFirmwareImage objects
  * dfu: Remove DfuPatch as no vendor actually uses this
  * dfu: Don't wrap provided VID-PID functions
  * dfu: Use the standard FuDevice custom flags functionality
  * dfu: Use klass_device->write_firmware() directly
  * dfu: Use the generic fu_plugin_usb_device_added() function
  * dfu: Use daemon flags to ignore devices rather than a special flag
  * dfu: Set the device state directly to avoid proxying signals
  * dfu: Use the built-in detach() and attach() vfuncs
  * Read firmware back from the device as a FuFirmware
  * dfu: Remove a pointless function
  * dfu: Remove support for the Metadata Store Proposal
  * dfu: Remove XTEA support
  * dfu: Remove the SREC and IHEX parsing out of the DFU plugin
  * ebitdo: Use klass_device->write_firmware like other plugins
  * trivial: Remove G_BEGIN_DECLS from all private headers
  * Remove FU_PLUGIN_RULE_REQUIRES_QUIRK as all the plugins now use it
  * Set all FuUdevDevice plugins to use FU_QUIRKS_PLUGIN
  * thunderbolt: recognize new 'generation' sysfs attribute
  * Rename and modernize the udev plugin
  * synaptics-rmi: Also add the product ID as a GUID without the minor version
  * synaptics-rmi: Correctly set the payload length rather than hardcoding it
  * synaptics-rmi: Write the core config correctly
  * synaptics-rmi: Decode BL7 status failures as actual errors
  * synaptics-rmi: Add some trivial debugging to help debug a write problem
  * trivial: uefi: Make efivarvs errors clearer (Fixes: 1330)
  * trivial: uefi: don't prefix efivar errors
  * trivial: Remove some now-unused vfuncs
  * altos: Modernize the plugin to simplify it
  * Create the custom plugin GType in common code
  * Reduce more boilerplate in plugins
  * synaptics-rmi: Check the correct register when querying bootloader mode
  * trivial: fu-engine: fix never reporting remotes
  * trivial: fu-util: don't show warnings for no reports to upload
  * trivial: debian: remove more conffiles from transitions (Closes: #932617)
  * trivial: debian/control*: Update for fwupdate transition
  * trivial: Fix a tiny memory leak when starting the daemon
  * modem-manager: Fix a tiny memory leak when starting the daemon
  * synaptics-rmi: Copy the behavior of rmi4utils for BL7 detach
  * synaptics-rmi: Simplify fu_synaptics_rmi_device_read()
  * synaptics-rmi: Set the version after ->setup has run
  * synaptics-rmi: Use the correct mask when getting the bootloader mode on BL7
  * syanptics-rmi: The build_id is 3 bytes long, not 2
  * synaptics-rmi: Read the config partition the same as rmi4utils
  * Provide a default implementation of common FuDevice actions
  * thunderbolt-power: avoid checking for bolt support
  * synaptics-rmi: Add some debugging for BL7 devices
  * Fix usage of incorrect type for return value
  * synaptics-rmi: Do as little as possible in device setup
  * synaptics-rmi: Speed up reading the PDT from 900ms to 30ms
  * fu-util: add support for a reinstall command
  * trivial: fu-util/fu-tool: update re-install help text to reinstall
  * trivial: fu-util: remove double printed message about succesful firmware update
  * trivial: fu-util: show no updatable devices error for update command
  * synaptics-rmi: Ignore the ATTN reports from the hardware when reading DATA
  * synaptics-rmi: Move the fuzzing instructions to the toplevel README
  * Fuzz the SREC and IHEX file parsers once more
  * Use parallel fuzzing for the SMBIOS checks too
  * synaptics-rmi: Fix the packing of the partition table
  * Add a plugin to update Synaptics RMI4 devices
  * trivial: Add a parallel fuzzing script
  * trivial: fu-util: output newline after prompt.
  * trivial: fix %%u output in report upload
  * Add a --no-domain logging option
  * trivial: Fix compiler warning for impossible-to-hit condition
  * Add support for automatically uploading reports
  * trivial: motd: disable updating motd for now
  * trivial: fwupd-refresh: fix a clash with fwupd.service (Closes: #941360)
  * trivial: Fix Fedora CI
  * trivial: fu-udev-device: fix some assertions
  * Search up the tree for a vendor name rather than (ab)using the HID_NAME
  * Add some success messages when CLI tasks have completed
  * trivial: Put the boolean prompt on the same line as the text
  * Never show LicenseRef-proprietary to the end user
  * trivial: snap: correct install hook root directory
  * Export the instructions for detaching the device
  * uefi: detect unmounted ESP partitions (Fixes: #1405)
  * uefi: stop recording efibootmgr output after flash
  * trivial: post release version bump
- Changes from version 1.3.2:
  * Add support for '<name_variant_suffix>' to disambiguate some firmware
  * thelio-io: Add a plugin to detach the Thelio IO board
  * trivial: uefi, dell: skip self tests with TPM if non-root (Fixes: #1396)
  * trivial: dell: quiet the TSS output
  * trivial: uefi: allow forcing to TPM2 via environment variable
  * Do not ask the user to upload a report if ReportURI is not set
  * Do not enumerate physical devices when running the internal self tests
  * trivial: libfwupd: skip tests if machine-id is empty too
  * Add a new plugin to update Conexant audio devices
  * Export the salted machine ID as a daemon property
  * Fall back to /var/lib/dbus/machine-id when required
  * trivial: add stalebot (Fixes: #1393)
  * trivial: dell-dock: correct another write_size error
  * Align the key values to the text *width* not the number of bytes
  * trivial: Move dbus directory location for snap too
  * trivial: Fix some NULL/FALSE confusion
  * synaptics-prometheus: Fix tiny memory leak when using FuSynapromConfig
  * trivial: Fix tiny memory leak when using FuSrecFirmware
  * snap: switch to core18
  * trivial: Return the correct property when getting the host product
  * trivial: fu-util-common: fix description wrapping (Fixes: #1378)
  * fu-util/fu-tool: Map out changelogs from remotes
  * fu-util/fu-tool: Better display historical information
  * fu-history: Update device_modified in sql database during updates
  * unifying: Use the instance ID to check for supported devices
  * unifying: Ensure HID++ v2.0 peripheral devices get scanned by the plugin
  * trivial: Add some more defines to the srec parser
  * trivial: fix wget command in fu-tool.c
  * Allow parsing a raw SREC file
  * trivial: wacom: Add support for second vendor ID
  * uefi, dell-esrt: Show firmware version when capsule updates unavailable
  * Add some more debugging to the SREC and IHEX parsers
  * Print the instance IDs if the GUIDs are unconverted
  * Add fu_common_bytes_compare_raw() for future usage
  * Call the set_quirk_kv() vfunc for the superclassed object
  * uefi: make the TPM optional for runtime again (Fixes: #1362)
  * trivial: uefi: Make the TCTI output less verbose
  * Support <issues> in AppStream metadata
  * Include all GUIDs when uploading a report
  * Do not crash when starting tpm2-abrmd
  * trivial: Update DBus conf path for example Fedora package
  * Move D-Bus conf file to datadir/dbus-1/system.d
  * trivial: Add fu_io_channel_write_byte_array() for future use
  * trivial: post release version bump
- Package new sub-packages typelib-1_0-FwupdPlugin-1_0 and
  libfwupdplugin1.
* Mon Oct 28 2019 Andreas Schwab <schwab@suse.de>
- Fix file list
* Wed Sep 18 2019 bjorn.lie@gmail.com
- Update to version 1.3.1: (jsc#SLE-10751)
  * Allow disabling all plugins
  * trivial: Specify the tpm2-tss-devel version in the example spec file
  * Move to CI Fedora 30
  * modem-manager: Fix two build warnings on Fedora 30
  * synapticsmst: Add another name quirk for the ThinkPad USB-C Dock
  * Re-introduce GUID support to fwupdmgr and fwupdtool
  * uefi-recovery: Add a plugin to add a fake ESRT entry for device recovery
  * Add a DMI quirk for the Minnowboard Turbot
  * trivial: Make it easy to disable or enable libflashrom for distros
  * trivial: Don't use Recommends for RHEL 7
  * unifying: fix timeout metadata
  * ci: arch: minor improvements
  * unifying: fix timeout
  * Allow disabling SSL strict mode for broken corporate proxies
  * trivial: Allow ignoring the daemon version check by using --force
  * Try to only show DMI product name once
  * trivial: fu-util-common: Show unknown devices as interesting devices
  * dell: Use TSS to query and build TPM vendor strings for GUIDs
  * trivial: dell: show reasons for lack of updates in `UpdateError`
  * fu-util-common: strip all trailing whitespace in XML description
  * trivial: fu-common: match all whitespace not just ' ' in `fu_common_strstrip`
  * fu-util: show release output in get-details again
  * unifying: use fu_firmware_strparse_uint16 to read be 16bit values
  * unifying: fix incomplete hex file parsing
  * fu-util/fu-tool: Print devices, remotes, releases using a tree
  * Add aliases for `get-upgrades` and `upgrade`
  * trivial: UEFI skip self tests if library fails to initialize
  * libfwupd: Add a new private function `fwupd_remote_set_remotes_dir`
  * trivial: add libtss2-dev into debian/control (Closes: #1324)
  * trivial: Fix up the GtkDoc Since lines for API only available in 1.3.x
  * trivial: Post branch version bump
  * thunderbolt: Add support for kernel safety checks (Fixes: #1312)
  * Include the kernel release as a runtime version
  * trivial: fu-util: Drop GUID support from get-devices
  * synapticsmst: Partially rewrite the plugin (Fixes #1105)
  * Remove replug flag after the device comes back from reboot
  * trivial: Fix running the tests on devices with the TPM in v1.2 mode
  * trivial: fu-util-common: more cleanup related to topology
  * trivial: fu-util: cleanup fwupdmgr get-details output
  * trivial: Don't use topology printing in --verbose mode
  * Make get-devices and get-topology aliases for one another
  * trivial: Adjust daemon device sorting
  * Make get-topology more useful by showing all information
  * trivial: Fix fu_common_string_append_kv() to align properly with idx > 0
  * trivial: dell-dock: correct an error preventing write_size from being set
  * trivial: Do not warn about deprecated declarations
  * trivial: Update BRs for the example Fedora package
  * uefi: add test for TPM 2.0 PCR read function
  * uefi: use tpm2-tss library to read PCR values
  * fu-common: Use environment variables for systemd managed directories
  * Use more systemd directives for directories
  * trivial: fu-util: fix debug output for devices
  * Allow turning off the timestamp prefix for debugging
  * Add a ->udev_device_changed plugin vfunc
  * Add fu_device_rescan() and a FuDevice->rescan() vfunc
  * Remove the duplicate files in meson.build
  * Hash the source files when generating the daemon hash
  * Split up source files in the build script
  * uefi: add support for tpm2-tools 4.X
  * trivial: plugins: clarify stance on afuefi.efi
  * trivial: plugins/: Update README
  * trivial: disable gtkdoc by default
  * trivial: update references of hughsie/fwupd to fwupd/fwupd
  * Publish docs to fwupd.github.io using CircelCI
  * Add support to integrate into the motd (Fixes: #1270)
  * Simplify get-devices output to not show un-useful fields
  * fu-engine/fu-config: Reload metadata store when configuration changes
  * trivial: If no devices support updates, show messaging (Closes: #1295)
  * trivial: uefi: set vendor name for system firwmare from DMI data
  * unifying: update Solaar url
  * thunderbolt: Fix logic to work properly with ICL thunderbolt controller
  * Add fu_udev_device_get_device_file() helper
  * trivial: Fix regression when using fu_device_incorporate()
  * trivial: Fix a potential crash when using FuPlugin in the self tests
  * synapticsmst: Make FuSynapticsmstConnection an actual GObject
  * synapticsmst: Use the same style as other plugins
  * trivial: Add some helper functions for GByteArray
  * Do not use FuDevice metadata for the physical and logical IDs
  * Use fu_common_string_append_kv() in subclassed device
  * synapticsmst: Use G_DECLARE_FINAL_TYPE to simplify the object
  * synapticsmst: Add a SynapticsMSTBoardID for another Lenovo dock
  * trivial: remove unnecessary CUSTOMERID_DELL define
  * synapticsmst: Add a SynapticsMSTBoardID for a Lenovo dock
  * synapticsmst: Display the board ID in non-hex form in the error message
  * synapticsmst: Use a more suitable icon for the device
  * trivial: Remove unused variable
  * Never use memcpy() in a possibly unsafe way
  * Add a ->to_string() vfunc to FuFirmware
  * Use FuFirmware as a container for firmware images
  * Allow filtering devices when using the command line tools
  * Be more accepting when trying to recover a failed database migration
  * trivial: Add translation for X-ThunderboltController
  * trivial: fixup standalone installer
  * modem-manager: add counterpart GUID for the DW5821e
  * solokey: Release the interface and rebind the kernel driver on close
  * fu-tool: Port ability to update a single device from fwupdmgr
  * uefi: Actually write the new device path if different than before
  * Allow setting custom flags when using fwupdate
  * trivial: Do not show a critical warning if no firmware is specified
  * trivial: Fix overzealous search-replace action in user string
  * Verify we don't break the ABI
  * Fix a crash when stopping the fwupd service
  * Relax the certificate time checks in the self tests for the legacy certificate
  * trivial: add cache directory into systemd unit rw paths
  * Never show AppStream markup on the console
  * Do not segfault when trying to quit the downgrade selection
  * trivial: Update icons for Thunderbolt and MST devices
  * Add support for the SoloKey Secure
  * trivial: Allow a device to *clear* a firmware version
  * trivial: debian: For signed package fill out Built-Using (Closes: #932757)
  * Allow specifying <firmware>GUID</firmware> to check any version exists
  * trivial: post release version bump
  * Release fwupd 1.2.10
  * Disable the flashrom plugin by default
  * trivial: thunderbolt: catch failure setting up device
  * dell-esrt: Improve the experience for the plugin (Closes: #1245)
  * fu-util: When unlocking prompt for reboot if applicable
  * remove those PIDs with Bluetooth interface, Wacom updater doesn't support updating from Bluetooth interface
  * flashrom: Only show DEBUG and DEBUG2 output if using --plugin-verbose=flashrom
  * flashrom: Only call flashrom_programmer_init() on whitelisted boards
  * flashrom: Fix no version format set
  * fu-util: Show devices with an UpdateError in get-devices output
  * trivial: uefi: use UEFI-dummy for device ID instead of just uefi
  * trivial: fix error handling for non UEFI case (#1220)
  * Add a specific error code for the low battery case
  * Fix Fedora docker build missing directory: dist
  * uefi: Determine whether running in legacy mode or not (Fixes: #1220)
  * trivial: ci: debian: Only turn on flashrom when running CI
  * trivial: Fix typos in error messages
  * Allow client code to construct objects from GVariant blobs
  * Export functionality to build an array of objects
  * flashrom: Use libflashrom
  * trivial: Fix the version script to pick up boxed types
  * trivial: Correctly order the map entries according to vercmp rules
  * trivial: Fix pylint issue in the version script
  * Add meson target to fix translations
  * Add support for 8bitdo USB Retro Receiver
  * Use the newer features of GRWLock rather than reinventing it
  * Revert "Allow SuperIO updates to be done live"
  * uefi: Try to find a duplicate using the loadopt name
  * uefi: Provide a quirk to disable the use of the UX capsule
  * trivial: uefi: use the path for efibootmgr that was detected
  * synaptics-prometheus: Fix installing CONFIG firmware updates
  * synaptics-prometheus: Set the install duration from a quirk
  * synaptics-prometheus: Don't emit critial warning when updating config firmware
  * synaptics-prometheus: Fix missing field in the IOTA reply struct
  * Create SECURITY.md
  * redfish: Never set NULL device name
  * modem-manager: Never set NULL device name
  * ata: Never set NULL device name
  * trivial: Add some parameter guards to FuDevice
  * trivial: snap: make polkit directories if they don't exist (Fixes: #1205)
  * trivial: fu-main: clarify missing PK file error
  * synapticsmst: fix GUID generation (Closes: #1207)
  * Lite Mk II flag for use-shim-unique
  * trivial: circleci: try to fix automatic snap deployment
  * Allow SuperIO updates to be done live
  * fu-util-common: Support empty proxy strings (Fixes: #1199)
  * trivial: uefi: clarify error message
  * trivial: Fix non-systemd build
  * trivial: Sync example spec file with downstream
  * trivial: post release version bump
- Drop fwupd-bsc1143905-hash-the-source-files.patch: Applied upstream.
- Add pkgconfig(tss2-esys) BuildRequires: New dependency.
- Add gtk-doc BuildRequires and pass gtkdoc=true to meson, build
  api docs even when using source service.
* Mon Aug 26 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add fwupd-bsc1143905-hash-the-source-files.patch to hash the
  source files instead of libfwupdprivate.a to avoid the checksum
  change due to the random naming LTO profile sections
  (bsc#1143905)
* Wed Jul 24 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to version 1.2.10:
  * Disable the flashrom plugin by default
  * dell-esrt: Improve the experience for the plugin (Closes: #1245)
  * fu-util: When unlocking prompt for reboot if applicable
  * remove those PIDs with Bluetooth interface, Wacom updater
    doesn't support updating from Bluetooth interface
  * flashrom: Only show DEBUG and DEBUG2 output if using
  - -plugin-verbose=flashrom
  * flashrom: Only call flashrom_programmer_init() on whitelisted
    boards
  * flashrom: Fix no version format set
  * fu-util: Show devices with an UpdateError in get-devices
    output
  * Add a specific error code for the low battery case
  * Fix Fedora docker build missing directory: dist
  * uefi: Determine whether running in legacy mode or not
    (Fixes: #1220)
  * Allow client code to construct objects from GVariant blobs
  * Export functionality to build an array of objects
  * flashrom: Use libflashrom
  * Add meson target to fix translations
  * Add support for 8bitdo USB Retro Receiver
  * Use the newer features of GRWLock rather than reinventing it
  * uefi: Try to find a duplicate using the loadopt name
  * uefi: Provide a quirk to disable the use of the UX capsule
  * synaptics-prometheus: Fix installing CONFIG firmware updates
  * synaptics-prometheus: Set the install duration from a quirk
  * synaptics-prometheus: Don't emit critial warning when updating
    config firmware
  * synaptics-prometheus: Fix missing field in the IOTA reply struct
  * Create SECURITY.md
  * redfish: Never set NULL device name
  * modem-manager: Never set NULL device name
  * ata: Never set NULL device name
  * synapticsmst: fix GUID generation (Closes: #1207)
  * Lite Mk II flag for use-shim-unique
  * fu-util-common: Support empty proxy strings (Fixes: #1199)
- Add python3-setuptools to BuildRequires for
  generate-version-script.py
* Tue Jun 25 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.2.9:
  * Release fwupd 1.2.9
  * trivial: Add two new translatable strings for new category types
  * Check if the system is offline during install, rather than at startup
  * Prompt the user to shutdown if requried when installing by ID
  * Use the correct file extension for the offline updates cache
  * trivial: Allow using --force to use the wrong daemon version
  * trivial: Display the correct expected command
  * standalone-installer: Be smarter about existing installed fwupd
  * Add a plugin to update Synaptics Prometheus fingerprint readers
  * trivial: standalone-installer: rename uninstall argument to cleanup
  * fu-util: Check the daemon version is at least the client version
  * fu-util: Check that daemon is started by expected unit
  * fu-util-common: when stopping a daemon, check for snap too
  * Allow using --force to trigger a duplicate offline update
  * trivial: Allow using FuUsbDevice without a GUsbDevice
  * trivial: Copy the icons if unset for the device child
  * trivial: Copy the physical ID if unset for the device child
  * trivial: Ensure the parent ID is up to date if the device ID changes
  * trivial: Fix typo when setting the parent ID
  * trivial: Disable the flatpak CI build
  * Allow handling FORCE for devices that subclass FuDevice
  * uefi: Fix a libasan failure when reading a UEFI variable
  * trivial: Fix a memory leak found using libasan
  * trivial: Fix an libasan failure in the dell plugin
  * trivial: Fix some dead code spotted by coverity
  * trivial: Fix a typo spotted by coverity
  * trivial: Fix a missing config.h include in a new source file
  * Dynamically read path to use for /system-update
  * Display the remote warning on the console in an easy-to-read way
  * ata: Set version format to plain for devices obtained from udev
  * trivial: Only apply SmbiosManufacturer to release version for internal
  * trivial: Fix two bugs in the hardware self tests script
  * Never guess the version format from the version string
  * Only force a semver when the device opts-in
  * Export the version-format to clients
  * Add missing gtk-doc documentation
  * dfu: Add some trivial, but useful, debugging for AVR DFU devices
  * dfu: Correctly identify DFU firmware that starts at offset zero
  * dfu: Don't keep showing trivial debug output
  * dfu: Reset the forced version during attach and detach
  * ata/nvme: For devices running Dell firmware, set `VersionFormat` (Fixes: #1169)
  * fu-engine: Check if VersionFormat is ambiguous when adding devices
  * trivial: Fix fwupdate --apply
  * Only use class-based instance IDs for quirk matching
  * trivial: dell-dock: set minimum board to 6
  * trivial: post release version bump
* Wed May  8 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.2.8:
  * Don't upload reports when the user has configured their system in a broken way
  * Allow setting the daemon verbose domains at runtime
  * Allow fwupdmgr to modify the daemon config
  * Do not compare version formats when the release format is unknown
  * Do not fall back integers to a plain version format
  * Use the device version format when converting the release version
  * Set the VersionFormat using the metadata or the UEFI quirk
- Changes from version 1.2.7:
  * l10n: Create Lithuanian translation file
  * l10n: Update LINGUAS
  * Updated: Add support for 8BitDo M30.
  * modem-manager: increase the timeout to wait for modem after uninhibited
  * modem-manager: implement qmi pdc active config selection as attach()
  * fu-engine: When removing activation flag match the correct version
  * Require --force to install a release with a different version format
  * Match the old or new version number when setting NEEDS_REBOOT
  * Make an error message clearer when there are no updates available
  * Add support for the not-child extension from Logitech
  * thunderbolt: Set require-ac for Thunderbolt devices
    (Fixes: gh#hughsie/fwupd#1142)
  * Fix some typos spotted using codespell
  * Add a component categories to express the firmware type
  * fu-tool: Port get-history command to fwupdtool
  * Recreate the history database if migration failed
  * Move the core built-in 'fwupd' remote over to the dell-esrt plugin
  * snap: Add a custom systemd unit to call activation on shutdown
    (Fixes: gh#hughsie/fwupd#1125)
  * ata: Flush cache before standby and activate
  * synapticsmst: blacklist plugin when using amdgpu
    (Fixes: gh#hughsie/fwupd#1121)
  * uefi: add a new option to specify the os name
  * Return the newest device when using fu_history_get_device_by_id()
  * uefi: More carefully check the output from tpm2_pcrlist
  * uefi: Don't overwrite CustomFlags if set from a quirk
  * Shut down the daemon if the on-disk binary is replaced
  * ata: Correct activation functionality
  * Fix version comparisons after reboot for some formats
  * fu-tool: save history from stuff installed with `fwupdtool`
- Changes from version 1.2.6:
  * ata: send ATA standby immediate when activating firmware
  * offline: Be more graceful when dealing with Plymouth failures
  * Save the new version in the history database for offline updates
  * Show the DeviceID when showing the updates list
  * Allow forcing an offline-only update on a live system using --force
  * Do not schedule an update on battery power if it requires AC power
  * superio: Add InstallDuration default value
  * superio: Add support for writing new e-flash contents
  * superio: Fix reading the attestation checksum
  * superio: Add support for reading the device checksum
  * superio: Use the chipset ID in the device name
  * superio: Move the device flush before getting the register map
  * superio: Move all the IT89xx code to a subclassed device object
  * superio: Move all the IT85xx code to a subclassed device object
  * superio: Split and export fu_superio_device_ec_writeX()
  * superio: Remove the port from fu_superio_device_ec_read()
  * superio: Move the register read/write into the FuSuperioDevice object
  * superio: Check the IOBAD0 is usable during setup
  * superio: Use fu_device_set_firmware_size()
  * superio: Move some constants out to the common header
  * superio: Use GObject properties in FuSuperioDevice
  * superio: Convert FuSuperioDevice to be derivable
  * Update Plymouth when updating pending firmware
  * Ask to reboot after scheduling an offline firmware update
  * Do not fail when scheduling more than one update to be run offline
  * Allow running offline updates when in system-update.target
  * Fix the location of fwupdoffline in the service file
  * Add optional vfuncs to allow detaching and attaching verify()
  * superio: Add list of SPI commands for future usage
  * Add a verify-update command to fwupdtool
  * uefi: Actually upload the UPDATE_INFO entry for the UX capsule
  * superio: Get the chip size from the EC rather than hardcoding
  * uefi: Check the error code of QueryCapsuleCapabilities() correctly
  * Update the UEFI UX Capsule Header checksum when needed.
  * uefi: Copy the shimx64.efi binary for known broken firmware
  * Correctly get the check the new version for devices that replug
  * Add a simple script to add a capsule header
  * Ensure the PKCS-7 client certificate exists at startup
  * fix makecab directive options
  * fwpup.service: use display-manager.service instead of gdm.service
  * Allow signing the fwupd report with the client certificate
  * Add a D-Bus method to generate a signature using the self-signed client certificate
  * Allow signing and verifying data using a PKCS-7 self-signed client certificate
  * Fix a critical warning when loading a PKCS-7 certificate with no DN
  * Include all device checksums in the LVFS report
  * modem-manager: Fix a trivial build warning
  * superio: Fix a trivial build warning
  * Move out the offline update functionality to a new binary
  * Do not reboot when failing to start fwupd during offline updates
  * Do not write the schema version to the db when loading
  * Do not recreate XbSilo caches when running on a readonly filesystem
  * Add the fwupdagent binary for use in shell scripts
  * Allow restricting firmware updates for enterprise use
  * standalone-installer: new --allow-older and --allow-reinstall options
  * Show the upgrade and downgrade flags when getting releases for a device
  * Rename FwupdRelease:trust-flags to FwupdRelease:flags
  * fu-tool: Save device state to @LOCALSTATEDIR@/lib/fwupd/state.json on actions
  * modem-manager: implement support for qmi-pdc
  * Add a plugin to support ModemManager hardware
  * fu-tool: Don't let failing to find dbus prevent engine from starting
  * ata: Support delayed activation
  * dell-dock: Use activation when calling fwupdtool activate
  * Add a support for delayed activation
  * uefi: Fix the self tests when running on Fedora SilverBlue
  * Do not fail to start the daemon if tpm2_pcrlist hangs
  * po/make-images.sh: quote LOCALEDIR and PYTHON3
  * meson: print stderr of python3 command instead of stdout
  * Revert "contrib/debian: Switch to debian unstable"
  * Add elogind support
  - Changes from version 1.2.5:
  * uefi: fix segfault in fwup_set_update_statuses
  * Show in Flathub correctly
  * debian: explicitly depend on shared-mime-info
  * superio: Implement detach() and attach()
  * superio: Correct the names of some constants and improve debugging support
  * dell-dock: Filter the last supported payloads of certain board 4 SKUs
  * circleci: Manage the lifecycle of the snap
  * Add support to run snap build in CircleCI
  * wacom-usb: Use the correct buffer format for the touch module
  * wacom-usb: Set the install duration for each device type
  * wacom-usb: Return with an error if there were too many retries
  * wacom-usb: Make updating less verbose
  * Convert all child instance IDs when converting the parent
  * uefi: Allow devices to create more complete fake UEFI devices
  * unifying: Fix regression when recovering from failed flash
  * Ensure libxmlb dir exists for LGTM.com
  * Add C build configuration for LGTM.com
  * Use G_BEGIN_DECLS correctly for internal headers
  * standalone-installer: Fix issue found by LGTM
  * Use '#pragma once' to avoid a lot of boilerplate
  * Force LGTM to see Python 3
  * fwupd: Hide firmware-packager behind meson option`
  * fu-common-cab: Correct handling of CAB files w/ nested directories and older libgcab
  * Fix a regression in using the InstanceIDs for quirk matching
  * thunderbolt: Convert the instance IDs as we never open the device
  * udev: Manally call fu_device_setup() to convert the instance IDs
  * fu-tool: Correct a crash caused by calling fwupdtool update
  * fu-tool: Don't fail if dbus is unavailable
  * contrib/debian: Switch to debian unstable
  * wacom-usb: Record the block number when failing
  * wacom-usb: The touch address is big endian
  * wacom-usb: Accept a non-binary IHEX file for the touch update
  * wacom-usb: Only poll when the device status is 'busy'
  * wacom-usb: Only reboot the device when all composite devices have been updated
  * wacom-usb: Fix flashing failure with latest Intuos Pro tablet
  * dfu: Fill holes when reading SREC files
  * Add fwupd_guid_from_string() to drop dep on uuid
  * wacom-raw: Check the InstanceID rather than GUID
  * Defer the InstanceID->GUID hashing until after setup
  * ata: Check for USB enclosures as well
  * Do not use efivar just to print a mixed endian GUID
  * Add fu_device_add_instance_id() and prefer explicit conversion
  * Report the DeviceInstanceIDs to `fwupdmgr get-updates`
  * Export some of the GUID functionality
  * Allow a plugin to set _ANOTHER_WRITE_REQUIRED to run more than one plugin
  * nvme: Add an extra check for Dell plugins to avoid false positives
  * ata: Add support for detecting Dell GUIDs
  * Fix the self tests when using glib2 >=2.59.0
  * Add support to call composite prepare and cleanup using fwupdtool
  * uefi: Disable -Wno-address-of-packed-member
  * uefi: Don't unconditionally enable Werror for the EFI binary
  * Disable -Wno-address-of-packed-member
- Changes from version 1.2.4:
  * Remove the autogenerated headers in the gettext files
  * ata: Default to the non-activation 0xE subcommand
  * fastboot: Use a much longer timeout as the removal delay
  * fu-progressbar: be more quiet when running non-interactive
  * fu-tool: Show UpdateMessage if applicable for install command
  * dfu: Simplify the SREC parser to avoid a crash with an invalid file
  * wacom-raw: Use the correct error codes when the panel is not supported
  * wacom-usb: Add some more information to the README
  * fu-keyring-utils: Don't fail missing PKI directory when compiled with GPG/PKCS7
  * dell: Check that the flash interface command is available
  * wacom-usb: Fix the plugin name to allow devices to be updated
  * fastboot: flash the partition after downloading the file
  * uefi: Add a quirk to use the legacy bootmgr description
  * ata: Mark all devices as needing a reboot
  * ata: Add a new plugin to upgrade firmware on ATA/ATAPI hardware
  * udev-device: Add a utility function for debugging
  * udev-device: Set the firmware revision automatically
  * udev-device: Set the serial number automatically
  * udev-device: Fall back to non-database model and vendor values
  * udev-device: Fix critical warning if the device has no parent
  * dell-dock: Add support for a passive flow
  * Add support for an `UpdateMessage` and display it in tools
  * fu-tool: Port the `get-updates` command over
  * When using `directory` remote type automatically generate metadata
  * libfwupd: Add support for new remote type "directory"
  * Ensure cabinet archives always have a container checksum
  * Add support for a per-release source and details URL
  * When generating a CAB Silo use the prefix "components"
  * uefi: Add a trivial debugging statement to debug a UX capsule failure
  * uefi: Use fwup_new0() to allocate the updates table array
  * nitrokey: Correct Nitrokey Storage invalid firmware version read
  * dell-dock: Add support for flashing Thunderbolt over I2C
  * wacom-raw: Add a plugin to update Wacom embedded EMR and AES panels
  * fu-util/fu-tool: sync up reboot and shutdown behavior
  * dfu: Ignore the SUB ASCII value
  * dfu: Fix the parser to support extended segment addresses
  * dfu: Support ihex files with leading comments
    don't show an error
  * uefi: Correct a boot order creation bug (Fixes: gh#hughsie/fwupd#956)
  * uefi: Remove all variable length arrays
  * uefi: Fix a logic bug in fwup_search_file()
  * uefi: Use _cleanup_free in one more place
  * uefi: Do not pass required attrs to fwup_delete_variable()
  * uefi: Delete the old Linux-Firmware-Updater boot entry
  * uefi: Use the GNU-EFI BOOL type
  * Check if plugin changed after the device attaches or detaches
  * uefi: Refactor and simplify the EFI loader
  * Show a console warning if loading an out-of-tree plugin
  * UEFI: Do the UX checksum calculation in fwupd
  * wacom-usb: Add two more Intuos tablets
  * nvme: Add the needs-shutdown quirk to Phison NVMe drives
  * Add _NEEDS_SHUTDOWN flag for devices
  * Use GCC __cleanup__ features in the EFI loader
  * nvme: Add flag to support manually aligning the firmware to the FWUG value
  * nvme: Support FGUID to get the SKU GUID
  * nvme: Support FWUG to get the write block size
  * nvme: Add trivial comment to clarify address bitshifting
  * uefi: Do not check the BGRT status before uploading a UX capsule
  * dfu: Fix flashing various Jabra devices
  * upower: Add support for checking battery percentage
  * nvme: Check the return code of the admin passthru ioctl
  * fu-tool: Add support for an 'update' command to fwupdtool
  * dell-dock: Set minimum board to board 4
  * dell-dock: Workaround a manufacturing bug for board level 4
  * dell-dock: Wait longer for re-enumeration on TBT SKU
  * superio: Support IT89xx devices
  * fu-main: remove incompatible locale error message
  * Add a new plugin checklist (Fixes: gh#hughsie/fwupd#899)
- Dropped obsolete patch: fwupd-bsc1130056-change-esp-os-name.patch
  (upstream PR: gh#hughsie/fwupd#1119
- Fixed fwupd-bsc1130056-change-shim-path.patch so that it works
  with the new files
- Cleaned up changelog
* Fri May  3 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Stop shipping polkit rules, as we have the distro specific setup
  in polkit-default-privs (boo#1125428).
* Thu Mar 28 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add fwupd-bsc1130056-change-esp-os-name.patch to change the
  OS directory in ESP (bsc#1130056)
- Add fwupd-bsc1130056-change-shim-path.patch to set the default
  shim binary for openSUSE/SLE (bsc#1130056)
- Link fwupd*.efi.signed to fwupd*.efi as requested by fwupd
  (bsc#1129466)
* Tue Feb  5 2019 Bernhard Voelker <mail@bernhard-voelker.de>
- fwupd.spec: fix shell syntax error in %%postun section (boo#1120363).
* Thu Jan 10 2019 bjorn.lie@gmail.com
- Update to version 1.2.3:
  * Correctly migrate the history database
- Changes from version 1.2.2:
  * Log an error if started with an incompatible locale
  * Fix building with -Wl,-z,defs
  * ebitdo: Fix the reported version number if the daemon locale is
    not C.UTF-8
  * Add Dell TB18DC to the known devices list
  * Allow replacing the last byte in the image when using 'dfu-tool
    replace-data'
  * Check the device checksum as well as the content checksum
    during verify
  * Submit the device firmware checksum and update protocol in the
    submitted report
  * Include the device checksum and update protocol in the
    historydb
  * uefi: Add the PCR0 value as the device checksum for system
    firmware
  * Add new API to get the release protocol from the metadata
  * Allow plugins to define support for a 'well-known' protocol
  * uefi: When adding headers set the header size to 4k
  * uefi: Append the header on capsules without headers from Linux
  * flashrom: Ensure the quirks database is set on the new object
  * uefi: Do not add devices with invalid GUIDs
  * Do not allow a GUID of zero
  * Add shared functionality for reading and writing with
    O_NONBLOCK
  * Only run attach and detach if the device is in the wrong mode
  * Sanitize the version if the version format has been specified
  * wacom-usb: Remove the DTH generation hardware as it will not
    work with fwupd
  * thunderbolt: Remove a superfluous boundary condition when
    verifying update
  * Add a plugin to update hardware that supports fastboot
  * Fix a regression when doing GetReleases on unsupported hardware
  * dfu: Require a specific USB class and subclass for DFU mode
  * Correctly parse format the version numbers correctly using old
    metadata
  * amt: Fix a crash if AMT returns an empty response
  * Check plugins set error on failure
  * contrib: Add a simple python3 client
  * installed-tests: Adjust to actually use a remote for installed
    tests
  * Add more standard USB identifier GUIDs
  * wacomhid: Rename to wacom-usb
  * Provide a way for plugins to decompress a custom archive to ram
- Changes from version 1.2.1:
  * Remove DaemonVersionFormat=quad
  * Shut down the daemon after 2h of inactivity
  * Create a silo index to speed up GUID queries
  * Fix flashing the 8bitdo SF30
  * Speed up fwupd startup by loading less thunderbolt firmware
  * Query the XbSilo when calling fu_plugin_check_supported()
  * Guess the version format when it is not provided
  * Fix a use-after-free when using valgrind and --immediate-exit
  * Add per-release install duration values
  * Fix showing the custom remote agreements
  * Be more explicit setting the update state
  * Include the os-release information in the release metadata
- Changes from version 1.2.0:
  * ebitdo: remove SF30/SN30 pro device ids
  * dell-dock: Drop delayed MST callback routine
  * synapticsmst: Adjust EVB board handling
  * synapticsmst: Remove the content checking of firmware
  * synapticsmst: Access Board ID through memory instead In
    firmware images HDCP 2.2 will be enabled by default,so access
    to flash region will fail.`
  * contrib: Adjust flatpak build for moving to flathub
  * dell-dock: Prefer to flash VMM5331 via I2C instead of DP aux
  * Use HTTPS_PROXY if set
  * firmware-packager: Make it clearer to use
  * Sort the firmware sack by component priority
  * flatpak: Update gnu-efi to latest version
  * amt: Set the full device version including the BuildNum
  * fwupdmgr/fwupdtool: Move monitor command to fwupdtool
  * fwupdmgr/fwupdtool: Move firmware builder from fwupdmgr to
    fwupdtool
  * Add version format quirks for several Lenovo machines
  * uefi: Set the quirks on created devices
  * dell_dock: Use correct offset for finding version of MST
  * dell-dock: Add missing unlock call for MST via dell_dock plugin
  * Support the Intel ME version format
  * Port from libappstream-glib to libxmlb
  * Bump requirement to meson 0.46.0
  * fu-main: Catch SIGTERM while update is in progress
  * fu-tool: Stop any running daemon over dbus before loading
    engine
  * meson: Bump dependency to 0.44 and adjust sysconfdir handling
  * dell-dock: If marketing name is invalid don't fail
    initialization
  * Readme Updated: Added KDE Discover as one more graphical
    front-end available for fwupd.
  * dell-dock: Correct a situation that error wasn't propagating
  * Don't segfault if a plugin returns FALSE from UpdateFunc with
    no error set
  * dell-dock: Use different debug strings for each device type
  * dell-dock: Don't use the VLA feature in the new dock
  * Add a plugin for an upcoming Dell USB-C dock
  * contrib: Add information on how to use debugging scripts
  * Allow setting the version format from a quirk entry
  * Don't use AppStream-glib for string helpers
  * Don't use AppStream-glib for version helpers
  * Don't use AppStream-glib for the GUID helpers
  * fu-device: Ensure that parent ID is created before creating
    quirked children
  * Update all sub-devices for a composite update
  * Stop showing the current release during updates in fwupdmgr
  * uefi: Move the TPM unlocking functionality from the Dell to
    UEFI plugin
  * Run the Dell plugin initialization after the UEFI plugin
  * thunderbolt-power: Fix possible linker problem
  * Allow firmware files to depend on versions from other devices
  * fu-debug: Redirect all debugging output to stderr instead of
    stdout
  * synapticsmst: Adjust panamera ESM update routine for some
    reported issues
  * fu-engine: Optionally wait for replug before updating a device
  * fu-device-list: Use delayed device removal when removing the
    tree
  * thunderbolt: Use replugging from the daemon
  * Add support for devices to show an estimated flash time
  * Marked some CL options for translation
  * ci: Run clang static analysis for Ubuntu build rather than just
    clang compiler
  * nvme: Initialize the buffer before reading the contents
  * contrib: Add a standalone installer creation script
  * rts54hid: Add support for Realtek USB devices using vendor HID
    commands
  * fu-engine: Don't show devices pending a reboot in GetUpgrades
  * Add FuMutex helper to make various parts of the daemon
    thread-safe
  * rts54hub: Add support for Realtek USB devices using vendor HUB
    commands
  * uefi: Check the amount of free space on the ESP
  * fu-tool: Import debugging options from fu-debug like fu-main
  * superio: Set the physical and logical IDs
- Add pkgconfig(xmlb) BuildRequires: New dependency.
* Tue Dec 11 2018 Gary Ching-Pang Lin <glin@suse.com>
- Add pesign-obs-integration to BuildRequires and add fwupd*.efi to
  BRP_PESIGN_FILES to get it signed
- Add LC_IMAGES and use efivar only if %%{with efi_fw_update}
  + Also update the version requirement of efivar
- Disable Redfish and NVME plugins if %%{without efi_fw_update}
  since those two plugins require efivar
- Remove fwup from BuildRequires since fwupdate is already merged
  into fwupd.
* Mon Dec 10 2018 schwab@suse.de
- Use gnu-efi only if %%{with efi_fw_update}, always use pkgconfig(efivar)
- Fix file list
* Thu Dec  6 2018 Gary Ching-Pang Lin <glin@suse.com>
- Amend %%post and %%postun to install/uninstall fwupd*.efi to the
  EFI system partition
  + Also add shim to Requires for fwupdx64.efi
- Mark fwupdate as obsolete
  + fwupdate has been merged into fwupd since fwupd 1.1.0.
* Mon Nov 12 2018 ndas@suse.de
- fwupd is require for thunderbolt firmware update in SLE15-SP1(fate#322681)
* Thu Sep 13 2018 Nico Kruber <nico.kruber@gmail.com>
- Update to version 1.1.2:
  + New Features:
  - Add a new device flag "ignore-validation" that will override checks
  - Add a new plugin to enumerate EC firmware
  - Add a new plugin to update NVMe hardware
  - Add a plugin for updating using the flashrom command line tool
  - Allow the device list to take care of waiting for the device replug
  - Allow updating just one specific device from the command line
  - Allow upgrades using a self-signed fwupd.efi binary
  - Download firmware if the user specifies a URI
  - Include serial number in daemon device output when trusted
  - Notify all plugins of device removals through a new vfunc
  - Use boltd force power API if available
  + Bugfixes:
  - Add an install hook for classic snap
  - Allow forcing installation even if no AC power is applied
  - Allow using --force to ignore version_lowest
  - Always use the same HardwareIDs as Windows
  - Check the device state before assuming a fake DFU runtime
  - Copy over parent GUIDs from other plugin donors
  - Detect location of python3 interpreter
  - Do not add udev devices after a small delay
  - Don't fail to run if compiled without GPG/PKCS7
  - Fix a segfault in fwupdtool caused by cleanup of USB plugins
  - Implement the systemd recommendations for offline updates
  - Improve performance when reading keys from the quirk database
  - Remove children of devices when the parent is removed
  - Rewrite synapticsmst to use modern error handling
  - Rewrite the unifying plugin to use the new daemon-provided functionality
  - Show a time estimate on the progressbar after an update has started
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summary. Trim request for comments from
  description.
* Fri Sep  7 2018 Nico Kruber <nico.kruber@gmail.com>
- Update to version 1.1.1:
  + New Features:
  - Add support for the Synaptics Panamera hardware
  - Add validation for Alpine and Titan Ridge
  - Improve the Redfish plugin to actually work with real hardware
  + Bugfixes:
  - Allow different plugins to add the same device
  - Allow flashing unifying devices in recovery mode
  - Allow running synapticsmst on non-Dell hardware
  - Check the ESP for sanity at at startup
  - Do not hold hidraw devices open forever
  - Don't override _FORTIFY_SOURCE when building the EFI binary
  - Don't show passwords in fwupdmgr
  - Fix a potential segfault in smbios data parsing
  - Fix encoding the GUID into the capsule EFI variable
  - Fix various bugs when reading the thunderbolt version number
  - Reboot synapticsmst devices at the end of flash cycle
  - Show status messages when the daemon is initializing
  - Show the correct title when updating devices
  - Show the reasons that plugins are not run on the CLI
  - Use localedir in po/make-images
* Wed Jul 25 2018 tchvatal@suse.com
- Run %%udev_rules_update in post as package install udev rules
* Thu Jul 12 2018 oliver@getspam.de
- Update to version 1.1.0: (FATE#326702)
  + New Features:
  - Add a initial Redfish support
  - Add a tool to mimic the original fwupdate CLI interface
  - Allow devices to assign a plugin from the quirk subsystem
  - Change the quirk file structure to be more efficient
  - Merge fwupdate functionality into fwupd
  - Run a plugin vfunc before and after all the composite devices are updated
  - Support more Wacom tablets
  + Bugfixes:
  - Add release information for locked devices
  - Allow building with older meson
  - Detect the EFI system partition location at runtime
  - Do not use 8bitdo bootloader commands after a successful flash
  - Enable accesing downloaded files in flatpak and snap
  - Fix a potential buffer overflow when applying a DFU patch
  - Fix downgrading older releases to devices
  - Fix flashing devices that require a manual replug
  - Fix several small memory leaks in various places
  - Fix the retrieval of Redfish version
  - Fix unifying failure to detach when using a slow host controller
  - Set the Wacom device status when erasing and writing firmware
  - Show errors in the CLI if unable to access directory
  - Use the parent device name for Wacom sub-modules
- Removed enable_pkcs7_when_testing_only.patch
* Wed Jul 11 2018 oliver@getspam.de
- Update to version 1.0.8:
  + New Features (including version 1.0.7):
  - Add an plugin to update some future Wacom tablets
  - Add 'fwupdmgr get-topology' to show logical device tree
  - Add support for creating a flatpak
  - Add support for creating a snap
  - Add support for Motorola S-record files
  - Add the Linux Foundation public GPG keys for firmware and metadata
  - Show a translated warning when the server is limiting downloads
  - Add enable-remote and disable-remote commands to fwupdmgr
  - Add fu_plugin_add_compile_version() for libraries to use
  - Allow requiring specific versions of libraries for firmware updates
  - If no remotes are enabled try to enable the LVFS
  - Show a warning with interactive prompt when enabling a remote
  + Bugfixes (including version 1.0.7):
  - Add a firmware diagnostic tool called fwupdtool
  - Adjust all licensing to LGPL 2.1+
  - Allow installing more than one firmware using 'fwupdmgr install'
  - Allow specifying hwids with OR relationships
  - Do not call fu_plugin_init() on blacklisted plugins
  - Do not require libcolorhug to build
  - Fix a crash in libfwupd where no device ID is set
  - Fix a potential DoS in libdfu by limiting holes to 1MiB
  - Fix a segfault that sometimes occurs during cleanup of USB plugins
  - Fix Hardware-ID{0,1,2,12} compatibility with Microsoft
  - Hide devices that aren't updatable by default in fwupdmgr
  - Search all UEFI GUIDs when matching hardware
  - Stop matching Nintendo Switch Pro in the 8bitdo plugin
  - Check that EFI system partition is mounted before update
  - Disable synapticsmst remote control on failure
  - Don't recoldplug thunderbolt to fix a flashing failure
  - Fix SQL error when running 'fwupdmgr clear-offline'
  - Improve the update report message
  - Only enumerate Dell Docks if the type is known
  - Only run certtool if a new enough gnutls is present
  - Prevent a client crash if the daemon somehow sends invalid data
  - Reboot after scheduling using logind not systemd
  - Use the right encoding for the label in make-images
- Added/backported enable_pkcs7_when_testing_only.patch:
  + needed to disable pkcs7 test during build (can be removed for
    fwupd >= 1.0.9)
* Wed Apr  4 2018 dimstar@opensuse.org
- Update hasbang in installed files from /usr/bin/env python3 to
  /usr/bin/python3.
* Tue Apr  3 2018 mpluskal@suse.com
- Update url
- Small packaging cleanup with spec-cleaner
* Fri Mar 23 2018 antoine.belvire@opensuse.org
- Update to version 1.0.6:
  + New Features:
  - Add bash completion for fwupdmgr.
  - Add support for newest Thunderbolt chips.
  - Allow all functions that take device arguments to be
    prompted.
  - Allow devices to use the runtime version when in bootloader
    mode.
  - Allow overriding ESP mount point via conf file.
  - Delete any old fwupdate capsules and efivars when launching
    fwupd.
  - Generate Vala bindings.
  + Bugfixes:
  - Allow ctrl-d out of the prompt for devices.
  - Allow to create package out of provided binary.
  - Correct handling of unknown Thunderbolt devices.
  - Correctly detect new remotes that are manually copied.
  - Fix a crash related to when passing device to downgrade in
    CLI.
  - Fix running the self tests when no fwupd is installed.
  - Fix Unifying signature writing and parsing for Texas
    bootloader.
  - Only send success and failure reports to the server.
  - Use a CNAME to redirect to the correct CDN for metadata.
  - Use a longer timeout when powering back the Thunderbolt
    device.
* Thu Mar 15 2018 fcrozat@suse.com
- Ensure library package has a dependency on main package,
  otherwise it won't be usable.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 1.0.5:
  + New Features:
  - Offer to reboot when processing an offline update.
  - Report the efivar, libsmbios and fwupdate library versions.
  - Report Thunderbolt safe mode and SecureBoot status.
  - Show the user a URL when they report a known problem.
  - Support split cabinet archives as produced by Windows Update.
  + Bugfixes:
  - Be more careful deleting and modifying device history.
  - Clarify which devices don't have upgrades.
  - Ensure the Thunderbolt version is xx.yy.
  - Fix a daemon warning when using fwupdmgr get-results.
  - Fix crasher with MST flashing.
  - Fix DFU detach with newer releases of libusb.
  - Include the device VID and PID when generating the device-id.
  - Set the RemoteId when using GetDetails.
  - Stop matching 8bitdo DS4 controller VID/PID.
  - Use help2man for dfu-tool and drop docbook dependencies.
  - Use ngettext for any strings with plurals.
  - Use the default value if ArchiveSizeMax is unspecified.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 1.0.4:
  + New Features:
  - Add D-Bus methods to get and modify the history information.
  - Allow the user to share firmware update success or failure.
  - Ask the user to refresh metadata when it is very old.
  - Store firmware update success and failure to a local
    database.
  + Bugfixes:
  - Add a device name for locked UEFI devices.
  - Allow each plugin to opt-in to the recoldplug action.
  - Fix firmware downloading using gnome-software.
  - Fix UX capsule reference to the one specified in efivar.
  - Never add two devices to the daemon with the same ID.
  - Rescan supported flags when refreshing metadata.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 1.0.3:
  + New Features:
  - Add a new plugin to add support for CSR "Driverless DFU".
  - Add initial SF30/SN30 Pro support.
  - Support AppStream metadata with relative <location> URLs.
  + Bugfixes:
  - Add more metadata to the user-agent string.
  - Block owned Dell TPM updates.
  - Choose the correct component from provides matches using
    requirements.
  - Do not try to parse huge compressed archive files.
  - Fix a double-free bug in the Udev code.
  - Handle Thunderbolt "native" mode.
  - Use the new functionality in libgcab >= 1.0 to avoid writing
    temp files.
* Thu Dec 21 2017 stefan.bruens@rwth-aachen.de
- Unbreak compilation on non-x86, upstream renamed options to disable
  plugins.
* Tue Dec 19 2017 fcrozat@suse.com
- Update to version 1.0.2:
  + Add a plugin for the Nitrokey Storage device
  + Add support for the original AVR DFU protocol
  + Allow different plugins to claim the same device
  + Allow quirks to set common USB properties
  + Move a common plugin functionality out to a new shared object
  + Optionally delay the device removal for better replugging
  + Set environment variables to allow easy per-plugin debugging
  + Use a SHA1 hash for the internal DeviceID
  + Add quirk for AT32UC3B1256 as used in the RubberDucky
  + Disable the dell plugin if libsmbios fails
  + Don't register for USB UDev events to later ignore them
  + Fix a possible buffer overflow when debugging ebitdo devices
  + Fix critical warning when more than one remote fails to load
  + Fix DFU attaching AVR32 devices like the XMEGA
  + Ignore useless Thunderbolt device types
  + Refactor ColorHug into a much more modern plugin
  + Release the Steelseries interface if getting the version failed
  + Remove autoconf-isms from the meson configure options
  + Show a nicer error message if the requirement fails
  + Sort the output of GetUpgrades correctly
- Changes from version 1.0.1:
  + Add support for HWID requirements
  + Add support for programming various AVR32 and XMEGA parts using DFU
  + Add the various DFU quirks for the Jabra Speak devices
  + Allow specifying the output file type for 'dfu-tool read'
  + Move the database of supported devices out into runtime loaded files
  + Support the IHEX record type 0x05
  + Use help2man to generate the man page at build time
  + Use the new quirk infrastructure for version numbers
  + Catch invalid Dell dock component requests
  + Correctly output Intel HEX files with > 16bit offset addresses
  + Do not try to verify the element write if upload is unsupported
  + Fix a double-unref when updating any 8Bitdo device
  + Fix crash when enumerating with Dell dock connected but with no UEFI
  + Fix uploading large firmware files over DFU
  + Format the BCD USB revision numbers correctly
  + Guess the DFU transfer size if it is not specified
  + Include the reset timeout as wValue to fix some DFU bootloaders
  + Make the error message clearer when sans fonts are missing
  + Support devices with truncated DFU interface data
  + Use the correct remote-specified username and passord when using fwupdmgr
  + Use the correct wDetachTimeOut when writing DFU firmware
  + Verify devices with legacy VIDs are actually 8Bitdo controllers
- Add help2man as BuildRequires.
* Thu Dec 14 2017 stefan.bruens@rwth-aachen.de
- Fix dependencies and build options for non-x86 architectures. At
  least FW updates for USB are arch independent, and EFI FW updates
  can also be applied on Aarch64.
* Fri Oct 27 2017 dimstar@opensuse.org
- Update to version 1.0.0:
  * Add the plugin documentation to the main gtk-doc
  * Add a waiting-for-auth daemon state
  * Add fwupd_remote_get_checksum() to use in client programs
  * Generate the LD script from the GObject Introspection data
  * Prevent fwupd from mounting filesystems
  * uefi: Do not use system-specific infomation for PCI devices
  * uefi: Support uploading the firmware splash image
  * dell: only set coldplug delay when we know we need it
  * dell: only run SMI to toggle host MST GPIO on systems with host MST
  * dell: add functionality to blacklist HW with problems
  * dell: only run on intended chassis
  * thunderbolt-power: always run after thunderbolt plugin
  * Allow plugins to depend on each other
  * Add support for SMBIOSv3
  * dell: prefer to use hwids to get DMI keys and DE table
  * debian: remove /etc/fwupd.conf on upgrade
  * unifying: Use fu_plugin_check_supported()
  * Add fu_plugin_check_supported()
  * unifying: Use a device whitelist to avoid breaking devices
  * Fix various printing issues with the progressbar
  * dell: Fix a trivial whitespace issue
  * Do not fail to load the daemon if cached metadata is invalid
  * Do not store the newest release as part of the FuDevice object
  * Add a method to return a list of upgrades for a specific device
  * Move the downgrade calculation to the daemon
  * Make FuDevice derive from FwupdDevice rather than FwupdResult
  * Add a command 'clear-offline' to fwupdmgr
  * Merge releases where multiple remotes provide the same firmware
  * Remove the UniqueID property
  * uefi: Do not set the release version
  * udev: Do not match USB devices, even with a GUID set
  * Use the intel-wmi-thunderbolt kernel module to force power
  * dell: drop thunderbolt force power code
  * unifying: Add hardcoded summaries for peripheral kinds
  * Create CODE_OF_CONDUCT.md
  * Ensure more devices set the device summary
  * Add an 'Summary' property to each device
  * Add a human-readable title for each remote
  * unifying: Disable if the kernel has no CONFIG_HIDRAW support
  * Move deprecated symbols to a new header
  * Introduce an s390x cross compile target to CI
  * Add ModifyRemote as an easy way to enable and disable remotes like the LVFS
  * Do not auto-open all USB devices at startup
  * dfu: Use FuDeviceLocker
  * unifying: Use FuDeviceLocker
  * colorhug: Use FuDeviceLocker
  * ebitdo: Use FuDeviceLocker
  * altos: Use FuDeviceLocker
  * steelseries: Use FuDeviceLocker
  * usb: Use FuDeviceLocker
  * Add FuDeviceLocker to simplify device open/close lifecycles
  * dfu: Remove DEVO support
  * dfu: Remove the now-unused symtab support
  * Remove the ELF support from libdfu and move the code to the altos plugin
  * Use -Werror when building in Travis CI
  * Do not install the libdfu helper library
  * Parse the SMBIOS DMI table directly
  * usb: Disable the fallback USB plugin
  * Test for missing language translations at build time
  * Fix the libdfu self test failure on s390 and ppc64
* Fri Oct 27 2017 dimstar@opensuse.org
- Update to version 0.9.8:
  * Add a command 'clear-offline' to fwupdmgr
  * Do not fail to load the daemon if cached metadata is invalid
  * Fix a crash when using fu_plugin_device_add_delay()
  * Fix the libdfu self test failure on s390 and ppc64
  * Format the BCD USB revision numbers correctly
  * Never fallback to an offline update from client code
  * Prevent fwupd from mounting filesystems
  * dfu: Allow flashing when the target does not specify an
    alt-name
  * dfu: Do not try to verify the element write if upload is
    unsupported
  * dfu: Fix uploading large firmware files
  * dfu: Include the reset timeout as wValue to fix some hardware
  * dfu: Set the vendor ID to the runtime USB VID
  * dfu: Use 0x0101 as an alias for 0x0110
  * thunderbolt: move test for mock environment
    (gh#hughsie/fwupd#280)
  * udev: Do not match USB devices, even with a GUID set
  * uefi: Do not set the release version
  * unifying: Disable if the kernel has no CONFIG_HIDRAW support
* Tue Sep 19 2017 dimstar@opensuse.org
- Update to version 0.9.7:
  + 10 months worth of bugfixing, integrating more vendor specific
    Firmware update paths.
* Thu Mar  2 2017 dimstar@opensuse.org
- Update to version 0.8.1:
  + Delete duplicate translations (gh#hughsie/fwupd#89).
  + Do not hardcode docbook2man path.
  + Fix fwupdmgr timeout with missing pending database.
  + Fix compiler warnings.
  + Fix a crash when enumerating devices on a Dell WLD15.
  + dell: don't initialize libsmbios on unsupported systems.
  + Do not fail to start on Dell hardware.
  + Adjust systemd confinement restrictions.
  + Do not dlclose modules when running under valgrind.
  + Really remove the NoNewPrivileges systemd confinement.
  + Release fwupd 0.8.1.
* Mon Feb 27 2017 mpluskal@suse.com
- Update to version 0.8.0:
  + Show a different error when checking for updates while on
  + battery power (gh#hughsie/fwupd#68).
  + Clarify the test in --help and man page related to offline
  + (gh#hughsie/fwupd#69).
  + libdfu: Use a heuristic for the start address if the firmware
  + has no DfuSe footer.
  + dell: Don't return the address of a stack variable.
  + dell: Fix a possibly-impossible-to-hit buffer overrun.
  + close USB devices before error returns (gh#hughsie/fwupd#73).
  + Make libelf support optional.
  + Always make sure we're getting a C99 compiler.
  + Fix redeclaration of polkit autocleanup functions.
  + Uncomment SystemdService parameter in the dbus service file
  + (gh#hughsie/fwupd#74).
  + Make all providers and plugins share a GUsbContext.
  + Unexport libebitdo.
  + Move the plugins into plugin-specific directories.
  + Convert the providers to plugins to simplify code and for
  + future features.
  + Add support for Logitech Unifying devices.
  + Add a set of vfuncs that are run before and after a device
  + update.
  + Return the pending UEFI update when not on AC power.
  + Move the UPower functionality to a plugin.
  + Fix udev plugin loading.
  + fix dfu plugin loading.
  + Disable PrivateNetwork on systemd service.
  + Use more restrictive settings when running under systemd.
  + dell: add a new method for forcing a controller to flash mode.
  + Add VerifyUpdate to update the device checksums server-side.
  + Move the Option ROM parsing to the Udev plugin.
  + Move the device add delay to shared code.
  + Add initial skeleton for Intel Thunderbolt support.
  + unifying: Use the actual bootloader VID/PIDs when in firmware
  + mode.
  + Allow the metadata to match a version of fwupd and the existing
  + fw version.
  + Add fwupd_result_get_device_version_bootloader().
  + Fix the appstream-glib version guards.
  + dell: Add coldplug methods to let other plugins turn on
  + TBT/GPIO.
  + libdfu: Don't read data from some DfuSe targets.
  + Add the ability to run a prepare->exec->cleanup on coldplug.
  + Allow plugins to request that all plugins re-coldplug.
  + thunderbolt: Detecting new devices and add an actual device to
  + the daemon.
  + Add support for flashing the ChaosKey.
  + thunderbolt: add some guards around empty arrays.
  + dell: Adjust the coldplug preparation and cleanup sequence.
  + dell: Fix possible linker problem.
  + Revert "thunderbolt: add some guards around empty arrays".
  + Add fu_plugin_set_coldplug_delay() to allow hardware to
  + initialize if required.
  + altos: Add error checking when using termios.
  + ebitdo: Subclass FuDevice like the altos plugin.
  + altos: Set the flags in the init_real so they work for the
  + cmdline tool.
  + unifying: Subclass FuDevice like the altos plugin.
  + Include all debug messages when run with --verbose.
  + dell: introduce a standalone (noinst) tool to force mode
  + flashes.
  + Introduce plugin for Synaptics MST hubs.
  + synapticsmst: Add cascade support.
  + Only register the D-Bus service when all devices have been
  + added.
  + synapticsmst: Refactor away the global state.
  + synapticsmst: fix cascade support in the plugin.
  + Updates for thunderbolt plugin.
  + thunderbolt: Add special handling for safe mode on Dell systems
  + (gh#hughsie/fwupd#84).
  + synapticsmst: Iterate all nodes rather than hardcoding to 3.
  + synapticsmst: build GUID using dock type.
  + Add a new function fu_dell_supported to fu-dell-common.
  + synapticsmst: add a test suite.
  + synapticsmst: Fix up some trivial whitespace issues.
  + Fix a refcounting issue in the udev plugin.
- Add rpmlintrc untill security review is resolved
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.5:
  + Clean up PO files
  + Verify devices support updating in mode they are called.
  + Fix an assert when unlocking the dummy ESRT device
  + Don't create the UEFI dummy device if the unlock will happen on
  + next boot
  + dell: Match on TB16 as well
  + Fix a -fstack-protector-strong crash when uploading firmware
  + Enable the stack protection in local builds
  + dell: If running in test suite, don't try to get product ID
  + from sysfs
  + libfdfu: Show a warning when getting the alt-name failed
  + dfu: Fix listing devices using the ST reference bootloader
  + Show the nicely formatted target name for DfuSe devices
  + libdfu: Fix two possible critical warnings for corrupt USB
  + descriptors
  + libdfu: Correctly offset addresses when one zone has multiple
  + sectors
  + libdfu: Do not do GetStatus on dfuse upload
  + libdfu: Fix uploading from DfuSe devices
  + libdfu: Use the device offset when writing DfuSe firmware
  + libdfu: Add DfuAction enumerated value to represent a device
  + action
  + libdfu: Use an animated progress bar when performing DFU
  + operations
  + libdfu: Do not do a zero-byte download when in DfuSe mode
  + libdfu: Fix verification of written DfuSe firmware
  + libdfu: Ensure the device is open before claiming the interface
  + libdfu: Ensure the mode is set correctly when faking a runtime
  + libdfu: Re-get the quirks when the DfuDevice gets a new
  + GUsbDevice
  + libdfu: Add quirks for HydraBus as it does not have a DFU
  + runtime
  + libdfu: Match the device booloader or runtime VID and PID when
  + checking firmware
  + Add a 'replace-data' command to dfu-tool
  + string
  + libdfu: Add dfu_sector_get_zone() to get the continuous memory
  + zone number
  + libdfu: Wait for DNBUSY to be cleared when checking the DfuSe
  + status
  + libdfu: Correctly erase DfuSe devices
  + Enable hardening flags on more binaries
  + libdfu: Correctly set the element address when uploading from
  + DfuSe devices
- Add pkgconfig(gmodule-2.0) BuildRequires: Align with what
  + configure checks for.
- Add pkgconfig(libsmbios_c) BuildRequires: Support dell bios.
  + Unfortunatly, until we have fwup packaged and enabled, this will
  + not work.
- Add disabled pkgconfig(libtbtfwu): For future thunderbolt
  + support.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.4:
  + Add a fallback for older appstream-glib releases
  + Write the ELF files with the correct section type
  + Fix libfwupd self tests when a host-provided fwupd is not
  + available
  + Add dfu_firmware_add_symbol()
  + Add the Altos symbol table to the DfuFirmware
  + Use the symtab to set the VID/PID from Altos IHEX firmware
  + images
  + Show the human-readable version in the 'dfu-tool dump' output
  + Allow specifying the argument to 'dfu-tool set-release' in
  + major.minor format.
  + sections
  + Support writing the IHEX symbol table
  + call
  + Load the symbol table from ELF firmware
  + Load the Altos USB descriptor from ELF files
  + Add DFU_CIPHER_KIND_RSA
  + Fix a possible crash when uploading firmware files using libdfu
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.3:
  + build: Fix gtk-doc build when srcdir != builddir
  + In get-details output, display the blob filename
  + Ensure the update ID is set when getting local firmware details
  + Use a private gnupg key store
  + Add support for installing against multiple devices from a CAB
  + file
  + Use the correct firmware blob when installing a composite
  + device update
  + in get-details output, display update_name rather than Unknown
  + Device
  + statements
  + Don't make failures critical while checking versions or locked
  + state
  + Show a more detailed error when installing firmware on the
  + wildcard
  + Add Dell TPM and TB15/WD15 support via new Dell provider.
  + file
  + Allow blacklisting devices by their GUID
  + header file
  + Add XPS 9250 to Dell TPM modeswitch blacklist
  + Only display flashes left in results output when it gets low.
  + Add a small library for talking with 0bitdo hardware
  + Add another compile warning and fix up any build failures
  + Embed fwupd version in generated libfwupd and libdfu
  + documentation
  + Update fwupdmgr manpage for new commands and arguments
  + build: Fix gtk-doc build when srcdir != builddir
  + online not offline
  + Get the firmware version correctly from 0Bitdo gamepads
  + Switch to the Amazon S3 CDN for firmware metadata
  + Fix writing 8Bitdo device firmware
  + be updated
  + Show the vendor flashing instructions when installing
  + Split out the DFU file formats to separate files
  + Add fwupd_result_remove_device_flag()
  + Add FU_DEVICE_FLAG_NEEDS_BOOTLOADER
  + get-updates output
  + Allow providers to export percentage completion
  + Add fwupd_client_get_status()
  + Handle the 8Bitdo bootloader in a better way
  + Show a progress notification when installing firmware
  + Add fwupd_result_get_unique_id()
  + Use the SHA1 hash of the local file data as the component
  + origin
  + Use the correct define prefix for FwupdDeviceFlags
  + libdfu: Fix hang when parsing corrupt IHEX files
  + Add a set-target-size command to dfu-tool
  + Support the 'DEVO' cipher kind in libdfu
  + Add a set-address command to dfu-util
  + Disable the Dell specific code by default
  + Conditionally enable all providers based upon what's installed
  + Add a summary of providers that are enabled from configure
  + Do not use the deprecated GNOME_COMPILE_WARNINGS
  + Ignore devices that do not add at least one GUID
  + Do not attempt to add DFU devices not in runtime mode
  + Save the unique ID in the pending database
  + libdfu: Add initial ELF reading and writing support
  + Add dfu_firmware_format_from_string()
  + Normalize the DfuFirmwareFormat enums
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.2:
  + Allow devices to have multiple assigned GUIDs
  + Only return updatable devices from GetDevices()
  + Add fu_device_get_alternate()
  + Allow metainfo files to match only specific revisions of
  + devices
  + Re-read flags for a device after a provider's unlock routine is
  + done
  + Test for a locked device when trying to install firmware update
  + Enforce allowing providers to take away flash abilities
  + Support returning multiple GUIDs from GetDetails
  + Add a GetDetailsLocal() method to eventually replace
  + GetDetails()
  + break
  + libdfu: Add DfuVersion enumerated values
  + libdfu: Show the DFU protocol version in 'dfu-tool list'
  + Only claim the DFU interface when required
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.1:
  + Fix libdfu CRC check for big endian architectures
  + Add dfu_image_get_element_default()
  + Fix libdfu CRC check for big endian architectures
  + Fix big endian issues when reading and writing DFU and DfuSe
  + files
  + Remove non-interactive pinentry setting from fu-keyring
  + Set the system's DMI product name as the DisplayName for UEFI
  + Re-order output of get-devices to be easier to read
  + Make the device display name nicer
  + update version
  + Return all update descriptions newer than the installed version
  + Add summary and name field for Rival SteelSeries
  + Fix a critical warning when restarting the daemon
  + Add a 'supported' flag to the FuDevice
  + Add fwupd_client_connect()
  + Add a 'monitor' debugging command for fwupdmgr
  + Add device-added, device-removed and device-changed signals
  + Match the AppStream metadata after a device has been adedd
  + Re-match devices when the AppStream metadata is updated
  + Show 'Unknow Device' in fwupdmgr when a device name is not set
  + Set the device description when parsing local firmware files
  + Add support for a new device field "Flashes Left".
  + src/Makefile.am: reshuffle so enableable bits are only
  + referenced when on
  + Add support for a --force flag to override provider warnings
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.0:
  + Use g_usb_context_wait_for_replug()
  + Run vendor plugins as required
  + Add a plugin for SteelSeries hardware
  + Add fwupd_device_flag_to_string()
  + Return the device flags when getting firmware details
  + Show device flags in 'fwupdmgr get-devices'
  + Add fwupd_trust_flag_to_string()
  + Export FwupdUpdateState in libfwupd
  + Export FwupdUpdateFlags in libfwupd
  + Add FwupdResult to libfwupd
  + Add a self test framework for libfwupd
  + Add FwupdClient to libfwupd
  + Use FwupdClient from libfwupd in fwupdmgr
  + Use libfwupd inside the daemon
  + Emit a FwupdClient::changed when the daemon emits this signal
  + Rename some of the new libfwupd API to align with the D-Bus
  + names
  + libdfu: Fix up some NULL/FALSE confusion
  + libfwup: Fix up some NULL/FALSE confusion
  + FwupdClient
  + Allow other checksum kinds in FwupdResult
  + Allow SHA-256 hashes when verifying
  + Show the checksum kind in the fwupdmgr output
  + Add Alienware to the version quirk table
  + Do not use /tmp for downloaded files
  + Add fwupd_result_has_device_flag()
  + Do not return updates that require AC when on battery
  + Connect to UPower at startup
  + Test that GPG key import actually was successful (or didn't
  + change a key already in the keyring)
  + Use g_auto() in FuKeyring
  + Return errors of the correct type when using libfwupd
  + Allow overridding the location of the pending database for
  + test suite
  + Allow overriding the location of the provider offline files for
  + test suite
  + Validate that the dbus system bus is available before running
  + libfwupd tests
  + Update README.md for changes that have happened in the project
  + Add some basic explanation of how to use fwupd with various
  + frontends
  + Split out the libdfu-devel package
  + Revert "Allow overridding the location of the pending database
  + for test suite"
  + Revert "Allow overriding the location of the provider offline
  + files for test suite"
  + Allow the test suite to run in %%check
  + Generate gtk-doc documentation for libfwupd
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.6.3:
  + Require AC power before scheduling some types of firmware
  + update
  + Install the hardcoded firmware AppStream file
  + Correct the BCD version number for DFU 1.1
  + Add an unlock method for devices
  + Add ESRT enable method into UEFI provider.
  + Only read PCI OptionROM firmware when devices are manually
  + unlocked
  + Do not use deprecated API from libappstream-glib
  + Ignore the DFU runtime on the DW1820A
  + Export the attribute and quirk values in libdfu
  + Show ignored DFU devices in dfu-util, but not in fwupd
  + Allow defining update vfuncs with no runtime support
  + Revert "Allow defining update vfuncs with no runtime support"
  + Add a simple plugin infrastructure
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.6.2:
  + Add 'Created' and 'Modified' properties on managed devices
  + Fix get-results for UEFI provider.
  + Support vendor-specific UEFI version encodings
  + Move quirks directly into a single table and file.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.6.1:
  + Only dump the profiling data when run with --verbose
  + Always persist ColorHug devices after replug
  + Do not misdetect different ColorHug devices
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.6.0:
  + Add support for updating USB devices with DFU
  + libdfu: Add support for DfuSe firmware
  + libdfu: Generate gtk-doc documentation
  + libdfu: Don't rely on specific hardware to be present
  + libdfu: Move the VID:PID checks from the tool to DfuDevice
  + libdfu: Use a custom error domain
  + Use the same device identification string format as Microsoft
  + libdfu: Fix crash when setting a target size
  + libdfu: Allow setting the alternate settings in DfuSe firmware
  + libdfu: Add a merge command to dfu-tool
  + libdfu: Allow choosing a different alt-setting when downloading
  + libdfu: Fix a crash when setting a NULL image name
  + libdfu: Correctly implement auto-boot in dfu_device_download()
  + libdfu: Check for extra args to dfu-tool convert
  + libdfu: Call the progress callback when doing detach
  + Ignore the DFU device detach:attach when verifying
  + libdfu: Require a --force flag to flash wildcard firmware
  + Use new API available in fwup 0.5
  + libdfu: Make the element address 32 bits in size
  + libdfu: Support the ST-specific bitCanAccelerate
  + libdfu: Only do a Detach notification if we're actually doing
    to do it
  + libdfu: Use the progress bar for all uploads and downloads
  + libdfu: Improve the output of 'dfu-util list'
  + libdfu: Support download and upload to ST DfuSe devices
  + libdfu: Fix multi-interface devices like the Neo Freerunner
  + libdfu: Add a pkgconfig file
  + libdfu: Use signals to propagate device state
  + libdfu: Add a context object to handle device hotplug
  + libdfu: Add an example showing GObject Introspection
  + libdfu: Do not ref DfuDevice in DfuTarget so the auto-close
  + logic works
  + Close DFU devices as soon as possible after the transfer has
    completed
  + Emit the changed signal after doing an update
  + Rescan the DFU device after replug to get the new version
  + libdfu: Add dfu_context_get_device_by_platform_id()
  + libdfu: Add dfu_device_get_runtime_release()
  + libdfu: Add dfu_device_get_display_name()
  + libdfu: Fix self tests after recent API change
  + Split out the DFU provider as a new file
  + libdfu: Copy the platform ID and invalidate the GUsbDevice when
    removed
  + libdfu: Accept multiple spaces after the DfuSe sector name
  + libdfu: Verify the GUsbDevice is set before using it
  + libdfu: Remove the weak pointer when destroying the DfuTarget
  + libdfu: Fix dfu_device_wait_for_replug() so it can work with a
    DfuContext
  + Export the AppStream ID when returning device results
  + Rescan the DFU device after firmware has been updated
  + libdfu: Handle cancellation with ctrl+c in dfu-tool
  + libdfu: Add a quirk to support DFU runtime-less devices
  + libdfu: Add an explicit 'attach' method
  + libdfu: Add dfu_firmware_get_image_by_name()
  + libdfu: Make reading and writing to targets easier to
  + understand
  + Fix compile with --disable-shared
  + libdfu: Display all the files shown with 'dfu-tool dump'
  + libdfu: Fix a few crashers found using afl
  + libdfu: Fix another bug discovered by the fuzzer
  + libdfu: Add commands to encrypt and decrypt firmware images
  + libdfu: Show better device errors
  + libdfu: Add DfuCipher which is a property on a target and a
  + firmware file
  + libdfu: Add support for the draft 'DFU Metadata Table
  + Specification'
  + libdfu: Only enumerate the DfuContext when required
  + libdfu: Fix several reported crashes in the inhex32 import code
  + Release fwupd 0.6.0
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.4:
  + Fix compile error against fwupdate git due to dropped
  + functions.
  + Use strerror() when printing errors from libfwupdate
  + Use new API available in fwup 0.5
  + Release fwupd 0.5.4
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.3:
  + Avoid seeking when reading the file magic during refresh
  + Do not assume that the compressed XML data will be NUL
  + terminated
  + debugging
  + Use the correct user agent string for fwupdmgr
  + Release fwupd 0.5.3
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.2:
  + Ensure D-Bus remote errors are registered at fwupdmgr startup
  + Show the dotted-decimal representation of the UEFI version
  + number
  + require appstream-glib 0.5.1
  + not found
  + When the version is from the 'FW' extension do not cache the
  + device
  + Support cabinet archives files with more than one firmware
  + Add the update description to the GetDetails results
  + Add profiling data to debug slow startup times
  + Fix verify-update to produce components with the correct
  + provide values
  + Clear the in-memory firmware store only after parsing a valid
  + XML file
  + Release fwupd 0.5.2
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.1:
  + Fix the error message when no devices can be updated
  + offline update: Use glib api for for reading symlinks
  + Release fwupd 0.5.1
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.0:
  + Do not merge the existing firmware metadata with the submitted
  + files
  + Raise the dep on GLib to support and use g_autoptr()
  + Do not reboot if racing with the PackageKit offline update
  + mechanism
  + Release fwupd 0.5.0
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.6:
  + Install fwupd and fwsignd into /usr/lib/$(triplet)/fwupd
  + instead.
  + Use the new secure metadata URI
  + Update the offline update service to invoke right command
  + Don't apply firmware if something else is processing the
  + offline update
  + Remove fwsignd, we have the LVFS now
  + Depend on appstream-glib >= 0.5.0
  + Add application metadata when getting the updates list
  + Simplify the version properties on devices to avoid complexity
  + and bugs
  + Release fwupd 0.1.6
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.5:
  + Allow fwupd to be autostarted by systemd
  + Sign the test binary with the correct key
  + Do not pre-convert the update description from AppStream XML
  + Devices with option ROM are always internal
  + Prefer the GUID from the firmware than the device
  + Allow no arguments to 'fwupdmgr verify-update' and use sane
  + defaults
  + Add the ability to remove a vendor on the LVFS site
  + Fix validation of written firmware
  + Move the verification and metadata matching phase to the daemon
  + Add a simple config file to store the correct LVFS download URI
  + Make parsing the option ROM runtime optional
  + Add a Raspberry Pi firmware provider
  + Use the AppStream 0.9 firmware specification by default
  + Generate the ColorHug test files at runtime
  + Release fwupd 0.1.5
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.4:
  + man/Makefile.am: Add --sgml to docbook2man invocation
  + Make statements about storing private keys stronger.
  + Provide a way for clients to add new firmware metadata to the
  + system cache
  + Fix fwupd-offline-update.service
  + Revert "man/Makefile.am: Add --sgml to docbook2man invocation"
  + Add a Udev firmware provider
  + Extract the version string from the ROM in PCI devices
  + Add a 'verify' command that verifies the cryptographic hash of
  + device firmware
  + Make the ROM parsing more robust and add self tests
  + Get the version number out from Intel VBIOS too
  + Provide a way to dump the option ROM using the command line
  + build: gusb is required even without colorhug
  + remove unused variables
  + Do not return NULL as a gboolean
  + Fix Intel VBIOS detection on Dell hardware
  + Do not use the subsystem information when constructing the fake
  + GUID
  + Actually parse the PCI option ROM
  + Accept multiple files at one time when using fwupdmgr dump-rom
  + verify run
  + Add a 'verify-update' command to fwupdmgr
  + Fix trivial bug when parsing firmware versions
  + Keep hitting the hardware until it gives us enough ROM
  + Make the version parsing more resilient to corrupt firmware
  + Fix the example .inf file to reflect reality
  + Fix ROM PPID searching to work for all ROMs
  + Move the LVFS website to the fwupd project
  + Add the ability to create detached signatures
  + Allow cab files to be saved
  + Add a simple signing server that operates on .cab files
  + Automatically download metadata using fwupdmgr if required
  + Don't call efibootmgr after fwupdate.
  + Associate the contact email address directly with the vendor
  + key
  + Use the actual LVFS GPG key
  + Allow running fwsignd as the non-root user
  + metadata
  + Do not merge existing LVFS metadata
  + Do not use the file hash when storing the LVFS submitted
  + firmwares
  + Move GetUpdates to the daemon
  + Change the DBus method for installing firmware to 'Install'
  + Allow installing an offline UEFI update without --offline
  + Add a 'fwupdmgr update' command to update all devices to latest
  + versions
  + 'update' command
  + Increase the size limit of firmware to 50Mb
  + Only sign files when the entire file has been copied
  + Fallback to offline install when calling the update argument.
  + Reload appstream data after refreshing.
  + Release fwupd 0.1.4
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.3:
  + Coldplug the devices before acquiring the well known name
  + Add an UNKNOWN status so we can return meaningful enum values
  + Run the offline actions using systemd when required
  + Get the firmware version from the device descriptors
  + Added syntax highlighting
  + More markup
  + Support OpenHardware devices using the fwupd vendor extensions
  + Move boolean properties on the device to a set of flags
  + Release fwupd 0.1.3
* Wed May 27 2015 dimstar@opensuse.org
- Update to version 0.1.2:
  + More markup
  + Fixed typos and markup for executable
  + Add slovak translation
  + Add helper code to validate public key signatures
  + Decompress any firmware signatures in the .cab file
  + Verify firmware if a detached signature is present
  + Show the firmware trust status when doing GetDetails()
  + Only allow signed firmware to be upgraded without a password
  + Add some guidelines for vendors to README
  + Small grammar fix
  + Extract the .cat file alongside the firmware
  + Release fwupd 0.1.2
* Mon Apr 13 2015 dimstar@opensuse.org
- Update to version fwupd_0_1_1:
  + Do not crash when there are no devices to return
  + Add a 'get-updates' command to fwupdmgr
  + Add and document the offline-update lifecycle
  + Create runtime directories if they do not exist
  + Create a libfwupd shared library
  + Export the status as an enumerated value rather than a string
  + Release fwupd 0.1.1
* Mon Apr 13 2015 dimstar@opensuse.org
- Initial package.
